package com.alibaba.fastjson.parser;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.deserializer.CollectionResolveFieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.ExtraProcessor;
import com.alibaba.fastjson.parser.deserializer.ExtraTypeProvider;
import com.alibaba.fastjson.parser.deserializer.FieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer;
import com.alibaba.fastjson.parser.deserializer.ListResolveFieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.MapResolveFieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.IntegerCodec;
import com.alibaba.fastjson.serializer.LongCodec;
import com.alibaba.fastjson.serializer.StringCodec;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.PdrUtil;
import java.io.Closeable;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

public class DefaultJSONParser extends AbstractJSONParser implements Closeable {
    public static final int NONE = 0;
    public static final int NeedToResolve = 1;
    public static final int TypeNameRedirect = 2;
    private static final Set<Class<?>> primitiveClasses;
    protected ParserConfig config;
    protected ParseContext context;
    private ParseContext[] contextArray;
    private int contextArrayIndex;
    private DateFormat dateFormat;
    private String dateFormatPattern;
    private List<ExtraProcessor> extraProcessors;
    private List<ExtraTypeProvider> extraTypeProviders;
    protected final Object input;
    protected final JSONLexer lexer;
    private int resolveStatus;
    private List<ResolveTask> resolveTaskList;
    protected final SymbolTable symbolTable;

    static {
        HashSet hashSet = new HashSet();
        primitiveClasses = hashSet;
        hashSet.add(Boolean.TYPE);
        hashSet.add(Byte.TYPE);
        hashSet.add(Short.TYPE);
        hashSet.add(Integer.TYPE);
        hashSet.add(Long.TYPE);
        hashSet.add(Float.TYPE);
        hashSet.add(Double.TYPE);
        hashSet.add(Boolean.class);
        hashSet.add(Byte.class);
        hashSet.add(Short.class);
        hashSet.add(Integer.class);
        hashSet.add(Long.class);
        hashSet.add(Float.class);
        hashSet.add(Double.class);
        hashSet.add(BigInteger.class);
        hashSet.add(BigDecimal.class);
        hashSet.add(String.class);
    }

    public String getDateFomartPattern() {
        return this.dateFormatPattern;
    }

    public DateFormat getDateFormat() {
        if (this.dateFormat == null) {
            this.dateFormat = new SimpleDateFormat(this.dateFormatPattern);
        }
        return this.dateFormat;
    }

    public void setDateFormat(String str) {
        this.dateFormatPattern = str;
        this.dateFormat = null;
    }

    public void setDateFomrat(DateFormat dateFormat2) {
        this.dateFormat = dateFormat2;
    }

    public DefaultJSONParser(String str) {
        this(str, ParserConfig.getGlobalInstance(), JSON.DEFAULT_PARSER_FEATURE);
    }

    public DefaultJSONParser(String str, ParserConfig parserConfig) {
        this(str, new JSONScanner(str, JSON.DEFAULT_PARSER_FEATURE), parserConfig);
    }

    public DefaultJSONParser(String str, ParserConfig parserConfig, int i) {
        this(str, new JSONScanner(str, i), parserConfig);
    }

    public DefaultJSONParser(char[] cArr, int i, ParserConfig parserConfig, int i2) {
        this(cArr, new JSONScanner(cArr, i, i2), parserConfig);
    }

    public DefaultJSONParser(JSONLexer jSONLexer) {
        this(jSONLexer, ParserConfig.getGlobalInstance());
    }

    public DefaultJSONParser(JSONLexer jSONLexer, ParserConfig parserConfig) {
        this((Object) null, jSONLexer, parserConfig);
    }

    public DefaultJSONParser(Object obj, JSONLexer jSONLexer, ParserConfig parserConfig) {
        this.dateFormatPattern = JSON.DEFFAULT_DATE_FORMAT;
        this.contextArray = new ParseContext[8];
        this.contextArrayIndex = 0;
        this.resolveStatus = 0;
        this.extraTypeProviders = null;
        this.extraProcessors = null;
        this.lexer = jSONLexer;
        this.input = obj;
        this.config = parserConfig;
        this.symbolTable = parserConfig.getSymbolTable();
        jSONLexer.nextToken(12);
    }

    public SymbolTable getSymbolTable() {
        return this.symbolTable;
    }

    public String getInput() {
        Object obj = this.input;
        if (obj instanceof char[]) {
            return new String((char[]) this.input);
        }
        return obj.toString();
    }

    /* JADX WARNING: Removed duplicated region for block: B:134:0x02bc  */
    /* JADX WARNING: Removed duplicated region for block: B:136:0x02c5  */
    /* JADX WARNING: Removed duplicated region for block: B:66:0x0191  */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x01a4  */
    /* JADX WARNING: Removed duplicated region for block: B:98:0x0216  */
    public final Object parseObject(Map map, Object obj) {
        String str;
        boolean z;
        Object obj2;
        Number number;
        Object obj3;
        Object obj4;
        JSONLexer jSONLexer = this.lexer;
        if (jSONLexer.token() == 8) {
            jSONLexer.next();
            return null;
        } else if (jSONLexer.token() == 12 || jSONLexer.token() == 16) {
            ParseContext context2 = getContext();
            boolean z2 = false;
            while (true) {
                try {
                    jSONLexer.skipWhitespace();
                    char current = jSONLexer.getCurrent();
                    if (isEnabled(Feature.AllowArbitraryCommas)) {
                        while (current == ',') {
                            jSONLexer.next();
                            jSONLexer.skipWhitespace();
                            current = jSONLexer.getCurrent();
                        }
                    }
                    if (current == '\"') {
                        Object scanSymbol = jSONLexer.scanSymbol(this.symbolTable, Operators.QUOTE);
                        jSONLexer.skipWhitespace();
                        obj4 = scanSymbol;
                        if (jSONLexer.getCurrent() != ':') {
                            throw new JSONException("expect ':' at " + jSONLexer.pos() + ", name " + scanSymbol);
                        }
                    } else if (current == '}') {
                        jSONLexer.next();
                        jSONLexer.resetStringPosition();
                        jSONLexer.nextToken();
                        setContext(context2);
                        return map;
                    } else if (current == '\'') {
                        if (isEnabled(Feature.AllowSingleQuotes)) {
                            Object scanSymbol2 = jSONLexer.scanSymbol(this.symbolTable, Operators.SINGLE_QUOTE);
                            jSONLexer.skipWhitespace();
                            obj4 = scanSymbol2;
                            if (jSONLexer.getCurrent() != ':') {
                                throw new JSONException("expect ':' at " + jSONLexer.pos());
                            }
                        } else {
                            throw new JSONException("syntax error");
                        }
                    } else if (current == 26) {
                        throw new JSONException("syntax error");
                    } else if (current == ',') {
                        throw new JSONException("syntax error");
                    } else if ((current >= '0' && current <= '9') || current == '-') {
                        jSONLexer.resetStringPosition();
                        jSONLexer.scanNumber();
                        if (jSONLexer.token() == 2) {
                            obj3 = jSONLexer.integerValue();
                        } else {
                            obj3 = jSONLexer.decimalValue(true);
                        }
                        Object obj5 = obj3;
                        obj4 = obj5;
                        if (jSONLexer.getCurrent() != ':') {
                            throw new JSONException("expect ':' at " + jSONLexer.pos() + ", name " + obj5);
                        }
                    } else if (current == '{' || current == '[') {
                        jSONLexer.nextToken();
                        z = true;
                        str = parse();
                        if (!z) {
                            jSONLexer.next();
                            jSONLexer.skipWhitespace();
                        }
                        char current2 = jSONLexer.getCurrent();
                        jSONLexer.resetStringPosition();
                        if (str != JSON.DEFAULT_TYPE_KEY) {
                            String scanSymbol3 = jSONLexer.scanSymbol(this.symbolTable, Operators.QUOTE);
                            Class<?> loadClass = TypeUtils.loadClass(scanSymbol3);
                            if (loadClass == null) {
                                map.put(JSON.DEFAULT_TYPE_KEY, scanSymbol3);
                            } else {
                                jSONLexer.nextToken(16);
                                if (jSONLexer.token() == 13) {
                                    jSONLexer.nextToken(16);
                                    try {
                                        ObjectDeserializer deserializer = this.config.getDeserializer(loadClass);
                                        Object createInstance = deserializer instanceof JavaBeanDeserializer ? ((JavaBeanDeserializer) deserializer).createInstance(this, loadClass) : null;
                                        if (createInstance == null) {
                                            if (loadClass == Cloneable.class) {
                                                createInstance = new HashMap();
                                            } else {
                                                createInstance = loadClass.newInstance();
                                            }
                                        }
                                        return createInstance;
                                    } catch (Exception e) {
                                        throw new JSONException("create instance error", e);
                                    }
                                } else {
                                    setResolveStatus(2);
                                    if (this.context != null && !(obj instanceof Integer)) {
                                        popContext();
                                    }
                                    Object deserialze = this.config.getDeserializer(loadClass).deserialze(this, loadClass, obj);
                                    setContext(context2);
                                    return deserialze;
                                }
                            }
                        } else if (str == "$ref") {
                            jSONLexer.nextToken(4);
                            if (jSONLexer.token() == 4) {
                                String stringVal = jSONLexer.stringVal();
                                jSONLexer.nextToken(13);
                                if ("@".equals(stringVal)) {
                                    if (getContext() != null) {
                                        ParseContext context3 = getContext();
                                        Object object = context3.getObject();
                                        if ((object instanceof Object[]) || (object instanceof Collection)) {
                                            obj2 = object;
                                            if (jSONLexer.token() == 13) {
                                                jSONLexer.nextToken(16);
                                                setContext(context2);
                                                return obj2;
                                            }
                                            throw new JSONException("syntax error");
                                        } else if (context3.getParentContext() != null) {
                                            obj2 = context3.getParentContext().getObject();
                                            if (jSONLexer.token() == 13) {
                                            }
                                        }
                                    }
                                } else if (PdrUtil.FILE_PATH_ENTRY_BACK.equals(stringVal)) {
                                    ParseContext parentContext = context2.getParentContext();
                                    if (parentContext.getObject() != null) {
                                        obj2 = parentContext.getObject();
                                        if (jSONLexer.token() == 13) {
                                        }
                                    } else {
                                        addResolveTask(new ResolveTask(parentContext, stringVal));
                                        setResolveStatus(1);
                                    }
                                } else if (Operators.DOLLAR_STR.equals(stringVal)) {
                                    ParseContext parseContext = context2;
                                    while (parseContext.getParentContext() != null) {
                                        parseContext = parseContext.getParentContext();
                                    }
                                    if (parseContext.getObject() != null) {
                                        obj2 = parseContext.getObject();
                                        if (jSONLexer.token() == 13) {
                                        }
                                    } else {
                                        addResolveTask(new ResolveTask(parseContext, stringVal));
                                        setResolveStatus(1);
                                    }
                                } else {
                                    addResolveTask(new ResolveTask(context2, stringVal));
                                    setResolveStatus(1);
                                }
                                obj2 = null;
                                if (jSONLexer.token() == 13) {
                                }
                            } else {
                                throw new JSONException("illegal ref, " + JSONToken.name(jSONLexer.token()));
                            }
                        } else {
                            if (!z2) {
                                setContext(map, obj);
                                z2 = true;
                            }
                            String str2 = str;
                            if (map.getClass() == JSONObject.class) {
                                if (str == null) {
                                    str2 = "null";
                                } else {
                                    str2 = str.toString();
                                }
                            }
                            if (current2 == '\"') {
                                jSONLexer.scanString();
                                String stringVal2 = jSONLexer.stringVal();
                                String str3 = stringVal2;
                                if (jSONLexer.isEnabled(Feature.AllowISO8601DateFormat)) {
                                    JSONScanner jSONScanner = new JSONScanner(stringVal2);
                                    Date date = stringVal2;
                                    if (jSONScanner.scanISO8601DateIfMatch()) {
                                        date = jSONScanner.getCalendar().getTime();
                                    }
                                    jSONScanner.close();
                                    str3 = date;
                                }
                                map.put(str2, str3 == 1 ? 1 : 0);
                            } else if ((current2 >= '0' && current2 <= '9') || current2 == '-') {
                                jSONLexer.scanNumber();
                                if (jSONLexer.token() == 2) {
                                    number = jSONLexer.integerValue();
                                } else {
                                    number = jSONLexer.decimalValue(isEnabled(Feature.UseBigDecimal));
                                }
                                map.put(str2, number);
                            } else if (current2 == '[') {
                                jSONLexer.nextToken();
                                JSONArray jSONArray = new JSONArray();
                                parseArray(jSONArray, str2);
                                map.put(str2, jSONArray);
                                if (jSONLexer.token() == 13) {
                                    jSONLexer.nextToken();
                                    setContext(context2);
                                    return map;
                                } else if (jSONLexer.token() != 16) {
                                    throw new JSONException("syntax error");
                                }
                            } else if (current2 == '{') {
                                jSONLexer.nextToken();
                                boolean z3 = obj != null && obj.getClass() == Integer.class;
                                Map jSONObject = new JSONObject();
                                ParseContext context4 = !z3 ? setContext(context2, jSONObject, str2) : null;
                                Object parseObject = parseObject(jSONObject, str2);
                                if (!(context4 == null || jSONObject == parseObject)) {
                                    context4.setObject(map);
                                }
                                checkMapResolve(map, str2.toString());
                                if (map.getClass() == JSONObject.class) {
                                    map.put(str2.toString(), parseObject);
                                } else {
                                    map.put(str2, parseObject);
                                }
                                if (z3) {
                                    setContext(context2, parseObject, str2);
                                }
                                if (jSONLexer.token() == 13) {
                                    jSONLexer.nextToken();
                                    setContext(context2);
                                    setContext(context2);
                                    return map;
                                } else if (jSONLexer.token() != 16) {
                                    throw new JSONException("syntax error, " + jSONLexer.tokenName());
                                }
                            } else {
                                jSONLexer.nextToken();
                                Object parse = parse();
                                String str4 = str2;
                                if (map.getClass() == JSONObject.class) {
                                    str4 = str2.toString();
                                }
                                map.put(str4, parse);
                                if (jSONLexer.token() == 13) {
                                    jSONLexer.nextToken();
                                    setContext(context2);
                                    return map;
                                } else if (jSONLexer.token() != 16) {
                                    throw new JSONException("syntax error, position at " + jSONLexer.pos() + ", name " + ((Object) str4));
                                }
                            }
                            jSONLexer.skipWhitespace();
                            char current3 = jSONLexer.getCurrent();
                            if (current3 == ',') {
                                jSONLexer.next();
                            } else if (current3 == '}') {
                                jSONLexer.next();
                                jSONLexer.resetStringPosition();
                                jSONLexer.nextToken();
                                setContext(map, obj);
                                setContext(context2);
                                return map;
                            } else {
                                throw new JSONException("syntax error, position at " + jSONLexer.pos() + ", name " + ((Object) str2));
                            }
                        }
                    } else if (isEnabled(Feature.AllowUnQuotedFieldNames)) {
                        Object scanSymbolUnQuoted = jSONLexer.scanSymbolUnQuoted(this.symbolTable);
                        jSONLexer.skipWhitespace();
                        char current4 = jSONLexer.getCurrent();
                        obj4 = scanSymbolUnQuoted;
                        if (current4 != ':') {
                            throw new JSONException("expect ':' at " + jSONLexer.pos() + ", actual " + current4);
                        }
                    } else {
                        throw new JSONException("syntax error");
                    }
                    z = false;
                    str = obj4;
                    if (!z) {
                    }
                    char current22 = jSONLexer.getCurrent();
                    jSONLexer.resetStringPosition();
                    if (str != JSON.DEFAULT_TYPE_KEY) {
                    }
                } finally {
                    setContext(context2);
                }
            }
        } else {
            throw new JSONException("syntax error, expect {, actual " + jSONLexer.tokenName());
        }
    }

    public ParserConfig getConfig() {
        return this.config;
    }

    public void setConfig(ParserConfig parserConfig) {
        this.config = parserConfig;
    }

    public <T> T parseObject(Class<T> cls) {
        return (T) parseObject((Type) cls);
    }

    public <T> T parseObject(Type type) {
        if (this.lexer.token() == 8) {
            this.lexer.nextToken();
            return null;
        }
        if (this.lexer.token() == 4) {
            type = TypeUtils.unwrap(type);
            if (type == byte[].class) {
                T t = (T) this.lexer.bytesValue();
                this.lexer.nextToken();
                return t;
            } else if (type == char[].class) {
                String stringVal = this.lexer.stringVal();
                this.lexer.nextToken();
                return (T) stringVal.toCharArray();
            }
        }
        try {
            return (T) this.config.getDeserializer(type).deserialze(this, type, null);
        } catch (JSONException e) {
            throw e;
        } catch (Throwable th) {
            throw new JSONException(th.getMessage(), th);
        }
    }

    public <T> List<T> parseArray(Class<T> cls) {
        ArrayList arrayList = new ArrayList();
        parseArray((Class<?>) cls, (Collection) arrayList);
        return arrayList;
    }

    public void parseArray(Class<?> cls, Collection collection) {
        parseArray((Type) cls, collection);
    }

    public void parseArray(Type type, Collection collection) {
        parseArray(type, collection, null);
    }

    /* JADX INFO: finally extract failed */
    public void parseArray(Type type, Collection collection, Object obj) {
        ObjectDeserializer objectDeserializer;
        if (this.lexer.token() == 21 || this.lexer.token() == 22) {
            this.lexer.nextToken();
        }
        if (this.lexer.token() == 14) {
            if (Integer.TYPE == type) {
                objectDeserializer = IntegerCodec.instance;
                this.lexer.nextToken(2);
            } else if (String.class == type) {
                objectDeserializer = StringCodec.instance;
                this.lexer.nextToken(4);
            } else {
                objectDeserializer = this.config.getDeserializer(type);
                this.lexer.nextToken(objectDeserializer.getFastMatchToken());
            }
            ParseContext context2 = getContext();
            setContext(collection, obj);
            int i = 0;
            while (true) {
                try {
                    if (isEnabled(Feature.AllowArbitraryCommas)) {
                        while (this.lexer.token() == 16) {
                            this.lexer.nextToken();
                        }
                    }
                    if (this.lexer.token() == 15) {
                        setContext(context2);
                        this.lexer.nextToken(16);
                        return;
                    }
                    Object obj2 = null;
                    if (Integer.TYPE == type) {
                        collection.add(IntegerCodec.instance.deserialze(this, null, null));
                    } else if (String.class == type) {
                        if (this.lexer.token() == 4) {
                            obj2 = this.lexer.stringVal();
                            this.lexer.nextToken(16);
                        } else {
                            Object parse = parse();
                            if (parse != null) {
                                obj2 = parse.toString();
                            }
                        }
                        collection.add(obj2);
                    } else {
                        if (this.lexer.token() == 8) {
                            this.lexer.nextToken();
                        } else {
                            obj2 = objectDeserializer.deserialze(this, type, Integer.valueOf(i));
                        }
                        collection.add(obj2);
                        checkListResolve(collection);
                    }
                    if (this.lexer.token() == 16) {
                        this.lexer.nextToken(objectDeserializer.getFastMatchToken());
                    }
                    i++;
                } catch (Throwable th) {
                    setContext(context2);
                    throw th;
                }
            }
        } else {
            throw new JSONException("exepct '[', but " + JSONToken.name(this.lexer.token()));
        }
    }

    public Object[] parseArray(Type[] typeArr) {
        Object obj;
        boolean z;
        Class<?> cls;
        int i = 8;
        if (this.lexer.token() == 8) {
            this.lexer.nextToken(16);
            return null;
        }
        int i2 = 14;
        if (this.lexer.token() == 14) {
            Object[] objArr = new Object[typeArr.length];
            if (typeArr.length == 0) {
                this.lexer.nextToken(15);
                if (this.lexer.token() == 15) {
                    this.lexer.nextToken(16);
                    return new Object[0];
                }
                throw new JSONException("syntax error");
            }
            this.lexer.nextToken(2);
            int i3 = 0;
            while (i3 < typeArr.length) {
                if (this.lexer.token() == i) {
                    this.lexer.nextToken(16);
                    obj = null;
                } else {
                    Type type = typeArr[i3];
                    if (type == Integer.TYPE || type == Integer.class) {
                        if (this.lexer.token() == 2) {
                            obj = Integer.valueOf(this.lexer.intValue());
                            this.lexer.nextToken(16);
                        } else {
                            obj = TypeUtils.cast(parse(), type, this.config);
                        }
                    } else if (type != String.class) {
                        if (i3 != typeArr.length - 1 || !(type instanceof Class)) {
                            cls = null;
                            z = false;
                        } else {
                            Class cls2 = (Class) type;
                            z = cls2.isArray();
                            cls = cls2.getComponentType();
                        }
                        if (!z || this.lexer.token() == i2) {
                            obj = this.config.getDeserializer(type).deserialze(this, type, null);
                        } else {
                            ArrayList arrayList = new ArrayList();
                            ObjectDeserializer deserializer = this.config.getDeserializer(cls);
                            int fastMatchToken = deserializer.getFastMatchToken();
                            if (this.lexer.token() != 15) {
                                while (true) {
                                    arrayList.add(deserializer.deserialze(this, type, null));
                                    if (this.lexer.token() != 16) {
                                        break;
                                    }
                                    this.lexer.nextToken(fastMatchToken);
                                }
                                if (this.lexer.token() != 15) {
                                    throw new JSONException("syntax error :" + JSONToken.name(this.lexer.token()));
                                }
                            }
                            obj = TypeUtils.cast(arrayList, type, this.config);
                        }
                    } else if (this.lexer.token() == 4) {
                        obj = this.lexer.stringVal();
                        this.lexer.nextToken(16);
                    } else {
                        obj = TypeUtils.cast(parse(), type, this.config);
                    }
                }
                objArr[i3] = obj;
                if (this.lexer.token() == 15) {
                    break;
                } else if (this.lexer.token() == 16) {
                    if (i3 == typeArr.length - 1) {
                        this.lexer.nextToken(15);
                    } else {
                        this.lexer.nextToken(2);
                    }
                    i3++;
                    i = 8;
                    i2 = 14;
                } else {
                    throw new JSONException("syntax error :" + JSONToken.name(this.lexer.token()));
                }
            }
            if (this.lexer.token() == 15) {
                this.lexer.nextToken(16);
                return objArr;
            }
            throw new JSONException("syntax error");
        }
        throw new JSONException("syntax error : " + this.lexer.tokenName());
    }

    public void parseObject(Object obj) {
        Object obj2;
        Class<?> cls = obj.getClass();
        Map<String, FieldDeserializer> fieldDeserializers = this.config.getFieldDeserializers(cls);
        if (this.lexer.token() == 12 || this.lexer.token() == 16) {
            while (true) {
                String scanSymbol = this.lexer.scanSymbol(this.symbolTable);
                if (scanSymbol == null) {
                    if (this.lexer.token() == 13) {
                        this.lexer.nextToken(16);
                        return;
                    } else if (this.lexer.token() == 16 && isEnabled(Feature.AllowArbitraryCommas)) {
                    }
                }
                FieldDeserializer fieldDeserializer = fieldDeserializers.get(scanSymbol);
                if (fieldDeserializer == null && scanSymbol != null) {
                    Iterator<Map.Entry<String, FieldDeserializer>> it = fieldDeserializers.entrySet().iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            break;
                        }
                        Map.Entry<String, FieldDeserializer> next = it.next();
                        if (scanSymbol.equalsIgnoreCase(next.getKey())) {
                            fieldDeserializer = next.getValue();
                            break;
                        }
                    }
                }
                if (fieldDeserializer != null) {
                    Class<?> fieldClass = fieldDeserializer.getFieldClass();
                    Type fieldType = fieldDeserializer.getFieldType();
                    if (fieldClass == Integer.TYPE) {
                        this.lexer.nextTokenWithColon(2);
                        obj2 = IntegerCodec.instance.deserialze(this, fieldType, null);
                    } else if (fieldClass == String.class) {
                        this.lexer.nextTokenWithColon(4);
                        obj2 = StringCodec.deserialze(this);
                    } else if (fieldClass == Long.TYPE) {
                        this.lexer.nextTokenWithColon(2);
                        obj2 = LongCodec.instance.deserialze(this, fieldType, null);
                    } else {
                        ObjectDeserializer deserializer = this.config.getDeserializer(fieldClass, fieldType);
                        this.lexer.nextTokenWithColon(deserializer.getFastMatchToken());
                        obj2 = deserializer.deserialze(this, fieldType, null);
                    }
                    fieldDeserializer.setValue(obj, obj2);
                    if (this.lexer.token() != 16 && this.lexer.token() == 13) {
                        this.lexer.nextToken(16);
                        return;
                    }
                } else if (isEnabled(Feature.IgnoreNotMatch)) {
                    this.lexer.nextTokenWithColon();
                    parse();
                    if (this.lexer.token() == 13) {
                        this.lexer.nextToken();
                        return;
                    }
                } else {
                    throw new JSONException("setter not found, class " + cls.getName() + ", property " + scanSymbol);
                }
            }
        } else {
            throw new JSONException("syntax error, expect {, actual " + this.lexer.tokenName());
        }
    }

    public Object parseArrayWithType(Type type) {
        if (this.lexer.token() == 8) {
            this.lexer.nextToken();
            return null;
        }
        Type[] actualTypeArguments = ((ParameterizedType) type).getActualTypeArguments();
        if (actualTypeArguments.length == 1) {
            Type type2 = actualTypeArguments[0];
            if (type2 instanceof Class) {
                ArrayList arrayList = new ArrayList();
                parseArray((Class) type2, (Collection) arrayList);
                return arrayList;
            } else if (type2 instanceof WildcardType) {
                WildcardType wildcardType = (WildcardType) type2;
                Type type3 = wildcardType.getUpperBounds()[0];
                if (!Object.class.equals(type3)) {
                    ArrayList arrayList2 = new ArrayList();
                    parseArray((Class) type3, (Collection) arrayList2);
                    return arrayList2;
                } else if (wildcardType.getLowerBounds().length == 0) {
                    return parse();
                } else {
                    throw new JSONException("not support type : " + type);
                }
            } else {
                if (type2 instanceof TypeVariable) {
                    TypeVariable typeVariable = (TypeVariable) type2;
                    Type[] bounds = typeVariable.getBounds();
                    if (bounds.length == 1) {
                        Type type4 = bounds[0];
                        if (type4 instanceof Class) {
                            ArrayList arrayList3 = new ArrayList();
                            parseArray((Class) type4, (Collection) arrayList3);
                            return arrayList3;
                        }
                    } else {
                        throw new JSONException("not support : " + typeVariable);
                    }
                }
                if (type2 instanceof ParameterizedType) {
                    ArrayList arrayList4 = new ArrayList();
                    parseArray((ParameterizedType) type2, arrayList4);
                    return arrayList4;
                }
                throw new JSONException("TODO : " + type);
            }
        } else {
            throw new JSONException("not support type " + type);
        }
    }

    public int getResolveStatus() {
        return this.resolveStatus;
    }

    public void setResolveStatus(int i) {
        this.resolveStatus = i;
    }

    public Object getObject(String str) {
        for (int i = 0; i < this.contextArrayIndex; i++) {
            if (str.equals(this.contextArray[i].getPath())) {
                return this.contextArray[i].getObject();
            }
        }
        return null;
    }

    public void checkListResolve(Collection collection) {
        if (this.resolveStatus != 1) {
            return;
        }
        if (collection instanceof List) {
            ResolveTask lastResolveTask = getLastResolveTask();
            lastResolveTask.setFieldDeserializer(new ListResolveFieldDeserializer(this, (List) collection, collection.size() - 1));
            lastResolveTask.setOwnerContext(this.context);
            setResolveStatus(0);
            return;
        }
        ResolveTask lastResolveTask2 = getLastResolveTask();
        lastResolveTask2.setFieldDeserializer(new CollectionResolveFieldDeserializer(this, collection));
        lastResolveTask2.setOwnerContext(this.context);
        setResolveStatus(0);
    }

    public void checkMapResolve(Map map, String str) {
        if (this.resolveStatus == 1) {
            MapResolveFieldDeserializer mapResolveFieldDeserializer = new MapResolveFieldDeserializer(map, str);
            ResolveTask lastResolveTask = getLastResolveTask();
            lastResolveTask.setFieldDeserializer(mapResolveFieldDeserializer);
            lastResolveTask.setOwnerContext(this.context);
            setResolveStatus(0);
        }
    }

    public Object parseObject(Map map) {
        return parseObject(map, null);
    }

    public JSONObject parseObject() {
        JSONObject jSONObject = new JSONObject();
        parseObject((Map) jSONObject);
        return jSONObject;
    }

    public final void parseArray(Collection collection) {
        parseArray(collection, (Object) null);
    }

    public final void parseArray(Collection collection, Object obj) {
        Object obj2;
        JSONLexer lexer2 = getLexer();
        if (lexer2.token() == 21 || lexer2.token() == 22) {
            lexer2.nextToken();
        }
        if (lexer2.token() == 14) {
            lexer2.nextToken(4);
            ParseContext context2 = getContext();
            setContext(collection, obj);
            int i = 0;
            while (true) {
                try {
                    if (isEnabled(Feature.AllowArbitraryCommas)) {
                        while (lexer2.token() == 16) {
                            lexer2.nextToken();
                        }
                    }
                    int i2 = lexer2.token();
                    Object obj3 = null;
                    obj3 = null;
                    if (i2 == 2) {
                        Object integerValue = lexer2.integerValue();
                        lexer2.nextToken(16);
                        obj3 = integerValue;
                    } else if (i2 == 3) {
                        if (lexer2.isEnabled(Feature.UseBigDecimal)) {
                            obj2 = lexer2.decimalValue(true);
                        } else {
                            obj2 = lexer2.decimalValue(false);
                        }
                        obj3 = obj2;
                        lexer2.nextToken(16);
                    } else if (i2 == 4) {
                        String stringVal = lexer2.stringVal();
                        lexer2.nextToken(16);
                        obj3 = stringVal;
                        if (lexer2.isEnabled(Feature.AllowISO8601DateFormat)) {
                            JSONScanner jSONScanner = new JSONScanner(stringVal);
                            Object obj4 = stringVal;
                            if (jSONScanner.scanISO8601DateIfMatch()) {
                                obj4 = jSONScanner.getCalendar().getTime();
                            }
                            jSONScanner.close();
                            obj3 = obj4;
                        }
                    } else if (i2 == 6) {
                        Object obj5 = Boolean.TRUE;
                        lexer2.nextToken(16);
                        obj3 = obj5;
                    } else if (i2 == 7) {
                        Object obj6 = Boolean.FALSE;
                        lexer2.nextToken(16);
                        obj3 = obj6;
                    } else if (i2 == 8) {
                        lexer2.nextToken(4);
                    } else if (i2 == 12) {
                        obj3 = parseObject(new JSONObject(), Integer.valueOf(i));
                    } else if (i2 == 20) {
                        throw new JSONException("unclosed jsonArray");
                    } else if (i2 == 23) {
                        lexer2.nextToken(4);
                    } else if (i2 == 14) {
                        Collection jSONArray = new JSONArray();
                        parseArray(jSONArray, Integer.valueOf(i));
                        obj3 = jSONArray;
                    } else if (i2 != 15) {
                        obj3 = parse();
                    } else {
                        lexer2.nextToken(16);
                        return;
                    }
                    collection.add(obj3 == 1 ? 1 : 0);
                    checkListResolve(collection);
                    if (lexer2.token() == 16) {
                        lexer2.nextToken(4);
                    }
                    i++;
                } finally {
                    setContext(context2);
                }
            }
        } else {
            throw new JSONException("syntax error, expect [, actual " + JSONToken.name(lexer2.token()) + ", pos " + lexer2.pos());
        }
    }

    public ParseContext getContext() {
        return this.context;
    }

    public void addResolveTask(ResolveTask resolveTask) {
        if (this.resolveTaskList == null) {
            this.resolveTaskList = new ArrayList(2);
        }
        this.resolveTaskList.add(resolveTask);
    }

    public ResolveTask getLastResolveTask() {
        List<ResolveTask> list = this.resolveTaskList;
        return list.get(list.size() - 1);
    }

    public List<ExtraProcessor> getExtraProcessors() {
        if (this.extraProcessors == null) {
            this.extraProcessors = new ArrayList(2);
        }
        return this.extraProcessors;
    }

    public List<ExtraProcessor> getExtraProcessorsDirect() {
        return this.extraProcessors;
    }

    public List<ExtraTypeProvider> getExtraTypeProviders() {
        if (this.extraTypeProviders == null) {
            this.extraTypeProviders = new ArrayList(2);
        }
        return this.extraTypeProviders;
    }

    public List<ExtraTypeProvider> getExtraTypeProvidersDirect() {
        return this.extraTypeProviders;
    }

    public void setContext(ParseContext parseContext) {
        if (!isEnabled(Feature.DisableCircularReferenceDetect)) {
            this.context = parseContext;
        }
    }

    public void popContext() {
        if (!isEnabled(Feature.DisableCircularReferenceDetect)) {
            this.context = this.context.getParentContext();
            ParseContext[] parseContextArr = this.contextArray;
            int i = this.contextArrayIndex;
            parseContextArr[i - 1] = null;
            this.contextArrayIndex = i - 1;
        }
    }

    public ParseContext setContext(Object obj, Object obj2) {
        if (isEnabled(Feature.DisableCircularReferenceDetect)) {
            return null;
        }
        return setContext(this.context, obj, obj2);
    }

    public ParseContext setContext(ParseContext parseContext, Object obj, Object obj2) {
        if (isEnabled(Feature.DisableCircularReferenceDetect)) {
            return null;
        }
        ParseContext parseContext2 = new ParseContext(parseContext, obj, obj2);
        this.context = parseContext2;
        addContext(parseContext2);
        return this.context;
    }

    private void addContext(ParseContext parseContext) {
        int i = this.contextArrayIndex;
        this.contextArrayIndex = i + 1;
        ParseContext[] parseContextArr = this.contextArray;
        if (i >= parseContextArr.length) {
            ParseContext[] parseContextArr2 = new ParseContext[((parseContextArr.length * 3) / 2)];
            System.arraycopy(parseContextArr, 0, parseContextArr2, 0, parseContextArr.length);
            this.contextArray = parseContextArr2;
        }
        this.contextArray[i] = parseContext;
    }

    public Object parse() {
        return parse(null);
    }

    public Object parseKey() {
        if (this.lexer.token() != 18) {
            return parse(null);
        }
        String stringVal = this.lexer.stringVal();
        this.lexer.nextToken(16);
        return stringVal;
    }

    public Object parse(Object obj) {
        JSONLexer lexer2 = getLexer();
        int i = lexer2.token();
        if (i == 2) {
            Number integerValue = lexer2.integerValue();
            lexer2.nextToken();
            return integerValue;
        } else if (i == 3) {
            Number decimalValue = lexer2.decimalValue(isEnabled(Feature.UseBigDecimal));
            lexer2.nextToken();
            return decimalValue;
        } else if (i == 4) {
            String stringVal = lexer2.stringVal();
            lexer2.nextToken(16);
            if (lexer2.isEnabled(Feature.AllowISO8601DateFormat)) {
                JSONScanner jSONScanner = new JSONScanner(stringVal);
                try {
                    if (jSONScanner.scanISO8601DateIfMatch()) {
                        return jSONScanner.getCalendar().getTime();
                    }
                    jSONScanner.close();
                } finally {
                    jSONScanner.close();
                }
            }
            return stringVal;
        } else if (i == 12) {
            return parseObject(new JSONObject(), obj);
        } else {
            if (i != 14) {
                switch (i) {
                    case 6:
                        lexer2.nextToken();
                        return Boolean.TRUE;
                    case 7:
                        lexer2.nextToken();
                        return Boolean.FALSE;
                    case 8:
                        lexer2.nextToken();
                        return null;
                    case 9:
                        lexer2.nextToken(18);
                        if (lexer2.token() == 18) {
                            lexer2.nextToken(10);
                            accept(10);
                            long longValue = lexer2.integerValue().longValue();
                            accept(2);
                            accept(11);
                            return new Date(longValue);
                        }
                        throw new JSONException("syntax error");
                    default:
                        switch (i) {
                            case 20:
                                if (lexer2.isBlankInput()) {
                                    return null;
                                }
                                throw new JSONException("unterminated json string, pos " + lexer2.getBufferPosition());
                            case 21:
                                lexer2.nextToken();
                                HashSet hashSet = new HashSet();
                                parseArray(hashSet, obj);
                                return hashSet;
                            case 22:
                                lexer2.nextToken();
                                TreeSet treeSet = new TreeSet();
                                parseArray(treeSet, obj);
                                return treeSet;
                            case 23:
                                lexer2.nextToken();
                                return null;
                            default:
                                throw new JSONException("syntax error, pos " + lexer2.getBufferPosition());
                        }
                }
            } else {
                JSONArray jSONArray = new JSONArray();
                parseArray(jSONArray, obj);
                return jSONArray;
            }
        }
    }

    public void config(Feature feature, boolean z) {
        getLexer().config(feature, z);
    }

    public boolean isEnabled(Feature feature) {
        return getLexer().isEnabled(feature);
    }

    public JSONLexer getLexer() {
        return this.lexer;
    }

    public final void accept(int i) {
        JSONLexer lexer2 = getLexer();
        if (lexer2.token() == i) {
            lexer2.nextToken();
            return;
        }
        throw new JSONException("syntax error, expect " + JSONToken.name(i) + ", actual " + JSONToken.name(lexer2.token()));
    }

    public final void accept(int i, int i2) {
        JSONLexer lexer2 = getLexer();
        if (lexer2.token() == i) {
            lexer2.nextToken(i2);
            return;
        }
        throw new JSONException("syntax error, expect " + JSONToken.name(i) + ", actual " + JSONToken.name(lexer2.token()));
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        JSONLexer lexer2 = getLexer();
        try {
            if (isEnabled(Feature.AutoCloseSource)) {
                if (lexer2.token() != 20) {
                    throw new JSONException("not close json text, token : " + JSONToken.name(lexer2.token()));
                }
            }
        } finally {
            lexer2.close();
        }
    }

    public void handleResovleTask(Object obj) {
        Object obj2;
        List<ResolveTask> list = this.resolveTaskList;
        if (list != null) {
            int size = list.size();
            for (int i = 0; i < size; i++) {
                ResolveTask resolveTask = this.resolveTaskList.get(i);
                FieldDeserializer fieldDeserializer = resolveTask.getFieldDeserializer();
                if (fieldDeserializer != null) {
                    Object obj3 = null;
                    if (resolveTask.getOwnerContext() != null) {
                        obj3 = resolveTask.getOwnerContext().getObject();
                    }
                    String referenceValue = resolveTask.getReferenceValue();
                    if (referenceValue.startsWith(Operators.DOLLAR_STR)) {
                        obj2 = getObject(referenceValue);
                    } else {
                        obj2 = resolveTask.getContext().getObject();
                    }
                    fieldDeserializer.setValue(obj3, obj2);
                }
            }
        }
    }

    public static class ResolveTask {
        private final ParseContext context;
        private FieldDeserializer fieldDeserializer;
        private ParseContext ownerContext;
        private final String referenceValue;

        public ResolveTask(ParseContext parseContext, String str) {
            this.context = parseContext;
            this.referenceValue = str;
        }

        public ParseContext getContext() {
            return this.context;
        }

        public String getReferenceValue() {
            return this.referenceValue;
        }

        public FieldDeserializer getFieldDeserializer() {
            return this.fieldDeserializer;
        }

        public void setFieldDeserializer(FieldDeserializer fieldDeserializer2) {
            this.fieldDeserializer = fieldDeserializer2;
        }

        public ParseContext getOwnerContext() {
            return this.ownerContext;
        }

        public void setOwnerContext(ParseContext parseContext) {
            this.ownerContext = parseContext;
        }
    }
}
