package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.JSONToken;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.serializer.FilterUtils;
import com.alibaba.fastjson.util.DeserializeBeanInfo;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.PdrUtil;
import java.lang.reflect.Constructor;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class JavaBeanDeserializer implements ObjectDeserializer {
    private DeserializeBeanInfo beanInfo;
    private final Class<?> clazz;
    private final Map<String, FieldDeserializer> feildDeserializerMap;
    private final List<FieldDeserializer> fieldDeserializers;
    private final List<FieldDeserializer> sortedFieldDeserializers;

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 12;
    }

    public JavaBeanDeserializer(ParserConfig parserConfig, Class<?> cls) {
        this(parserConfig, cls, cls);
    }

    public JavaBeanDeserializer(ParserConfig parserConfig, Class<?> cls, Type type) {
        this.feildDeserializerMap = new IdentityHashMap();
        this.fieldDeserializers = new ArrayList();
        this.sortedFieldDeserializers = new ArrayList();
        this.clazz = cls;
        DeserializeBeanInfo computeSetters = DeserializeBeanInfo.computeSetters(cls, type);
        this.beanInfo = computeSetters;
        for (FieldInfo fieldInfo : computeSetters.getFieldList()) {
            addFieldDeserializer(parserConfig, cls, fieldInfo);
        }
        for (FieldInfo fieldInfo2 : this.beanInfo.getSortedFieldList()) {
            this.sortedFieldDeserializers.add(this.feildDeserializerMap.get(fieldInfo2.getName().intern()));
        }
    }

    public Map<String, FieldDeserializer> getFieldDeserializerMap() {
        return this.feildDeserializerMap;
    }

    private void addFieldDeserializer(ParserConfig parserConfig, Class<?> cls, FieldInfo fieldInfo) {
        String intern = fieldInfo.getName().intern();
        FieldDeserializer createFieldDeserializer = createFieldDeserializer(parserConfig, cls, fieldInfo);
        this.feildDeserializerMap.put(intern, createFieldDeserializer);
        this.fieldDeserializers.add(createFieldDeserializer);
    }

    public FieldDeserializer createFieldDeserializer(ParserConfig parserConfig, Class<?> cls, FieldInfo fieldInfo) {
        return parserConfig.createFieldDeserializer(parserConfig, cls, fieldInfo);
    }

    public Object createInstance(DefaultJSONParser defaultJSONParser, Type type) {
        Object obj;
        if ((type instanceof Class) && this.clazz.isInterface()) {
            return Proxy.newProxyInstance(Thread.currentThread().getContextClassLoader(), new Class[]{(Class) type}, new JSONObject());
        } else if (this.beanInfo.getDefaultConstructor() == null) {
            return null;
        } else {
            try {
                Constructor<?> defaultConstructor = this.beanInfo.getDefaultConstructor();
                if (defaultConstructor.getParameterTypes().length == 0) {
                    obj = defaultConstructor.newInstance(new Object[0]);
                } else {
                    obj = defaultConstructor.newInstance(defaultJSONParser.getContext().getObject());
                }
                if (defaultJSONParser.isEnabled(Feature.InitStringFieldAsEmpty)) {
                    for (FieldInfo fieldInfo : this.beanInfo.getFieldList()) {
                        if (fieldInfo.getFieldClass() == String.class) {
                            try {
                                fieldInfo.set(obj, "");
                            } catch (Exception e) {
                                throw new JSONException("create instance error, class " + this.clazz.getName(), e);
                            }
                        }
                    }
                }
                return obj;
            } catch (Exception e2) {
                throw new JSONException("create instance error, class " + this.clazz.getName(), e2);
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        return (T) deserialze(defaultJSONParser, type, obj, null);
    }

    public <T> T deserialzeArrayMapping(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2) {
        JSONLexer lexer = defaultJSONParser.getLexer();
        if (lexer.token() == 14) {
            T t = (T) createInstance(defaultJSONParser, type);
            int size = this.sortedFieldDeserializers.size();
            int i = 0;
            while (i < size) {
                char c = i == size + -1 ? Operators.ARRAY_END : Operators.ARRAY_SEPRATOR;
                FieldDeserializer fieldDeserializer = this.sortedFieldDeserializers.get(i);
                Class<?> fieldClass = fieldDeserializer.getFieldClass();
                if (fieldClass == Integer.TYPE) {
                    fieldDeserializer.setValue((Object) t, lexer.scanInt(c));
                } else if (fieldClass == String.class) {
                    fieldDeserializer.setValue((Object) t, lexer.scanString(c));
                } else if (fieldClass == Long.TYPE) {
                    fieldDeserializer.setValue(t, lexer.scanLong(c));
                } else if (fieldClass.isEnum()) {
                    fieldDeserializer.setValue(t, lexer.scanEnum(fieldClass, defaultJSONParser.getSymbolTable(), c));
                } else {
                    lexer.nextToken(14);
                    fieldDeserializer.setValue(t, defaultJSONParser.parseObject(fieldDeserializer.getFieldType()));
                    if (c == ']') {
                        if (lexer.token() == 15) {
                            lexer.nextToken(16);
                        } else {
                            throw new JSONException("syntax error");
                        }
                    } else if (c == ',' && lexer.token() != 16) {
                        throw new JSONException("syntax error");
                    }
                }
                i++;
            }
            lexer.nextToken(16);
            return t;
        }
        throw new JSONException("error");
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:126:0x0233 */
    /* JADX WARNING: Code restructure failed: missing block: B:100:0x01d1, code lost:
        if (r3 == null) goto L_0x01d6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:101:0x01d3, code lost:
        r3.setObject(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:102:0x01d6, code lost:
        r20.setContext(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:103:0x01d9, code lost:
        return r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:125:0x022d, code lost:
        r2 = r2;
        r3 = r3;
        r1 = (T) r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:162:0x0313, code lost:
        throw new com.alibaba.fastjson.JSONException("syntax error, unexpect token " + com.alibaba.fastjson.parser.JSONToken.name(r10.token()));
     */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x0322  */
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2) {
        Object obj3;
        Throwable th;
        Object obj4;
        if (type == JSON.class || type == JSONObject.class) {
            return (T) defaultJSONParser.parse();
        }
        JSONLexer lexer = defaultJSONParser.getLexer();
        ParseContext parseContext = null;
        if (lexer.token() == 8) {
            lexer.nextToken(16);
            return null;
        }
        ParseContext context = defaultJSONParser.getContext();
        if (!(obj2 == null || context == null)) {
            context = context.getParentContext();
        }
        try {
            if (lexer.token() == 13) {
                lexer.nextToken(16);
                T t = obj2 == null ? (T) createInstance(defaultJSONParser, type) : (T) obj2;
                defaultJSONParser.setContext(context);
                return t;
            } else if (lexer.token() == 14 && isSupportArrayToBean(lexer)) {
                T t2 = (T) deserialzeArrayMapping(defaultJSONParser, type, obj, obj2);
                defaultJSONParser.setContext(context);
                return t2;
            } else if (lexer.token() == 12 || lexer.token() == 16) {
                if (defaultJSONParser.getResolveStatus() == 2) {
                    defaultJSONParser.setResolveStatus(0);
                }
                obj3 = obj2;
                HashMap hashMap = null;
                ParseContext parseContext2 = null;
                while (true) {
                    try {
                        String scanSymbol = lexer.scanSymbol(defaultJSONParser.getSymbolTable());
                        if (scanSymbol == null) {
                            if (lexer.token() == 13) {
                                lexer.nextToken(16);
                                obj4 = obj3;
                                break;
                            } else if (lexer.token() == 16 && defaultJSONParser.isEnabled(Feature.AllowArbitraryCommas)) {
                            }
                        }
                        if ("$ref" == scanSymbol) {
                            lexer.nextTokenWithColon(4);
                            if (lexer.token() == 4) {
                                String stringVal = lexer.stringVal();
                                if ("@".equals(stringVal)) {
                                    obj3 = (T) context.getObject();
                                } else if (PdrUtil.FILE_PATH_ENTRY_BACK.equals(stringVal)) {
                                    ParseContext parentContext = context.getParentContext();
                                    if (parentContext.getObject() != null) {
                                        obj3 = (T) parentContext.getObject();
                                    } else {
                                        defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parentContext, stringVal));
                                        defaultJSONParser.setResolveStatus(1);
                                    }
                                } else if (Operators.DOLLAR_STR.equals(stringVal)) {
                                    ParseContext parseContext3 = context;
                                    while (parseContext3.getParentContext() != null) {
                                        parseContext3 = parseContext3.getParentContext();
                                    }
                                    if (parseContext3.getObject() != null) {
                                        obj3 = (T) parseContext3.getObject();
                                    } else {
                                        defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext3, stringVal));
                                        defaultJSONParser.setResolveStatus(1);
                                    }
                                } else {
                                    defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(context, stringVal));
                                    defaultJSONParser.setResolveStatus(1);
                                }
                                lexer.nextToken(13);
                                if (lexer.token() == 13) {
                                    lexer.nextToken(16);
                                    defaultJSONParser.setContext(context, obj3, obj);
                                    if (parseContext2 != null) {
                                        parseContext2.setObject(obj3);
                                    }
                                    defaultJSONParser.setContext(context);
                                    return (T) obj3;
                                }
                                throw new JSONException("illegal ref");
                            }
                            throw new JSONException("illegal ref, " + JSONToken.name(lexer.token()));
                        } else if (JSON.DEFAULT_TYPE_KEY == scanSymbol) {
                            lexer.nextTokenWithColon(4);
                            if (lexer.token() == 4) {
                                String stringVal2 = lexer.stringVal();
                                lexer.nextToken(16);
                                if (!(type instanceof Class) || !stringVal2.equals(((Class) type).getName())) {
                                    Type loadClass = TypeUtils.loadClass(stringVal2);
                                    T t3 = (T) defaultJSONParser.getConfig().getDeserializer(loadClass).deserialze(defaultJSONParser, loadClass, obj);
                                } else if (lexer.token() == 13) {
                                    lexer.nextToken();
                                    obj4 = obj3;
                                    break;
                                }
                            } else {
                                throw new JSONException("syntax error");
                            }
                        } else {
                            if (obj3 == null && hashMap == null) {
                                obj3 = (T) createInstance(defaultJSONParser, type);
                                if (obj3 == null) {
                                    hashMap = new HashMap(this.fieldDeserializers.size());
                                }
                                parseContext2 = defaultJSONParser.setContext(context, obj3, obj);
                            }
                            try {
                                if (!parseField(defaultJSONParser, scanSymbol, obj3, type, hashMap)) {
                                    if (lexer.token() == 13) {
                                        lexer.nextToken();
                                        break;
                                    }
                                    obj3 = (T) obj3;
                                    hashMap = hashMap;
                                    parseContext2 = parseContext2;
                                } else {
                                    if (lexer.token() != 16) {
                                        if (lexer.token() == 13) {
                                            lexer.nextToken(16);
                                            break;
                                        } else if (lexer.token() == 18 || lexer.token() == 1) {
                                        }
                                    }
                                    obj3 = (T) obj3;
                                    hashMap = hashMap;
                                    parseContext2 = parseContext2;
                                }
                            } catch (Throwable th2) {
                                th = th2;
                                obj3 = (T) obj3;
                                parseContext = parseContext2;
                                if (parseContext != null) {
                                    parseContext.setObject(obj3);
                                }
                                defaultJSONParser.setContext(context);
                                throw th;
                            }
                        }
                    } catch (Throwable th3) {
                        th = th3;
                        parseContext = parseContext2;
                        if (parseContext != null) {
                        }
                        defaultJSONParser.setContext(context);
                        throw th;
                    }
                }
                if (obj4 == null) {
                    if (hashMap == null) {
                        T t4 = (T) createInstance(defaultJSONParser, type);
                        if (parseContext2 == null) {
                            parseContext2 = defaultJSONParser.setContext(context, t4, obj);
                        }
                        if (parseContext2 != null) {
                            parseContext2.setObject(t4);
                        }
                        defaultJSONParser.setContext(context);
                        return t4;
                    }
                    List<FieldInfo> fieldList = this.beanInfo.getFieldList();
                    int size = fieldList.size();
                    Object[] objArr = new Object[size];
                    for (int i = 0; i < size; i++) {
                        objArr[i] = hashMap.get(fieldList.get(i).getName());
                    }
                    if (this.beanInfo.getCreatorConstructor() != null) {
                        try {
                            obj4 = (T) this.beanInfo.getCreatorConstructor().newInstance(objArr);
                        } catch (Exception e) {
                            throw new JSONException("create instance error, " + this.beanInfo.getCreatorConstructor().toGenericString(), e);
                        }
                    } else if (this.beanInfo.getFactoryMethod() != null) {
                        try {
                            obj4 = (T) this.beanInfo.getFactoryMethod().invoke(null, objArr);
                        } catch (Exception e2) {
                            throw new JSONException("create factory method error, " + this.beanInfo.getFactoryMethod().toString(), e2);
                        }
                    }
                }
                if (parseContext2 != null) {
                    parseContext2.setObject(obj4);
                }
                defaultJSONParser.setContext(context);
                return (T) obj4;
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("syntax error, expect {, actual ");
                stringBuffer.append(lexer.tokenName());
                stringBuffer.append(", pos ");
                stringBuffer.append(lexer.pos());
                if (obj instanceof String) {
                    stringBuffer.append(", fieldName ");
                    stringBuffer.append(obj);
                }
                throw new JSONException(stringBuffer.toString());
            }
        } catch (Throwable th4) {
            th = th4;
            obj3 = obj2;
            if (parseContext != null) {
            }
            defaultJSONParser.setContext(context);
            throw th;
        }
    }

    public boolean parseField(DefaultJSONParser defaultJSONParser, String str, Object obj, Type type, Map<String, Object> map) {
        JSONLexer lexer = defaultJSONParser.getLexer();
        FieldDeserializer fieldDeserializer = this.feildDeserializerMap.get(str);
        if (fieldDeserializer == null) {
            Iterator<Map.Entry<String, FieldDeserializer>> it = this.feildDeserializerMap.entrySet().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Map.Entry<String, FieldDeserializer> next = it.next();
                if (next.getKey().equalsIgnoreCase(str)) {
                    fieldDeserializer = next.getValue();
                    break;
                }
            }
        }
        if (fieldDeserializer == null) {
            parseExtra(defaultJSONParser, obj, str);
            return false;
        }
        lexer.nextTokenWithColon(fieldDeserializer.getFastMatchToken());
        fieldDeserializer.parseField(defaultJSONParser, obj, type, map);
        return true;
    }

    /* access modifiers changed from: package-private */
    public void parseExtra(DefaultJSONParser defaultJSONParser, Object obj, String str) {
        Object obj2;
        JSONLexer lexer = defaultJSONParser.getLexer();
        if (lexer.isEnabled(Feature.IgnoreNotMatch)) {
            lexer.nextTokenWithColon();
            Type extratype = FilterUtils.getExtratype(defaultJSONParser, obj, str);
            if (extratype == null) {
                obj2 = defaultJSONParser.parse();
            } else {
                obj2 = defaultJSONParser.parseObject(extratype);
            }
            FilterUtils.processExtra(defaultJSONParser, obj, str, obj2);
            return;
        }
        throw new JSONException("setter not found, class " + this.clazz.getName() + ", property " + str);
    }

    public final boolean isSupportArrayToBean(JSONLexer jSONLexer) {
        return Feature.isEnabled(this.beanInfo.getParserFeatures(), Feature.SupportArrayToBean) || jSONLexer.isEnabled(Feature.SupportArrayToBean);
    }
}
