package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.util.TypeUtils;
import java.lang.reflect.Array;
import java.lang.reflect.GenericArrayType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.ArrayList;

public class JavaObjectDeserializer implements ObjectDeserializer {
    public static final JavaObjectDeserializer instance = new JavaObjectDeserializer();

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 12;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        if (!(type instanceof GenericArrayType)) {
            return (T) defaultJSONParser.parse(obj);
        }
        Type genericComponentType = ((GenericArrayType) type).getGenericComponentType();
        if (genericComponentType instanceof TypeVariable) {
            genericComponentType = ((TypeVariable) genericComponentType).getBounds()[0];
        }
        ArrayList arrayList = new ArrayList();
        defaultJSONParser.parseArray(genericComponentType, arrayList);
        if (!(genericComponentType instanceof Class)) {
            return (T) arrayList.toArray();
        }
        Class cls = (Class) genericComponentType;
        if (cls == Boolean.TYPE) {
            return (T) TypeUtils.cast((Object) arrayList, boolean[].class, defaultJSONParser.getConfig());
        }
        if (cls == Short.TYPE) {
            return (T) TypeUtils.cast((Object) arrayList, short[].class, defaultJSONParser.getConfig());
        }
        if (cls == Integer.TYPE) {
            return (T) TypeUtils.cast((Object) arrayList, int[].class, defaultJSONParser.getConfig());
        }
        if (cls == Long.TYPE) {
            return (T) TypeUtils.cast((Object) arrayList, long[].class, defaultJSONParser.getConfig());
        }
        if (cls == Float.TYPE) {
            return (T) TypeUtils.cast((Object) arrayList, float[].class, defaultJSONParser.getConfig());
        }
        if (cls == Double.TYPE) {
            return (T) TypeUtils.cast((Object) arrayList, double[].class, defaultJSONParser.getConfig());
        }
        T t = (T) ((Object[]) Array.newInstance(cls, arrayList.size()));
        arrayList.toArray(t);
        return t;
    }
}
