package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.util.Base64;
import com.alibaba.fastjson.util.IOUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.IOException;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
import java.io.Writer;
import java.lang.ref.SoftReference;
import java.nio.charset.Charset;

public final class SerializeWriter extends Writer {
    private static final ThreadLocal<SoftReference<char[]>> bufLocal = new ThreadLocal<>();
    protected char[] buf;
    protected int count;
    private int features;
    private final Writer writer;

    public SerializeWriter() {
        this((Writer) null);
    }

    public SerializeWriter(Writer writer2) {
        this.writer = writer2;
        this.features = JSON.DEFAULT_GENERATE_FEATURE;
        ThreadLocal<SoftReference<char[]>> threadLocal = bufLocal;
        SoftReference<char[]> softReference = threadLocal.get();
        if (softReference != null) {
            this.buf = softReference.get();
            threadLocal.set(null);
        }
        if (this.buf == null) {
            this.buf = new char[1024];
        }
    }

    public SerializeWriter(SerializerFeature... serializerFeatureArr) {
        this((Writer) null, serializerFeatureArr);
    }

    public SerializeWriter(Writer writer2, SerializerFeature... serializerFeatureArr) {
        this.writer = writer2;
        ThreadLocal<SoftReference<char[]>> threadLocal = bufLocal;
        SoftReference<char[]> softReference = threadLocal.get();
        if (softReference != null) {
            this.buf = softReference.get();
            threadLocal.set(null);
        }
        if (this.buf == null) {
            this.buf = new char[1024];
        }
        int i = 0;
        for (SerializerFeature serializerFeature : serializerFeatureArr) {
            i |= serializerFeature.getMask();
        }
        this.features = i;
    }

    public int getBufferLength() {
        return this.buf.length;
    }

    public SerializeWriter(int i) {
        this((Writer) null, i);
    }

    public SerializeWriter(Writer writer2, int i) {
        this.writer = writer2;
        if (i > 0) {
            this.buf = new char[i];
            return;
        }
        throw new IllegalArgumentException("Negative initial size: " + i);
    }

    public void config(SerializerFeature serializerFeature, boolean z) {
        if (z) {
            this.features = serializerFeature.getMask() | this.features;
            return;
        }
        this.features = (serializerFeature.getMask() ^ -1) & this.features;
    }

    public boolean isEnabled(SerializerFeature serializerFeature) {
        return SerializerFeature.isEnabled(this.features, serializerFeature);
    }

    @Override // java.io.Writer
    public void write(int i) {
        int i2 = 1;
        int i3 = this.count + 1;
        if (i3 > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i3);
            } else {
                flush();
                this.buf[this.count] = (char) i;
                this.count = i2;
            }
        }
        i2 = i3;
        this.buf[this.count] = (char) i;
        this.count = i2;
    }

    public void write(char c) {
        int i = 1;
        int i2 = this.count + 1;
        if (i2 > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i2);
            } else {
                flush();
                this.buf[this.count] = c;
                this.count = i;
            }
        }
        i = i2;
        this.buf[this.count] = c;
        this.count = i;
    }

    @Override // java.io.Writer
    public void write(char[] cArr, int i, int i2) {
        int i3;
        if (i < 0 || i > cArr.length || i2 < 0 || (i3 = i + i2) > cArr.length || i3 < 0) {
            throw new IndexOutOfBoundsException();
        } else if (i2 != 0) {
            int i4 = this.count + i2;
            if (i4 > this.buf.length) {
                if (this.writer == null) {
                    expandCapacity(i4);
                } else {
                    do {
                        char[] cArr2 = this.buf;
                        int length = cArr2.length;
                        int i5 = this.count;
                        int i6 = length - i5;
                        System.arraycopy(cArr, i, cArr2, i5, i6);
                        this.count = this.buf.length;
                        flush();
                        i2 -= i6;
                        i += i6;
                    } while (i2 > this.buf.length);
                    i4 = i2;
                }
            }
            System.arraycopy(cArr, i, this.buf, this.count, i2);
            this.count = i4;
        }
    }

    public void expandCapacity(int i) {
        char[] cArr = this.buf;
        int length = ((cArr.length * 3) / 2) + 1;
        if (length >= i) {
            i = length;
        }
        char[] cArr2 = new char[i];
        System.arraycopy(cArr, 0, cArr2, 0, this.count);
        this.buf = cArr2;
    }

    @Override // java.io.Writer
    public void write(String str, int i, int i2) {
        int i3;
        int i4 = this.count + i2;
        if (i4 > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i4);
            } else {
                while (true) {
                    char[] cArr = this.buf;
                    int length = cArr.length;
                    int i5 = this.count;
                    int i6 = length - i5;
                    i3 = i + i6;
                    str.getChars(i, i3, cArr, i5);
                    this.count = this.buf.length;
                    flush();
                    i2 -= i6;
                    if (i2 <= this.buf.length) {
                        break;
                    }
                    i = i3;
                }
                i4 = i2;
                i = i3;
            }
        }
        str.getChars(i, i2 + i, this.buf, this.count);
        this.count = i4;
    }

    public void writeTo(Writer writer2) throws IOException {
        if (this.writer == null) {
            writer2.write(this.buf, 0, this.count);
            return;
        }
        throw new UnsupportedOperationException("writer not null");
    }

    public void writeTo(OutputStream outputStream, String str) throws IOException {
        writeTo(outputStream, Charset.forName(str));
    }

    public void writeTo(OutputStream outputStream, Charset charset) throws IOException {
        if (this.writer == null) {
            outputStream.write(new String(this.buf, 0, this.count).getBytes(charset.name()));
            return;
        }
        throw new UnsupportedOperationException("writer not null");
    }

    @Override // java.lang.Appendable, java.io.Writer, java.io.Writer
    public SerializeWriter append(CharSequence charSequence) {
        String obj = charSequence == null ? "null" : charSequence.toString();
        write(obj, 0, obj.length());
        return this;
    }

    @Override // java.lang.Appendable, java.io.Writer, java.io.Writer
    public SerializeWriter append(CharSequence charSequence, int i, int i2) {
        if (charSequence == null) {
            charSequence = "null";
        }
        String obj = charSequence.subSequence(i, i2).toString();
        write(obj, 0, obj.length());
        return this;
    }

    @Override // java.lang.Appendable, java.io.Writer, java.io.Writer
    public SerializeWriter append(char c) {
        write(c);
        return this;
    }

    public void reset() {
        this.count = 0;
    }

    public char[] toCharArray() {
        if (this.writer == null) {
            int i = this.count;
            char[] cArr = new char[i];
            System.arraycopy(this.buf, 0, cArr, 0, i);
            return cArr;
        }
        throw new UnsupportedOperationException("writer not null");
    }

    public byte[] toBytes(String str) {
        if (this.writer == null) {
            if (str == null) {
                str = "UTF-8";
            }
            try {
                return new String(this.buf, 0, this.count).getBytes(str);
            } catch (UnsupportedEncodingException e) {
                throw new JSONException("toBytes error", e);
            }
        } else {
            throw new UnsupportedOperationException("writer not null");
        }
    }

    public int size() {
        return this.count;
    }

    public String toString() {
        return new String(this.buf, 0, this.count);
    }

    @Override // java.io.Closeable, java.io.Writer, java.lang.AutoCloseable
    public void close() {
        if (this.writer != null && this.count > 0) {
            flush();
        }
        if (this.buf.length <= 8192) {
            bufLocal.set(new SoftReference<>(this.buf));
        }
        this.buf = null;
    }

    @Override // java.io.Writer
    public void write(String str) {
        if (str == null) {
            writeNull();
        } else {
            write(str, 0, str.length());
        }
    }

    public void writeInt(int i) {
        if (i == Integer.MIN_VALUE) {
            write("-2147483648");
            return;
        }
        int stringSize = i < 0 ? IOUtils.stringSize(-i) + 1 : IOUtils.stringSize(i);
        int i2 = this.count + stringSize;
        if (i2 > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i2);
            } else {
                char[] cArr = new char[stringSize];
                IOUtils.getChars((long) i, stringSize, cArr);
                write(cArr, 0, stringSize);
                return;
            }
        }
        IOUtils.getChars((long) i, i2, this.buf);
        this.count = i2;
    }

    public void writeByteArray(byte[] bArr) {
        int length = bArr.length;
        boolean isEnabled = isEnabled(SerializerFeature.UseSingleQuotes);
        char c = isEnabled ? Operators.SINGLE_QUOTE : Operators.QUOTE;
        if (length == 0) {
            write(isEnabled ? "''" : "\"\"");
            return;
        }
        char[] cArr = Base64.CA;
        int i = (length / 3) * 3;
        int i2 = length - 1;
        int i3 = this.count;
        int i4 = (((i2 / 3) + 1) << 2) + i3 + 2;
        int i5 = 0;
        if (i4 > this.buf.length) {
            if (this.writer != null) {
                write(c);
                int i6 = 0;
                while (i6 < i) {
                    int i7 = i6 + 1;
                    int i8 = i7 + 1;
                    int i9 = ((bArr[i6] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bArr[i7] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (bArr[i8] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
                    write(cArr[(i9 >>> 18) & 63]);
                    write(cArr[(i9 >>> 12) & 63]);
                    write(cArr[(i9 >>> 6) & 63]);
                    write(cArr[i9 & 63]);
                    i6 = i8 + 1;
                }
                int i10 = length - i;
                if (i10 > 0) {
                    int i11 = (bArr[i] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 10;
                    if (i10 == 2) {
                        i5 = (bArr[i2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 2;
                    }
                    int i12 = i11 | i5;
                    write(cArr[i12 >> 12]);
                    write(cArr[(i12 >>> 6) & 63]);
                    write(i10 == 2 ? cArr[i12 & 63] : '=');
                    write('=');
                }
                write(c);
                return;
            }
            expandCapacity(i4);
        }
        this.count = i4;
        int i13 = i3 + 1;
        this.buf[i3] = c;
        int i14 = 0;
        while (i14 < i) {
            int i15 = i14 + 1;
            int i16 = i15 + 1;
            int i17 = ((bArr[i14] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bArr[i15] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8);
            int i18 = i16 + 1;
            int i19 = i17 | (bArr[i16] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
            char[] cArr2 = this.buf;
            int i20 = i13 + 1;
            cArr2[i13] = cArr[(i19 >>> 18) & 63];
            int i21 = i20 + 1;
            cArr2[i20] = cArr[(i19 >>> 12) & 63];
            int i22 = i21 + 1;
            cArr2[i21] = cArr[(i19 >>> 6) & 63];
            i13 = i22 + 1;
            cArr2[i22] = cArr[i19 & 63];
            i14 = i18;
        }
        int i23 = length - i;
        if (i23 > 0) {
            int i24 = (bArr[i] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 10;
            if (i23 == 2) {
                i5 = (bArr[i2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 2;
            }
            int i25 = i24 | i5;
            char[] cArr3 = this.buf;
            cArr3[i4 - 5] = cArr[i25 >> 12];
            cArr3[i4 - 4] = cArr[(i25 >>> 6) & 63];
            cArr3[i4 - 3] = i23 == 2 ? cArr[i25 & 63] : '=';
            cArr3[i4 - 2] = '=';
        }
        this.buf[i4 - 1] = c;
    }

    public void writeLongAndChar(long j, char c) throws IOException {
        if (j == Long.MIN_VALUE) {
            write("-9223372036854775808");
            write(c);
            return;
        }
        int stringSize = this.count + (j < 0 ? IOUtils.stringSize(-j) + 1 : IOUtils.stringSize(j));
        int i = stringSize + 1;
        if (i > this.buf.length) {
            if (this.writer != null) {
                writeLong(j);
                write(c);
                return;
            }
            expandCapacity(i);
        }
        IOUtils.getChars(j, stringSize, this.buf);
        this.buf[stringSize] = c;
        this.count = i;
    }

    public void writeLong(long j) {
        if (j == Long.MIN_VALUE) {
            write("-9223372036854775808");
            return;
        }
        int stringSize = j < 0 ? IOUtils.stringSize(-j) + 1 : IOUtils.stringSize(j);
        int i = this.count + stringSize;
        if (i > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i);
            } else {
                char[] cArr = new char[stringSize];
                IOUtils.getChars(j, stringSize, cArr);
                write(cArr, 0, stringSize);
                return;
            }
        }
        IOUtils.getChars(j, i, this.buf);
        this.count = i;
    }

    public void writeNull() {
        write("null");
    }

    private void writeStringWithDoubleQuote(String str, char c) {
        writeStringWithDoubleQuote(str, c, true);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:103:0x0251, code lost:
        if (r8 == -1) goto L_0x0253;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:123:0x0284, code lost:
        if (r8 == -1) goto L_0x0253;
     */
    private void writeStringWithDoubleQuote(String str, char c, boolean z) {
        if (str == null) {
            writeNull();
            if (c != 0) {
                write(c);
                return;
            }
            return;
        }
        int length = str.length();
        int i = this.count + length + 2;
        if (c != 0) {
            i++;
        }
        char c2 = '\r';
        if (i > this.buf.length) {
            if (this.writer != null) {
                write(Operators.QUOTE);
                for (int i2 = 0; i2 < str.length(); i2++) {
                    char charAt = str.charAt(i2);
                    if (isEnabled(SerializerFeature.BrowserCompatible)) {
                        if (charAt == '\b' || charAt == '\f' || charAt == '\n' || charAt == '\r' || charAt == '\t' || charAt == '\"' || charAt == '/' || charAt == '\\') {
                            write('\\');
                            write(IOUtils.replaceChars[charAt]);
                        } else {
                            if (charAt < ' ') {
                                write('\\');
                                write('u');
                                write('0');
                                write('0');
                                int i3 = charAt * 2;
                                write(IOUtils.ASCII_CHARS[i3]);
                                write(IOUtils.ASCII_CHARS[i3 + 1]);
                            } else if (charAt >= 127) {
                                write('\\');
                                write('u');
                                write(IOUtils.DIGITS[(charAt >>> '\f') & 15]);
                                write(IOUtils.DIGITS[(charAt >>> '\b') & 15]);
                                write(IOUtils.DIGITS[(charAt >>> 4) & 15]);
                                write(IOUtils.DIGITS[charAt & 15]);
                            }
                        }
                    } else if ((charAt < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[charAt] != 0) || (charAt == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                        write('\\');
                        write(IOUtils.replaceChars[charAt]);
                    }
                    write(charAt);
                }
                write(Operators.QUOTE);
                if (c != 0) {
                    write(c);
                    return;
                }
                return;
            }
            expandCapacity(i);
        }
        int i4 = this.count;
        int i5 = i4 + 1;
        int i6 = i5 + length;
        char[] cArr = this.buf;
        cArr[i4] = Operators.QUOTE;
        char c3 = 0;
        str.getChars(0, length, cArr, i5);
        this.count = i;
        int i7 = -1;
        if (isEnabled(SerializerFeature.BrowserCompatible)) {
            for (int i8 = i5; i8 < i6; i8++) {
                char c4 = this.buf[i8];
                if (c4 == '\"' || c4 == '/' || c4 == '\\' || c4 == '\b' || c4 == '\f' || c4 == '\n' || c4 == '\r' || c4 == '\t') {
                    i++;
                } else if (c4 < ' ' || c4 >= 127) {
                    i += 5;
                }
                i7 = i8;
            }
            if (i > this.buf.length) {
                expandCapacity(i);
            }
            this.count = i;
            while (i7 >= i5) {
                char[] cArr2 = this.buf;
                char c5 = cArr2[i7];
                if (c5 == '\b' || c5 == '\f' || c5 == '\n' || c5 == c2 || c5 == '\t') {
                    int i9 = i7 + 1;
                    System.arraycopy(cArr2, i9, cArr2, i7 + 2, (i6 - i7) - 1);
                    char[] cArr3 = this.buf;
                    cArr3[i7] = '\\';
                    cArr3[i9] = IOUtils.replaceChars[c5];
                } else if (c5 == '\"' || c5 == '/' || c5 == '\\') {
                    int i10 = i7 + 1;
                    System.arraycopy(cArr2, i10, cArr2, i7 + 2, (i6 - i7) - 1);
                    char[] cArr4 = this.buf;
                    cArr4[i7] = '\\';
                    cArr4[i10] = c5;
                } else {
                    if (c5 < ' ') {
                        int i11 = i7 + 1;
                        System.arraycopy(cArr2, i11, cArr2, i7 + 6, (i6 - i7) - 1);
                        char[] cArr5 = this.buf;
                        cArr5[i7] = '\\';
                        cArr5[i11] = 'u';
                        cArr5[i7 + 2] = '0';
                        cArr5[i7 + 3] = '0';
                        int i12 = c5 * 2;
                        cArr5[i7 + 4] = IOUtils.ASCII_CHARS[i12];
                        this.buf[i7 + 5] = IOUtils.ASCII_CHARS[i12 + 1];
                    } else if (c5 >= 127) {
                        int i13 = i7 + 1;
                        System.arraycopy(cArr2, i13, cArr2, i7 + 6, (i6 - i7) - 1);
                        char[] cArr6 = this.buf;
                        cArr6[i7] = '\\';
                        cArr6[i13] = 'u';
                        cArr6[i7 + 2] = IOUtils.DIGITS[(c5 >>> '\f') & 15];
                        this.buf[i7 + 3] = IOUtils.DIGITS[(c5 >>> '\b') & 15];
                        this.buf[i7 + 4] = IOUtils.DIGITS[(c5 >>> 4) & 15];
                        this.buf[i7 + 5] = IOUtils.DIGITS[c5 & 15];
                    } else {
                        i7--;
                        c2 = '\r';
                    }
                    i6 += 5;
                    i7--;
                    c2 = '\r';
                }
                i6++;
                i7--;
                c2 = '\r';
            }
            if (c != 0) {
                char[] cArr7 = this.buf;
                int i14 = this.count;
                cArr7[i14 - 2] = Operators.QUOTE;
                cArr7[i14 - 1] = c;
                return;
            }
            this.buf[this.count - 1] = Operators.QUOTE;
            return;
        }
        if (z) {
            int i15 = -1;
            int i16 = -1;
            int i17 = 0;
            for (int i18 = i5; i18 < i6; i18++) {
                char c6 = this.buf[i18];
                if (c6 == 8232) {
                    i17++;
                    i += 4;
                } else if (c6 >= ']') {
                    if (c6 >= 127 && c6 <= 160) {
                        if (i15 == -1) {
                            i15 = i18;
                        }
                        i17++;
                        i += 4;
                        i16 = i18;
                        c3 = c6;
                    }
                } else if (isSpecial(c6, this.features)) {
                    i17++;
                    if (c6 < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[c6] == 4) {
                        i += 4;
                    }
                }
                i15 = i18;
                i16 = i15;
                c3 = c6;
            }
            if (i17 > 0) {
                int i19 = i + i17;
                if (i19 > this.buf.length) {
                    expandCapacity(i19);
                }
                this.count = i19;
                if (i17 == 1) {
                    if (c3 == 8232) {
                        int i20 = i16 + 1;
                        char[] cArr8 = this.buf;
                        System.arraycopy(cArr8, i20, cArr8, i16 + 6, (i6 - i16) - 1);
                        char[] cArr9 = this.buf;
                        cArr9[i16] = '\\';
                        cArr9[i20] = 'u';
                        int i21 = i20 + 1;
                        cArr9[i21] = '2';
                        int i22 = i21 + 1;
                        cArr9[i22] = '0';
                        int i23 = i22 + 1;
                        cArr9[i23] = '2';
                        cArr9[i23 + 1] = '8';
                    } else if (c3 >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[c3] != 4) {
                        int i24 = i16 + 1;
                        char[] cArr10 = this.buf;
                        System.arraycopy(cArr10, i24, cArr10, i16 + 2, (i6 - i16) - 1);
                        char[] cArr11 = this.buf;
                        cArr11[i16] = '\\';
                        cArr11[i24] = IOUtils.replaceChars[c3];
                    } else {
                        int i25 = i16 + 1;
                        char[] cArr12 = this.buf;
                        System.arraycopy(cArr12, i25, cArr12, i16 + 6, (i6 - i16) - 1);
                        char[] cArr13 = this.buf;
                        cArr13[i16] = '\\';
                        int i26 = i25 + 1;
                        cArr13[i25] = 'u';
                        int i27 = i26 + 1;
                        cArr13[i26] = IOUtils.DIGITS[(c3 >>> '\f') & 15];
                        int i28 = i27 + 1;
                        this.buf[i27] = IOUtils.DIGITS[(c3 >>> '\b') & 15];
                        this.buf[i28] = IOUtils.DIGITS[(c3 >>> 4) & 15];
                        this.buf[i28 + 1] = IOUtils.DIGITS[c3 & 15];
                    }
                } else if (i17 > 1) {
                    for (int i29 = i15 - i5; i29 < str.length(); i29++) {
                        char charAt2 = str.charAt(i29);
                        if (charAt2 >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[charAt2] == 0) {
                            if (charAt2 != '/' || !isEnabled(SerializerFeature.WriteSlashAsSpecial)) {
                                if (charAt2 == 8232) {
                                    char[] cArr14 = this.buf;
                                    int i30 = i15 + 1;
                                    cArr14[i15] = '\\';
                                    int i31 = i30 + 1;
                                    cArr14[i30] = 'u';
                                    int i32 = i31 + 1;
                                    cArr14[i31] = IOUtils.DIGITS[(charAt2 >>> '\f') & 15];
                                    int i33 = i32 + 1;
                                    this.buf[i32] = IOUtils.DIGITS[(charAt2 >>> '\b') & 15];
                                    int i34 = i33 + 1;
                                    this.buf[i33] = IOUtils.DIGITS[(charAt2 >>> 4) & 15];
                                    i15 = i34 + 1;
                                    this.buf[i34] = IOUtils.DIGITS[charAt2 & 15];
                                } else {
                                    this.buf[i15] = charAt2;
                                    i15++;
                                }
                            }
                        }
                        int i35 = i15 + 1;
                        this.buf[i15] = '\\';
                        if (IOUtils.specicalFlags_doubleQuotes[charAt2] == 4) {
                            char[] cArr15 = this.buf;
                            int i36 = i35 + 1;
                            cArr15[i35] = 'u';
                            int i37 = i36 + 1;
                            cArr15[i36] = IOUtils.DIGITS[(charAt2 >>> '\f') & 15];
                            int i38 = i37 + 1;
                            this.buf[i37] = IOUtils.DIGITS[(charAt2 >>> '\b') & 15];
                            int i39 = i38 + 1;
                            this.buf[i38] = IOUtils.DIGITS[(charAt2 >>> 4) & 15];
                            i15 = i39 + 1;
                            this.buf[i39] = IOUtils.DIGITS[charAt2 & 15];
                        } else {
                            i15 = i35 + 1;
                            this.buf[i35] = IOUtils.replaceChars[charAt2];
                        }
                    }
                }
            }
        }
        if (c != 0) {
            char[] cArr16 = this.buf;
            int i40 = this.count;
            cArr16[i40 - 2] = Operators.QUOTE;
            cArr16[i40 - 1] = c;
            return;
        }
        this.buf[this.count - 1] = Operators.QUOTE;
    }

    public void write(boolean z) {
        if (z) {
            write(AbsoluteConst.TRUE);
        } else {
            write(AbsoluteConst.FALSE);
        }
    }

    public void writeFieldValue(char c, String str, long j) {
        if (j == Long.MIN_VALUE || !isEnabled(SerializerFeature.QuoteFieldNames)) {
            writeFieldValue1(c, str, j);
            return;
        }
        char c2 = isEnabled(SerializerFeature.UseSingleQuotes) ? Operators.SINGLE_QUOTE : Operators.QUOTE;
        int stringSize = j < 0 ? IOUtils.stringSize(-j) + 1 : IOUtils.stringSize(j);
        int length = str.length();
        int i = this.count + length + 4 + stringSize;
        if (i > this.buf.length) {
            if (this.writer != null) {
                write(c);
                writeFieldName(str);
                writeLong(j);
                return;
            }
            expandCapacity(i);
        }
        int i2 = this.count;
        this.count = i;
        char[] cArr = this.buf;
        cArr[i2] = c;
        int i3 = i2 + length + 1;
        cArr[i2 + 1] = c2;
        str.getChars(0, length, cArr, i2 + 2);
        char[] cArr2 = this.buf;
        cArr2[i3 + 1] = c2;
        cArr2[i3 + 2] = Operators.CONDITION_IF_MIDDLE;
        IOUtils.getChars(j, this.count, cArr2);
    }

    public void writeFieldValue1(char c, String str, long j) {
        write(c);
        writeFieldName(str);
        writeLong(j);
    }

    public void writeFieldValue(char c, String str, String str2) {
        if (!isEnabled(SerializerFeature.QuoteFieldNames)) {
            write(c);
            writeFieldName(str);
            if (str2 == null) {
                writeNull();
            } else {
                writeString(str2);
            }
        } else if (isEnabled(SerializerFeature.UseSingleQuotes)) {
            write(c);
            writeFieldName(str);
            if (str2 == null) {
                writeNull();
            } else {
                writeString(str2);
            }
        } else if (isEnabled(SerializerFeature.BrowserCompatible)) {
            write(c);
            writeStringWithDoubleQuote(str, Operators.CONDITION_IF_MIDDLE);
            writeStringWithDoubleQuote(str2, 0);
        } else {
            writeFieldValueStringWithDoubleQuote(c, str, str2, true);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:25:0x0093, code lost:
        if (r11 == -1) goto L_0x0095;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:45:0x00c6, code lost:
        if (r11 == -1) goto L_0x0095;
     */
    private void writeFieldValueStringWithDoubleQuote(char c, String str, String str2, boolean z) {
        int i;
        int i2;
        int i3;
        int length = str.length();
        int i4 = this.count;
        if (str2 == null) {
            i2 = i4 + length + 8;
            i = 4;
        } else {
            i = str2.length();
            i2 = i4 + length + i + 6;
        }
        int i5 = 0;
        if (i2 > this.buf.length) {
            if (this.writer != null) {
                write(c);
                writeStringWithDoubleQuote(str, Operators.CONDITION_IF_MIDDLE, z);
                writeStringWithDoubleQuote(str2, 0, z);
                return;
            }
            expandCapacity(i2);
        }
        char[] cArr = this.buf;
        int i6 = this.count;
        cArr[i6] = c;
        int i7 = i6 + 2;
        int i8 = i7 + length;
        cArr[i6 + 1] = Operators.QUOTE;
        str.getChars(0, length, cArr, i7);
        this.count = i2;
        char[] cArr2 = this.buf;
        cArr2[i8] = Operators.QUOTE;
        int i9 = i8 + 1;
        int i10 = i9 + 1;
        cArr2[i9] = Operators.CONDITION_IF_MIDDLE;
        if (str2 == null) {
            int i11 = i10 + 1;
            cArr2[i10] = 'n';
            int i12 = i11 + 1;
            cArr2[i11] = 'u';
            cArr2[i12] = 'l';
            cArr2[i12 + 1] = 'l';
            return;
        }
        int i13 = i10 + 1;
        cArr2[i10] = Operators.QUOTE;
        int i14 = i13 + i;
        str2.getChars(0, i, cArr2, i13);
        if (z && !isEnabled(SerializerFeature.DisableCheckSpecialChar)) {
            char c2 = 0;
            int i15 = -1;
            int i16 = -1;
            for (int i17 = i13; i17 < i14; i17++) {
                char c3 = this.buf[i17];
                if (c3 == 8232) {
                    i5++;
                    i2 += 4;
                } else if (c3 >= ']') {
                    if (c3 >= 127 && c3 <= 160) {
                        if (i15 == -1) {
                            i15 = i17;
                        }
                        i5++;
                        i2 += 4;
                        i16 = i17;
                        c2 = c3;
                    }
                } else if (isSpecial(c3, this.features)) {
                    i5++;
                    if (c3 < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[c3] == 4) {
                        i2 += 4;
                    }
                }
                i15 = i17;
                i16 = i15;
                c2 = c3;
            }
            if (i5 > 0) {
                int i18 = i2 + i5;
                if (i18 > this.buf.length) {
                    expandCapacity(i18);
                }
                this.count = i18;
                if (i5 == 1) {
                    if (c2 == 8232) {
                        int i19 = i16 + 1;
                        char[] cArr3 = this.buf;
                        System.arraycopy(cArr3, i19, cArr3, i16 + 6, (i14 - i16) - 1);
                        char[] cArr4 = this.buf;
                        cArr4[i16] = '\\';
                        cArr4[i19] = 'u';
                        int i20 = i19 + 1;
                        cArr4[i20] = '2';
                        int i21 = i20 + 1;
                        cArr4[i21] = '0';
                        int i22 = i21 + 1;
                        cArr4[i22] = '2';
                        cArr4[i22 + 1] = '8';
                    } else if (c2 >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[c2] != 4) {
                        int i23 = i16 + 1;
                        char[] cArr5 = this.buf;
                        System.arraycopy(cArr5, i23, cArr5, i16 + 2, (i14 - i16) - 1);
                        char[] cArr6 = this.buf;
                        cArr6[i16] = '\\';
                        cArr6[i23] = IOUtils.replaceChars[c2];
                    } else {
                        int i24 = i16 + 1;
                        char[] cArr7 = this.buf;
                        System.arraycopy(cArr7, i24, cArr7, i16 + 6, (i14 - i16) - 1);
                        char[] cArr8 = this.buf;
                        cArr8[i16] = '\\';
                        int i25 = i24 + 1;
                        cArr8[i24] = 'u';
                        int i26 = i25 + 1;
                        cArr8[i25] = IOUtils.DIGITS[(c2 >>> '\f') & 15];
                        int i27 = i26 + 1;
                        this.buf[i26] = IOUtils.DIGITS[(c2 >>> '\b') & 15];
                        this.buf[i27] = IOUtils.DIGITS[(c2 >>> 4) & 15];
                        this.buf[i27 + 1] = IOUtils.DIGITS[c2 & 15];
                    }
                } else if (i5 > 1) {
                    for (int i28 = i15 - i13; i28 < str2.length(); i28++) {
                        char charAt = str2.charAt(i28);
                        if ((charAt < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[charAt] != 0) || (charAt == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                            int i29 = i15 + 1;
                            this.buf[i15] = '\\';
                            if (IOUtils.specicalFlags_doubleQuotes[charAt] == 4) {
                                char[] cArr9 = this.buf;
                                int i30 = i29 + 1;
                                cArr9[i29] = 'u';
                                int i31 = i30 + 1;
                                cArr9[i30] = IOUtils.DIGITS[(charAt >>> '\f') & 15];
                                int i32 = i31 + 1;
                                this.buf[i31] = IOUtils.DIGITS[(charAt >>> '\b') & 15];
                                int i33 = i32 + 1;
                                this.buf[i32] = IOUtils.DIGITS[(charAt >>> 4) & 15];
                                i3 = i33 + 1;
                                this.buf[i33] = IOUtils.DIGITS[charAt & 15];
                            } else {
                                i3 = i29 + 1;
                                this.buf[i29] = IOUtils.replaceChars[charAt];
                            }
                        } else if (charAt == 8232) {
                            char[] cArr10 = this.buf;
                            int i34 = i15 + 1;
                            cArr10[i15] = '\\';
                            int i35 = i34 + 1;
                            cArr10[i34] = 'u';
                            int i36 = i35 + 1;
                            cArr10[i35] = IOUtils.DIGITS[(charAt >>> '\f') & 15];
                            int i37 = i36 + 1;
                            this.buf[i36] = IOUtils.DIGITS[(charAt >>> '\b') & 15];
                            int i38 = i37 + 1;
                            this.buf[i37] = IOUtils.DIGITS[(charAt >>> 4) & 15];
                            i3 = i38 + 1;
                            this.buf[i38] = IOUtils.DIGITS[charAt & 15];
                        } else {
                            this.buf[i15] = charAt;
                            i15++;
                        }
                        i15 = i3;
                    }
                }
            }
        }
        this.buf[this.count - 1] = Operators.QUOTE;
    }

    static final boolean isSpecial(char c, int i) {
        if (c == ' ') {
            return false;
        }
        if (c == '/' && SerializerFeature.isEnabled(i, SerializerFeature.WriteSlashAsSpecial)) {
            return true;
        }
        if (c <= '#' || c == '\\') {
            return c <= 31 || c == '\\' || c == '\"';
        }
        return false;
    }

    public void writeString(String str) {
        if (isEnabled(SerializerFeature.UseSingleQuotes)) {
            writeStringWithSingleQuote(str);
        } else {
            writeStringWithDoubleQuote(str, 0);
        }
    }

    private void writeStringWithSingleQuote(String str) {
        int i = 0;
        if (str == null) {
            int i2 = this.count + 4;
            if (i2 > this.buf.length) {
                expandCapacity(i2);
            }
            "null".getChars(0, 4, this.buf, this.count);
            this.count = i2;
            return;
        }
        int length = str.length();
        int i3 = this.count + length + 2;
        if (i3 > this.buf.length) {
            if (this.writer != null) {
                write(Operators.SINGLE_QUOTE);
                while (i < str.length()) {
                    char charAt = str.charAt(i);
                    if (charAt <= '\r' || charAt == '\\' || charAt == '\'' || (charAt == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                        write('\\');
                        write(IOUtils.replaceChars[charAt]);
                    } else {
                        write(charAt);
                    }
                    i++;
                }
                write(Operators.SINGLE_QUOTE);
                return;
            }
            expandCapacity(i3);
        }
        int i4 = this.count;
        int i5 = i4 + 1;
        int i6 = i5 + length;
        char[] cArr = this.buf;
        cArr[i4] = Operators.SINGLE_QUOTE;
        str.getChars(0, length, cArr, i5);
        this.count = i3;
        int i7 = -1;
        char c = 0;
        for (int i8 = i5; i8 < i6; i8++) {
            char c2 = this.buf[i8];
            if (c2 <= '\r' || c2 == '\\' || c2 == '\'' || (c2 == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                i++;
                i7 = i8;
                c = c2;
            }
        }
        int i9 = i3 + i;
        if (i9 > this.buf.length) {
            expandCapacity(i9);
        }
        this.count = i9;
        if (i == 1) {
            char[] cArr2 = this.buf;
            int i10 = i7 + 1;
            System.arraycopy(cArr2, i10, cArr2, i7 + 2, (i6 - i7) - 1);
            char[] cArr3 = this.buf;
            cArr3[i7] = '\\';
            cArr3[i10] = IOUtils.replaceChars[c];
        } else if (i > 1) {
            char[] cArr4 = this.buf;
            int i11 = i7 + 1;
            System.arraycopy(cArr4, i11, cArr4, i7 + 2, (i6 - i7) - 1);
            char[] cArr5 = this.buf;
            cArr5[i7] = '\\';
            cArr5[i11] = IOUtils.replaceChars[c];
            int i12 = i6 + 1;
            for (int i13 = i11 - 2; i13 >= i5; i13--) {
                char c3 = this.buf[i13];
                if (c3 <= '\r' || c3 == '\\' || c3 == '\'' || (c3 == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                    char[] cArr6 = this.buf;
                    int i14 = i13 + 1;
                    System.arraycopy(cArr6, i14, cArr6, i13 + 2, (i12 - i13) - 1);
                    char[] cArr7 = this.buf;
                    cArr7[i13] = '\\';
                    cArr7[i14] = IOUtils.replaceChars[c3];
                    i12++;
                }
            }
        }
        this.buf[this.count - 1] = Operators.SINGLE_QUOTE;
    }

    public void writeFieldName(String str) {
        writeFieldName(str, false);
    }

    public void writeFieldName(String str, boolean z) {
        if (str == null) {
            write("null:");
        } else if (isEnabled(SerializerFeature.UseSingleQuotes)) {
            if (isEnabled(SerializerFeature.QuoteFieldNames)) {
                writeStringWithSingleQuote(str);
                write(Operators.CONDITION_IF_MIDDLE);
                return;
            }
            writeKeyWithSingleQuoteIfHasSpecial(str);
        } else if (isEnabled(SerializerFeature.QuoteFieldNames)) {
            writeStringWithDoubleQuote(str, Operators.CONDITION_IF_MIDDLE, z);
        } else {
            writeKeyWithDoubleQuoteIfHasSpecial(str);
        }
    }

    private void writeKeyWithDoubleQuoteIfHasSpecial(String str) {
        byte[] bArr = IOUtils.specicalFlags_doubleQuotes;
        int length = str.length();
        boolean z = true;
        int i = this.count + length + 1;
        int i2 = 0;
        if (i > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i);
            } else if (length == 0) {
                write(Operators.QUOTE);
                write(Operators.QUOTE);
                write(Operators.CONDITION_IF_MIDDLE);
                return;
            } else {
                int i3 = 0;
                while (true) {
                    if (i3 < length) {
                        char charAt = str.charAt(i3);
                        if (charAt < bArr.length && bArr[charAt] != 0) {
                            break;
                        }
                        i3++;
                    } else {
                        z = false;
                        break;
                    }
                }
                if (z) {
                    write(Operators.QUOTE);
                }
                while (i2 < length) {
                    char charAt2 = str.charAt(i2);
                    if (charAt2 >= bArr.length || bArr[charAt2] == 0) {
                        write(charAt2);
                    } else {
                        write('\\');
                        write(IOUtils.replaceChars[charAt2]);
                    }
                    i2++;
                }
                if (z) {
                    write(Operators.QUOTE);
                }
                write(Operators.CONDITION_IF_MIDDLE);
                return;
            }
        }
        if (length == 0) {
            int i4 = this.count;
            if (i4 + 3 > this.buf.length) {
                expandCapacity(i4 + 3);
            }
            char[] cArr = this.buf;
            int i5 = this.count;
            int i6 = i5 + 1;
            this.count = i6;
            cArr[i5] = Operators.QUOTE;
            int i7 = i6 + 1;
            this.count = i7;
            cArr[i6] = Operators.QUOTE;
            this.count = i7 + 1;
            cArr[i7] = Operators.CONDITION_IF_MIDDLE;
            return;
        }
        int i8 = this.count;
        int i9 = i8 + length;
        str.getChars(0, length, this.buf, i8);
        this.count = i;
        int i10 = i8;
        boolean z2 = false;
        while (i10 < i9) {
            char[] cArr2 = this.buf;
            char c = cArr2[i10];
            if (c < bArr.length && bArr[c] != 0) {
                if (!z2) {
                    i += 3;
                    if (i > cArr2.length) {
                        expandCapacity(i);
                    }
                    this.count = i;
                    char[] cArr3 = this.buf;
                    int i11 = i10 + 1;
                    System.arraycopy(cArr3, i11, cArr3, i10 + 3, (i9 - i10) - 1);
                    char[] cArr4 = this.buf;
                    System.arraycopy(cArr4, i2, cArr4, 1, i10);
                    char[] cArr5 = this.buf;
                    cArr5[i8] = Operators.QUOTE;
                    cArr5[i11] = '\\';
                    int i12 = i11 + 1;
                    cArr5[i12] = IOUtils.replaceChars[c];
                    i9 += 2;
                    this.buf[this.count - 2] = Operators.QUOTE;
                    i10 = i12;
                    z2 = true;
                } else {
                    i++;
                    if (i > cArr2.length) {
                        expandCapacity(i);
                    }
                    this.count = i;
                    char[] cArr6 = this.buf;
                    int i13 = i10 + 1;
                    System.arraycopy(cArr6, i13, cArr6, i10 + 2, i9 - i10);
                    char[] cArr7 = this.buf;
                    cArr7[i10] = '\\';
                    cArr7[i13] = IOUtils.replaceChars[c];
                    i9++;
                    i10 = i13;
                }
            }
            i10++;
            i2 = 0;
        }
        this.buf[this.count - 1] = Operators.CONDITION_IF_MIDDLE;
    }

    private void writeKeyWithSingleQuoteIfHasSpecial(String str) {
        byte[] bArr = IOUtils.specicalFlags_singleQuotes;
        int length = str.length();
        boolean z = true;
        int i = this.count + length + 1;
        int i2 = 0;
        if (i > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(i);
            } else if (length == 0) {
                write(Operators.SINGLE_QUOTE);
                write(Operators.SINGLE_QUOTE);
                write(Operators.CONDITION_IF_MIDDLE);
                return;
            } else {
                int i3 = 0;
                while (true) {
                    if (i3 < length) {
                        char charAt = str.charAt(i3);
                        if (charAt < bArr.length && bArr[charAt] != 0) {
                            break;
                        }
                        i3++;
                    } else {
                        z = false;
                        break;
                    }
                }
                if (z) {
                    write(Operators.SINGLE_QUOTE);
                }
                while (i2 < length) {
                    char charAt2 = str.charAt(i2);
                    if (charAt2 >= bArr.length || bArr[charAt2] == 0) {
                        write(charAt2);
                    } else {
                        write('\\');
                        write(IOUtils.replaceChars[charAt2]);
                    }
                    i2++;
                }
                if (z) {
                    write(Operators.SINGLE_QUOTE);
                }
                write(Operators.CONDITION_IF_MIDDLE);
                return;
            }
        }
        if (length == 0) {
            int i4 = this.count;
            if (i4 + 3 > this.buf.length) {
                expandCapacity(i4 + 3);
            }
            char[] cArr = this.buf;
            int i5 = this.count;
            int i6 = i5 + 1;
            this.count = i6;
            cArr[i5] = Operators.SINGLE_QUOTE;
            int i7 = i6 + 1;
            this.count = i7;
            cArr[i6] = Operators.SINGLE_QUOTE;
            this.count = i7 + 1;
            cArr[i7] = Operators.CONDITION_IF_MIDDLE;
            return;
        }
        int i8 = this.count;
        int i9 = i8 + length;
        str.getChars(0, length, this.buf, i8);
        this.count = i;
        int i10 = i8;
        boolean z2 = false;
        while (i10 < i9) {
            char[] cArr2 = this.buf;
            char c = cArr2[i10];
            if (c < bArr.length && bArr[c] != 0) {
                if (!z2) {
                    i += 3;
                    if (i > cArr2.length) {
                        expandCapacity(i);
                    }
                    this.count = i;
                    char[] cArr3 = this.buf;
                    int i11 = i10 + 1;
                    System.arraycopy(cArr3, i11, cArr3, i10 + 3, (i9 - i10) - 1);
                    char[] cArr4 = this.buf;
                    System.arraycopy(cArr4, i2, cArr4, 1, i10);
                    char[] cArr5 = this.buf;
                    cArr5[i8] = Operators.SINGLE_QUOTE;
                    cArr5[i11] = '\\';
                    int i12 = i11 + 1;
                    cArr5[i12] = IOUtils.replaceChars[c];
                    i9 += 2;
                    this.buf[this.count - 2] = Operators.SINGLE_QUOTE;
                    i10 = i12;
                    z2 = true;
                } else {
                    i++;
                    if (i > cArr2.length) {
                        expandCapacity(i);
                    }
                    this.count = i;
                    char[] cArr6 = this.buf;
                    int i13 = i10 + 1;
                    System.arraycopy(cArr6, i13, cArr6, i10 + 2, i9 - i10);
                    char[] cArr7 = this.buf;
                    cArr7[i10] = '\\';
                    cArr7[i13] = IOUtils.replaceChars[c];
                    i9++;
                    i10 = i13;
                }
            }
            i10++;
            i2 = 0;
        }
        this.buf[i - 1] = Operators.CONDITION_IF_MIDDLE;
    }

    @Override // java.io.Writer, java.io.Flushable
    public void flush() {
        Writer writer2 = this.writer;
        if (writer2 != null) {
            try {
                writer2.write(this.buf, 0, this.count);
                this.writer.flush();
                this.count = 0;
            } catch (IOException e) {
                throw new JSONException(e.getMessage(), e);
            }
        }
    }
}
