package com.alibaba.fastjson.util;

import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.annotation.JSONCreator;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.serializer.SerializerFeature;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;

public class DeserializeBeanInfo {
    private Constructor<?> creatorConstructor;
    private Constructor<?> defaultConstructor;
    private Method factoryMethod;
    private final List<FieldInfo> fieldList = new ArrayList();
    private int parserFeatures = 0;
    private final List<FieldInfo> sortedFieldList = new ArrayList();

    public DeserializeBeanInfo(Class<?> cls) {
        this.parserFeatures = TypeUtils.getParserFeatures(cls);
    }

    public Constructor<?> getDefaultConstructor() {
        return this.defaultConstructor;
    }

    public void setDefaultConstructor(Constructor<?> constructor) {
        this.defaultConstructor = constructor;
    }

    public Constructor<?> getCreatorConstructor() {
        return this.creatorConstructor;
    }

    public void setCreatorConstructor(Constructor<?> constructor) {
        this.creatorConstructor = constructor;
    }

    public Method getFactoryMethod() {
        return this.factoryMethod;
    }

    public void setFactoryMethod(Method method) {
        this.factoryMethod = method;
    }

    public List<FieldInfo> getFieldList() {
        return this.fieldList;
    }

    public List<FieldInfo> getSortedFieldList() {
        return this.sortedFieldList;
    }

    public boolean add(FieldInfo fieldInfo) {
        for (FieldInfo fieldInfo2 : this.fieldList) {
            if (fieldInfo2.getName().equals(fieldInfo.getName()) && (!fieldInfo2.isGetOnly() || fieldInfo.isGetOnly())) {
                return false;
            }
        }
        this.fieldList.add(fieldInfo);
        this.sortedFieldList.add(fieldInfo);
        Collections.sort(this.sortedFieldList);
        return true;
    }

    public static DeserializeBeanInfo computeSetters(Class<?> cls, Type type) {
        int i;
        int i2;
        String str;
        Method method;
        int i3;
        int i4;
        String str2;
        int i5;
        int i6;
        JSONField jSONField;
        JSONField jSONField2;
        JSONField jSONField3;
        DeserializeBeanInfo deserializeBeanInfo = new DeserializeBeanInfo(cls);
        Constructor<?> defaultConstructor2 = getDefaultConstructor(cls);
        if (defaultConstructor2 != null) {
            TypeUtils.setAccessible(defaultConstructor2);
            deserializeBeanInfo.setDefaultConstructor(defaultConstructor2);
        } else if (defaultConstructor2 == null && !cls.isInterface() && !Modifier.isAbstract(cls.getModifiers())) {
            Constructor<?> creatorConstructor2 = getCreatorConstructor(cls);
            if (creatorConstructor2 != null) {
                TypeUtils.setAccessible(creatorConstructor2);
                deserializeBeanInfo.setCreatorConstructor(creatorConstructor2);
                for (int i7 = 0; i7 < creatorConstructor2.getParameterTypes().length; i7++) {
                    Annotation[] annotationArr = creatorConstructor2.getParameterAnnotations()[i7];
                    int length = annotationArr.length;
                    int i8 = 0;
                    while (true) {
                        if (i8 >= length) {
                            jSONField3 = null;
                            break;
                        }
                        Annotation annotation = annotationArr[i8];
                        if (annotation instanceof JSONField) {
                            jSONField3 = (JSONField) annotation;
                            break;
                        }
                        i8++;
                    }
                    if (jSONField3 != null) {
                        deserializeBeanInfo.add(new FieldInfo(jSONField3.name(), cls, creatorConstructor2.getParameterTypes()[i7], creatorConstructor2.getGenericParameterTypes()[i7], TypeUtils.getField(cls, jSONField3.name()), jSONField3.ordinal(), SerializerFeature.of(jSONField3.serialzeFeatures())));
                    } else {
                        throw new JSONException("illegal json creator");
                    }
                }
                return deserializeBeanInfo;
            }
            Method factoryMethod2 = getFactoryMethod(cls);
            if (factoryMethod2 != null) {
                TypeUtils.setAccessible(factoryMethod2);
                deserializeBeanInfo.setFactoryMethod(factoryMethod2);
                for (int i9 = 0; i9 < factoryMethod2.getParameterTypes().length; i9++) {
                    Annotation[] annotationArr2 = factoryMethod2.getParameterAnnotations()[i9];
                    int length2 = annotationArr2.length;
                    int i10 = 0;
                    while (true) {
                        if (i10 >= length2) {
                            jSONField2 = null;
                            break;
                        }
                        Annotation annotation2 = annotationArr2[i10];
                        if (annotation2 instanceof JSONField) {
                            jSONField2 = (JSONField) annotation2;
                            break;
                        }
                        i10++;
                    }
                    if (jSONField2 != null) {
                        deserializeBeanInfo.add(new FieldInfo(jSONField2.name(), cls, factoryMethod2.getParameterTypes()[i9], factoryMethod2.getGenericParameterTypes()[i9], TypeUtils.getField(cls, jSONField2.name()), jSONField2.ordinal(), SerializerFeature.of(jSONField2.serialzeFeatures())));
                    } else {
                        throw new JSONException("illegal json creator");
                    }
                }
                return deserializeBeanInfo;
            }
            throw new JSONException("default constructor not found. " + cls);
        }
        Method[] methods = cls.getMethods();
        for (Method method2 : methods) {
            String name = method2.getName();
            if (name.length() >= 4 && !Modifier.isStatic(method2.getModifiers()) && ((method2.getReturnType().equals(Void.TYPE) || method2.getReturnType().equals(cls)) && method2.getParameterTypes().length == 1)) {
                JSONField jSONField4 = (JSONField) method2.getAnnotation(JSONField.class);
                if (jSONField4 == null) {
                    jSONField4 = TypeUtils.getSupperMethodAnnotation(cls, method2);
                }
                if (jSONField4 == null) {
                    method = method2;
                    i4 = 0;
                    i3 = 0;
                } else if (jSONField4.deserialize()) {
                    i4 = jSONField4.ordinal();
                    i3 = SerializerFeature.of(jSONField4.serialzeFeatures());
                    if (jSONField4.name().length() != 0) {
                        deserializeBeanInfo.add(new FieldInfo(jSONField4.name(), method2, (Field) null, cls, type, i4, i3));
                        TypeUtils.setAccessible(method2);
                    } else {
                        method = method2;
                    }
                }
                if (name.startsWith("set")) {
                    char charAt = name.charAt(3);
                    if (Character.isUpperCase(charAt)) {
                        str2 = TypeUtils.compatibleWithJavaBean ? TypeUtils.decapitalize(name.substring(3)) : Character.toLowerCase(name.charAt(3)) + name.substring(4);
                    } else if (charAt == '_') {
                        str2 = name.substring(4);
                    } else if (charAt == 'f') {
                        str2 = name.substring(3);
                    } else if (name.length() >= 5 && Character.isUpperCase(name.charAt(4))) {
                        str2 = TypeUtils.decapitalize(name.substring(3));
                    }
                    Field field = TypeUtils.getField(cls, str2);
                    if (field == null && method.getParameterTypes()[0] == Boolean.TYPE) {
                        field = TypeUtils.getField(cls, "is" + Character.toUpperCase(str2.charAt(0)) + str2.substring(1));
                    }
                    if (field == null || (jSONField = (JSONField) field.getAnnotation(JSONField.class)) == null) {
                        i6 = i4;
                        i5 = i3;
                    } else {
                        i6 = jSONField.ordinal();
                        i5 = SerializerFeature.of(jSONField.serialzeFeatures());
                        if (jSONField.name().length() != 0) {
                            deserializeBeanInfo.add(new FieldInfo(jSONField.name(), method, field, cls, type, i6, i5));
                        }
                    }
                    deserializeBeanInfo.add(new FieldInfo(str2, method, (Field) null, cls, type, i6, i5));
                    TypeUtils.setAccessible(method);
                }
            }
        }
        Field[] fields = cls.getFields();
        for (Field field2 : fields) {
            if (!Modifier.isStatic(field2.getModifiers())) {
                boolean z = false;
                for (FieldInfo fieldInfo : deserializeBeanInfo.getFieldList()) {
                    if (fieldInfo.getName().equals(field2.getName())) {
                        z = true;
                    }
                }
                if (!z) {
                    String name2 = field2.getName();
                    JSONField jSONField5 = (JSONField) field2.getAnnotation(JSONField.class);
                    if (jSONField5 != null) {
                        int ordinal = jSONField5.ordinal();
                        int of = SerializerFeature.of(jSONField5.serialzeFeatures());
                        if (jSONField5.name().length() != 0) {
                            name2 = jSONField5.name();
                        }
                        str = name2;
                        i2 = ordinal;
                        i = of;
                    } else {
                        str = name2;
                        i2 = 0;
                        i = 0;
                    }
                    deserializeBeanInfo.add(new FieldInfo(str, (Method) null, field2, cls, type, i2, i));
                }
            }
        }
        Method[] methods2 = cls.getMethods();
        for (Method method3 : methods2) {
            String name3 = method3.getName();
            if (name3.length() >= 4 && !Modifier.isStatic(method3.getModifiers()) && name3.startsWith("get") && Character.isUpperCase(name3.charAt(3)) && method3.getParameterTypes().length == 0 && (Collection.class.isAssignableFrom(method3.getReturnType()) || Map.class.isAssignableFrom(method3.getReturnType()))) {
                JSONField jSONField6 = (JSONField) method3.getAnnotation(JSONField.class);
                deserializeBeanInfo.add(new FieldInfo((jSONField6 == null || jSONField6.name().length() <= 0) ? Character.toLowerCase(name3.charAt(3)) + name3.substring(4) : jSONField6.name(), method3, (Field) null, cls, type));
                TypeUtils.setAccessible(method3);
            }
        }
        return deserializeBeanInfo;
    }

    public static Constructor<?> getDefaultConstructor(Class<?> cls) {
        Constructor<?> constructor = null;
        if (Modifier.isAbstract(cls.getModifiers())) {
            return null;
        }
        Constructor<?>[] declaredConstructors = cls.getDeclaredConstructors();
        int length = declaredConstructors.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            Constructor<?> constructor2 = declaredConstructors[i];
            if (constructor2.getParameterTypes().length == 0) {
                constructor = constructor2;
                break;
            }
            i++;
        }
        if (constructor != null || !cls.isMemberClass() || Modifier.isStatic(cls.getModifiers())) {
            return constructor;
        }
        Constructor<?>[] declaredConstructors2 = cls.getDeclaredConstructors();
        for (Constructor<?> constructor3 : declaredConstructors2) {
            if (constructor3.getParameterTypes().length == 1 && constructor3.getParameterTypes()[0].equals(cls.getDeclaringClass())) {
                return constructor3;
            }
        }
        return constructor;
    }

    public static Constructor<?> getCreatorConstructor(Class<?> cls) {
        Constructor<?>[] declaredConstructors = cls.getDeclaredConstructors();
        for (Constructor<?> constructor : declaredConstructors) {
            if (((JSONCreator) constructor.getAnnotation(JSONCreator.class)) != null) {
                return constructor;
            }
        }
        return null;
    }

    public static Method getFactoryMethod(Class<?> cls) {
        Method[] declaredMethods = cls.getDeclaredMethods();
        for (Method method : declaredMethods) {
            if (Modifier.isStatic(method.getModifiers()) && cls.isAssignableFrom(method.getReturnType()) && ((JSONCreator) method.getAnnotation(JSONCreator.class)) != null) {
                return method;
            }
        }
        return null;
    }

    public int getParserFeatures() {
        return this.parserFeatures;
    }
}
