package com.alibaba.fastjson.util;

import com.taobao.weex.el.parse.Operators;
import java.lang.annotation.Annotation;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.GenericArrayType;
import java.lang.reflect.GenericDeclaration;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;

public class FieldInfo implements Comparable<FieldInfo> {
    private final Class<?> declaringClass;
    private final Field field;
    private final Class<?> fieldClass;
    private final Type fieldType;
    private boolean getOnly;
    private final Method method;
    private final String name;
    private int ordinal;

    public FieldInfo(String str, Class<?> cls, Class<?> cls2, Type type, Field field2, int i, int i2) {
        this.ordinal = 0;
        this.getOnly = false;
        this.name = str;
        this.declaringClass = cls;
        this.fieldClass = cls2;
        this.fieldType = type;
        this.method = null;
        this.field = field2;
        this.ordinal = i;
        if (field2 != null) {
            TypeUtils.setAccessible(field2);
        }
    }

    public FieldInfo(String str, Method method2, Field field2) {
        this(str, method2, field2, (Class<?>) null, (Type) null);
    }

    public FieldInfo(String str, Method method2, Field field2, int i, int i2) {
        this(str, method2, field2, (Class<?>) null, (Type) null, i, i2);
    }

    public FieldInfo(String str, Method method2, Field field2, Class<?> cls, Type type) {
        this(str, method2, field2, cls, type, 0, 0);
    }

    public FieldInfo(String str, Method method2, Field field2, Class<?> cls, Type type, int i, int i2) {
        Type type2;
        Class<?> cls2;
        Type inheritGenericType;
        this.ordinal = 0;
        this.getOnly = false;
        this.name = str;
        this.method = method2;
        this.field = field2;
        this.ordinal = i;
        if (method2 != null) {
            TypeUtils.setAccessible(method2);
        }
        if (field2 != null) {
            TypeUtils.setAccessible(field2);
        }
        if (method2 != null) {
            if (method2.getParameterTypes().length == 1) {
                cls2 = method2.getParameterTypes()[0];
                type2 = method2.getGenericParameterTypes()[0];
            } else {
                cls2 = method2.getReturnType();
                Type genericReturnType = method2.getGenericReturnType();
                this.getOnly = true;
                type2 = genericReturnType;
            }
            this.declaringClass = method2.getDeclaringClass();
        } else {
            cls2 = field2.getType();
            Type genericType = field2.getGenericType();
            this.declaringClass = field2.getDeclaringClass();
            type2 = genericType;
        }
        if (cls == null || cls2 != Object.class || !(type2 instanceof TypeVariable) || (inheritGenericType = getInheritGenericType(cls, (TypeVariable) type2)) == null) {
            Type fieldType2 = getFieldType(cls, type, type2);
            if (fieldType2 != type2) {
                if (fieldType2 instanceof ParameterizedType) {
                    cls2 = TypeUtils.getClass(fieldType2);
                } else if (fieldType2 instanceof Class) {
                    cls2 = TypeUtils.getClass(fieldType2);
                }
            }
            this.fieldType = fieldType2;
            this.fieldClass = cls2;
            return;
        }
        this.fieldClass = TypeUtils.getClass(inheritGenericType);
        this.fieldType = inheritGenericType;
    }

    public static Type getFieldType(Class<?> cls, Type type, Type type2) {
        if (!(cls == null || type == null)) {
            if (type2 instanceof GenericArrayType) {
                Type genericComponentType = ((GenericArrayType) type2).getGenericComponentType();
                Type fieldType2 = getFieldType(cls, type, genericComponentType);
                return genericComponentType != fieldType2 ? Array.newInstance(TypeUtils.getClass(fieldType2), 0).getClass() : type2;
            } else if (!TypeUtils.isGenericParamType(type)) {
                return type2;
            } else {
                if (type2 instanceof TypeVariable) {
                    ParameterizedType parameterizedType = (ParameterizedType) TypeUtils.getGenericParamType(type);
                    Class<?> cls2 = TypeUtils.getClass(parameterizedType);
                    TypeVariable typeVariable = (TypeVariable) type2;
                    for (int i = 0; i < cls2.getTypeParameters().length; i++) {
                        if (cls2.getTypeParameters()[i].getName().equals(typeVariable.getName())) {
                            return parameterizedType.getActualTypeArguments()[i];
                        }
                    }
                }
                if (type2 instanceof ParameterizedType) {
                    ParameterizedType parameterizedType2 = (ParameterizedType) type2;
                    Type[] actualTypeArguments = parameterizedType2.getActualTypeArguments();
                    boolean z = false;
                    for (int i2 = 0; i2 < actualTypeArguments.length; i2++) {
                        Type type3 = actualTypeArguments[i2];
                        if (type3 instanceof TypeVariable) {
                            TypeVariable typeVariable2 = (TypeVariable) type3;
                            if (type instanceof ParameterizedType) {
                                ParameterizedType parameterizedType3 = (ParameterizedType) type;
                                for (int i3 = 0; i3 < cls.getTypeParameters().length; i3++) {
                                    if (cls.getTypeParameters()[i3].getName().equals(typeVariable2.getName())) {
                                        actualTypeArguments[i2] = parameterizedType3.getActualTypeArguments()[i3];
                                        z = true;
                                    }
                                }
                            }
                        }
                    }
                    if (z) {
                        return new ParameterizedTypeImpl(actualTypeArguments, parameterizedType2.getOwnerType(), parameterizedType2.getRawType());
                    }
                }
            }
        }
        return type2;
    }

    public static Type getInheritGenericType(Class<?> cls, TypeVariable<?> typeVariable) {
        GenericDeclaration genericDeclaration = typeVariable.getGenericDeclaration();
        while (true) {
            Type genericSuperclass = cls.getGenericSuperclass();
            if (genericSuperclass == null) {
                return null;
            }
            if (genericSuperclass instanceof ParameterizedType) {
                ParameterizedType parameterizedType = (ParameterizedType) genericSuperclass;
                if (parameterizedType.getRawType() == genericDeclaration) {
                    TypeVariable<?>[] typeParameters = genericDeclaration.getTypeParameters();
                    Type[] actualTypeArguments = parameterizedType.getActualTypeArguments();
                    for (int i = 0; i < typeParameters.length; i++) {
                        if (typeParameters[i] == typeVariable) {
                            return actualTypeArguments[i];
                        }
                    }
                    return null;
                }
            }
            Class<?> cls2 = TypeUtils.getClass(genericSuperclass);
            if (genericSuperclass == null) {
                return null;
            }
            cls = cls2;
        }
    }

    public String toString() {
        return this.name;
    }

    public Class<?> getDeclaringClass() {
        return this.declaringClass;
    }

    public Class<?> getFieldClass() {
        return this.fieldClass;
    }

    public Type getFieldType() {
        return this.fieldType;
    }

    public String getName() {
        return this.name;
    }

    public String gerQualifiedName() {
        Member member = getMember();
        return member.getDeclaringClass().getName() + Operators.DOT_STR + member.getName();
    }

    public Member getMember() {
        Method method2 = this.method;
        if (method2 != null) {
            return method2;
        }
        return this.field;
    }

    public Method getMethod() {
        return this.method;
    }

    public Field getField() {
        return this.field;
    }

    public int compareTo(FieldInfo fieldInfo) {
        int i = this.ordinal;
        int i2 = fieldInfo.ordinal;
        if (i < i2) {
            return -1;
        }
        if (i > i2) {
            return 1;
        }
        return this.name.compareTo(fieldInfo.name);
    }

    public <T extends Annotation> T getAnnotation(Class<T> cls) {
        Field field2;
        Method method2 = this.method;
        T t = method2 != null ? (T) method2.getAnnotation(cls) : null;
        return (t != null || (field2 = this.field) == null) ? t : (T) field2.getAnnotation(cls);
    }

    public Object get(Object obj) throws IllegalAccessException, InvocationTargetException {
        Method method2 = this.method;
        if (method2 != null) {
            return method2.invoke(obj, new Object[0]);
        }
        return this.field.get(obj);
    }

    public void set(Object obj, Object obj2) throws IllegalAccessException, InvocationTargetException {
        Method method2 = this.method;
        if (method2 != null) {
            method2.invoke(obj, obj2);
            return;
        }
        this.field.set(obj, obj2);
    }

    public void setAccessible(boolean z) throws SecurityException {
        Method method2 = this.method;
        if (method2 != null) {
            TypeUtils.setAccessible(method2);
        } else {
            TypeUtils.setAccessible(this.field);
        }
    }

    public boolean isGetOnly() {
        return this.getOnly;
    }
}
