package com.autonavi.base.ae.gmap.bean;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Typeface;
import android.text.Layout;
import android.text.StaticLayout;
import android.text.TextPaint;
import com.amap.api.col.p0003s.dl;
import com.amap.api.col.p0003s.p;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.autonavi.base.amap.mapcore.FileUtil;
import java.nio.ByteBuffer;

public class NativeTextGenerate {
    private static volatile NativeTextGenerate instance;
    private float density;
    private final int kTextAlignmentCenter;
    private final int kTextAlignmentLeft;
    private final int kTextAlignmentRight;
    private final int kTextLayoutLeftToRight;
    private final int kTextLayoutUpToDown;
    private TextPaint text_paint_bitmap;
    private TextPaint text_paint_size;

    public static NativeTextGenerate getInstance() {
        if (instance == null) {
            synchronized (NativeTextGenerate.class) {
                if (instance == null) {
                    instance = new NativeTextGenerate();
                }
            }
        }
        return instance;
    }

    private NativeTextGenerate() {
        this.text_paint_size = null;
        this.text_paint_bitmap = null;
        this.density = 1.0f;
        this.kTextLayoutLeftToRight = 0;
        this.kTextLayoutUpToDown = 1;
        this.kTextAlignmentCenter = 0;
        this.kTextAlignmentLeft = 1;
        this.kTextAlignmentRight = 2;
        this.text_paint_size = new TextPaint();
        this.text_paint_bitmap = new TextPaint();
    }

    public void setDensity(float f) {
        this.density = f;
    }

    private StaticLayout setPaintStyle(TextPaint textPaint, TextGenerateTextBitmap textGenerateTextBitmap, TextGenerateTextStyle textGenerateTextStyle, TextGeneratePOIStyleDesc textGeneratePOIStyleDesc) {
        if (textGenerateTextBitmap == null || textGenerateTextStyle == null || textGeneratePOIStyleDesc == null) {
            return null;
        }
        float f = ((float) textGeneratePOIStyleDesc.fontSize) * this.density;
        textPaint.setColor(textGeneratePOIStyleDesc.fontColor);
        textPaint.setTextSize(f);
        textPaint.setStyle(Paint.Style.FILL);
        int i = 1;
        textPaint.setAntiAlias(true);
        textPaint.setFilterBitmap(true);
        textPaint.setTypeface(textGeneratePOIStyleDesc.boldFont == 1 ? Typeface.DEFAULT_BOLD : Typeface.DEFAULT);
        int i2 = textGenerateTextStyle.textAlignment;
        if (i2 == 0) {
            textPaint.setTextAlign(Paint.Align.CENTER);
        } else if (i2 != 2) {
            textPaint.setTextAlign(Paint.Align.LEFT);
        } else {
            textPaint.setTextAlign(Paint.Align.RIGHT);
        }
        int length = textGenerateTextBitmap.text.length();
        int i3 = textGenerateTextStyle.singleLineCharaterLimit;
        if (length > textGenerateTextStyle.singleLineCharaterLimit || length % textGenerateTextStyle.singleLineCharaterLimit != 0) {
            int i4 = (length / textGenerateTextStyle.singleLineCharaterLimit) + 1;
            int i5 = length / i4;
            if (length % i4 <= 0) {
                i = 0;
            }
            i3 = i5 + i;
        }
        return new StaticLayout(textGenerateTextBitmap.text, textPaint, (int) (f * ((float) i3)), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false);
    }

    /* access modifiers changed from: package-private */
    public void calculateTextBoundSize(TextGenerateTextBitmap textGenerateTextBitmap, TextGenerateTextStyle textGenerateTextStyle, TextGeneratePOIStyleDesc textGeneratePOIStyleDesc) {
        if (textGenerateTextBitmap != null && textGenerateTextStyle != null && textGeneratePOIStyleDesc != null) {
            StaticLayout paintStyle = setPaintStyle(this.text_paint_size, textGenerateTextBitmap, textGenerateTextStyle, textGeneratePOIStyleDesc);
            float measureText = this.text_paint_size.measureText(textGenerateTextBitmap.text);
            Paint.FontMetrics fontMetrics = this.text_paint_size.getFontMetrics();
            textGenerateTextBitmap.width = (double) measureText;
            textGenerateTextBitmap.height = (double) (fontMetrics.descent - fontMetrics.ascent);
            textGenerateTextBitmap.width = (double) paintStyle.getWidth();
            textGenerateTextBitmap.height = (double) paintStyle.getHeight();
        }
    }

    /* access modifiers changed from: package-private */
    public void generateTextBitmap(TextGenerateTextBitmap textGenerateTextBitmap, TextGenerateTextStyle textGenerateTextStyle, TextGeneratePOIStyleDesc textGeneratePOIStyleDesc) {
        if (textGenerateTextBitmap != null && textGenerateTextStyle != null && textGeneratePOIStyleDesc != null) {
            StaticLayout paintStyle = setPaintStyle(this.text_paint_bitmap, textGenerateTextBitmap, textGenerateTextStyle, textGeneratePOIStyleDesc);
            Bitmap createBitmap = Bitmap.createBitmap((int) textGenerateTextBitmap.width, (int) textGenerateTextBitmap.height, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(createBitmap);
            if (textGenerateTextStyle.textAlignment == 0) {
                canvas.translate(((float) textGenerateTextBitmap.width) / 2.0f, 0.0f);
            } else if (textGenerateTextStyle.textAlignment == 2) {
                canvas.translate((float) textGenerateTextBitmap.width, 0.0f);
            }
            paintStyle.draw(canvas);
            this.text_paint_bitmap.setStyle(Paint.Style.STROKE);
            this.text_paint_bitmap.setStrokeWidth(1.0f);
            this.text_paint_bitmap.setColor(textGeneratePOIStyleDesc.fontBorderColor);
            paintStyle.draw(canvas);
            textGenerateTextBitmap.dataLength = (int) (textGenerateTextBitmap.width * textGenerateTextBitmap.height * 4.0d);
            textGenerateTextBitmap.data = new byte[textGenerateTextBitmap.dataLength];
            textGenerateTextBitmap.dataId = dl.b();
            createBitmap.copyPixelsToBuffer(ByteBuffer.wrap(textGenerateTextBitmap.data));
        }
    }

    /* access modifiers changed from: package-private */
    public BitmapDescriptor getIconBitmap(String str) {
        if (str == null) {
            return null;
        }
        try {
            Context context = p.a;
            byte[] uncompress = FileUtil.uncompress(FileUtil.readFileContentsFromAssetsByPreName(context, AMapEngineUtils.MAP_MAP_ASSETS_NAME, str + "_"));
            if (uncompress != null) {
                return BitmapDescriptorFactory.fromBitmap(BitmapFactory.decodeByteArray(uncompress, 0, uncompress.length));
            }
        } catch (Throwable th) {
            dl.a(th);
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    public byte[] getMapStyleJsonData() {
        try {
            return FileUtil.uncompress(FileUtil.readFileContentsFromAssets(p.a, "map_custom/terrain/terrainStyle.data"));
        } catch (Throwable th) {
            dl.a(th);
            return null;
        }
    }

    /* access modifiers changed from: package-private */
    public static class TextGenerateTextBitmap {
        byte[] data;
        public int dataId;
        int dataLength;
        double height;
        BitmapDescriptor imageData;
        String text;
        double width;

        TextGenerateTextBitmap() {
        }
    }

    /* access modifiers changed from: package-private */
    public static class TextGenerateTextStyle {
        int layoutDirection = 0;
        int singleLineCharaterLimit = 7;
        int textAlignment = 0;

        TextGenerateTextStyle() {
        }
    }

    /* access modifiers changed from: package-private */
    public static class TextGeneratePOIStyleDesc {
        int boldFont = 0;
        int fontBgColor = 0;
        int fontBorderColor = 0;
        int fontColor = 0;
        int fontSize = 0;

        TextGeneratePOIStyleDesc() {
        }
    }
}
