package com.autonavi.base.amap.mapcore;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import android.util.Pair;
import com.amap.api.col.p0003s.dl;
import com.amap.api.col.p0003s.dm;
import com.amap.api.col.p0003s.dn;
import com.amap.api.col.p0003s.il;
import com.amap.api.maps.MapsInitializer;
import com.autonavi.base.amap.mapcore.tools.GLFileUtil;
import io.dcloud.common.DHInterface.IApp;
import java.io.BufferedOutputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.zip.CRC32;
import java.util.zip.CheckedInputStream;
import java.util.zip.GZIPInputStream;
import java.util.zip.GZIPOutputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

public class FileUtil {
    private static final int BUFFER = 1024;
    private static final String FILE_PATH_ENTRY_BACK = "..";
    private static final String FILE_PATH_ENTRY_SEPARATOR1 = "\\";
    private static final String FILE_PATH_ENTRY_SEPARATOR2 = "%";
    private static final String TAG = "FileUtil";
    private static final char UNIX_SEPARATOR = '/';
    private static final char WINDOWS_SEPARATOR = '\\';

    public static class UnZipFileBrake {
        public boolean mIsAborted = false;
    }

    public interface ZipCompressProgressListener {
        void onFinishProgress(long j);
    }

    public static void createNoMediaFileIfNotExist(String str) {
    }

    public static boolean deleteFile(File file) {
        File[] listFiles;
        if (file == null || !file.exists()) {
            return false;
        }
        if (file.isDirectory() && (listFiles = file.listFiles()) != null) {
            for (int i = 0; i < listFiles.length; i++) {
                if (listFiles[i].isFile()) {
                    if (!listFiles[i].delete()) {
                        return false;
                    }
                } else if (!deleteFile(listFiles[i])) {
                    return false;
                } else {
                    listFiles[i].delete();
                }
            }
        }
        file.delete();
        return true;
    }

    public static String getMapBaseStorage(Context context) {
        String str = null;
        if (context == null) {
            return null;
        }
        String str2 = Build.VERSION.SDK_INT > 18 ? "map_base_path_v44" : "map_base_path";
        SharedPreferences sharedPreferences = context.getSharedPreferences("base_path", 0);
        if (MapsInitializer.sdcardDir == null || MapsInitializer.sdcardDir.trim().length() <= 0) {
            String string = sharedPreferences.getString(str2, "");
            String externalStroragePath = getExternalStroragePath(context);
            if (string == null || string.contains(externalStroragePath)) {
                str = string;
            }
        } else {
            str = MapsInitializer.sdcardDir + File.separatorChar;
        }
        if (str != null && str.length() > 2) {
            File file = new File(str);
            if (!file.exists()) {
                file.mkdir();
            }
            if (file.isDirectory()) {
                if (checkCanWrite(file)) {
                    return str;
                }
                String str3 = context.getCacheDir().toString() + AeUtil.ROOTPATH;
                if (str3 != null && str3.length() > 2) {
                    File file2 = new File(str3);
                    if (!file2.exists()) {
                        file2.mkdir();
                    }
                    if (file2.isDirectory()) {
                        return str3;
                    }
                }
            }
        }
        String str4 = getExternalStroragePath(context) + AeUtil.ROOTPATH;
        if (str4 != null && str4.length() > 2) {
            File file3 = new File(str4);
            if (!file3.exists()) {
                file3.mkdir();
            }
            if (file3.isDirectory() && file3.canWrite()) {
                SharedPreferences.Editor edit = sharedPreferences.edit();
                edit.putString(str2, str4);
                edit.commit();
                createNoMediaFileIfNotExist(str4);
                return str4;
            }
        }
        String str5 = context.getCacheDir().toString() + AeUtil.ROOTPATH;
        if (str5 != null && str5.length() > 2) {
            File file4 = new File(str5);
            if (!file4.exists()) {
                file4.mkdir();
            }
            if (file4.isDirectory()) {
            }
        }
        return str5;
    }

    public static boolean checkCanWrite(File file) {
        if (file == null || !file.canWrite()) {
            return false;
        }
        File file2 = new File(file, "amap.tmp");
        try {
            file2.createNewFile();
            if (!file2.exists()) {
                return false;
            }
            try {
                file2.delete();
                return true;
            } catch (Exception e) {
                e.printStackTrace();
                return false;
            }
        } catch (IOException e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public static String getExternalStroragePath(Context context) {
        if (context == null) {
            return null;
        }
        return context.getExternalFilesDir("").getAbsolutePath() + File.separatorChar;
    }

    public static void writeDatasToFile(String str, byte[] bArr) {
        Throwable th;
        Exception e;
        ReentrantReadWriteLock.WriteLock writeLock = new ReentrantReadWriteLock().writeLock();
        writeLock.lock();
        FileOutputStream fileOutputStream = null;
        if (bArr != null) {
            try {
                if (bArr.length != 0) {
                    File file = new File(str);
                    if (file.exists()) {
                        file.delete();
                    }
                    file.createNewFile();
                    FileOutputStream fileOutputStream2 = new FileOutputStream(file);
                    try {
                        fileOutputStream2.write(bArr);
                        fileOutputStream2.flush();
                        writeLock.unlock();
                        safelyCloseFile(fileOutputStream2);
                        return;
                    } catch (Exception e2) {
                        fileOutputStream = fileOutputStream2;
                        e = e2;
                        try {
                            e.printStackTrace();
                            writeLock.unlock();
                            safelyCloseFile(fileOutputStream);
                            return;
                        } catch (Throwable th2) {
                            th = th2;
                            writeLock.unlock();
                            safelyCloseFile(fileOutputStream);
                            throw th;
                        }
                    } catch (Throwable th3) {
                        fileOutputStream = fileOutputStream2;
                        th = th3;
                        writeLock.unlock();
                        safelyCloseFile(fileOutputStream);
                        throw th;
                    }
                }
            } catch (Exception e3) {
                e = e3;
                e.printStackTrace();
                writeLock.unlock();
                safelyCloseFile(fileOutputStream);
                return;
            }
        }
        writeLock.unlock();
        safelyCloseFile((OutputStream) null);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r6v1, types: [java.io.InputStream] */
    /* JADX WARN: Type inference failed for: r6v2 */
    /* JADX WARN: Type inference failed for: r6v4, types: [java.io.FileInputStream, java.io.InputStream] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public static byte[] readFileContents(String str) {
        ?? r6;
        ByteArrayOutputStream byteArrayOutputStream;
        Throwable th;
        try {
            File file = new File(str);
            if (!file.exists()) {
                safelyCloseFile((OutputStream) null);
                safelyCloseFile((InputStream) null);
                return null;
            }
            r6 = new FileInputStream(file);
            try {
                byte[] bArr = new byte[1024];
                ByteArrayOutputStream byteArrayOutputStream2 = new ByteArrayOutputStream();
                while (true) {
                    try {
                        int read = r6.read(bArr);
                        if (read != -1) {
                            byteArrayOutputStream2.write(bArr, 0, read);
                        } else {
                            byte[] byteArray = byteArrayOutputStream2.toByteArray();
                            safelyCloseFile(byteArrayOutputStream2);
                            safelyCloseFile((InputStream) r6);
                            return byteArray;
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        byteArrayOutputStream = byteArrayOutputStream2;
                        try {
                            il.c(th, TAG, "readFileContents");
                            dl.a(th);
                            dn.b(dm.f, "read file from disk failed " + th.getMessage());
                            return null;
                        } finally {
                            safelyCloseFile(byteArrayOutputStream);
                            safelyCloseFile((InputStream) r6);
                        }
                    }
                }
            } catch (Throwable th3) {
                th = th3;
                byteArrayOutputStream = null;
                il.c(th, TAG, "readFileContents");
                dl.a(th);
                dn.b(dm.f, "read file from disk failed " + th.getMessage());
                return null;
            }
        } catch (Throwable th4) {
            th = th4;
            r6 = null;
            byteArrayOutputStream = r6;
            il.c(th, TAG, "readFileContents");
            dl.a(th);
            dn.b(dm.f, "read file from disk failed " + th.getMessage());
            return null;
        }
    }

    public static void saveFileContents(String str, byte[] bArr) {
        Throwable th;
        FileOutputStream fileOutputStream = null;
        try {
            FileOutputStream fileOutputStream2 = new FileOutputStream(new File(str));
            try {
                fileOutputStream2.write(bArr);
                safelyCloseFile(fileOutputStream2);
            } catch (Throwable th2) {
                th = th2;
                fileOutputStream = fileOutputStream2;
                try {
                    il.c(th, TAG, "saveFileContents");
                    dl.a(th);
                    String str2 = dm.f;
                    dn.b(str2, "save file from disk failed " + th.getMessage());
                } finally {
                    safelyCloseFile(fileOutputStream);
                }
            }
        } catch (Throwable th3) {
            th = th3;
            il.c(th, TAG, "saveFileContents");
            dl.a(th);
            String str22 = dm.f;
            dn.b(str22, "save file from disk failed " + th.getMessage());
        }
    }

    public static byte[] readFileContentsFromAssetsByPreName(Context context, String str, String str2) {
        if (!(context == null || str == null || str2 == null)) {
            try {
                String[] list = context.getAssets().list(str);
                if (list == null) {
                    return null;
                }
                for (String str3 : list) {
                    if (str3 != null && str3.contains(str2)) {
                        return readFileContentsFromAssets(context, str + "/" + str3);
                    }
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return null;
    }

    public static byte[] readFileContentsFromAssets(Context context, String str) {
        Throwable th;
        IOException e;
        InputStream inputStream;
        OutOfMemoryError e2;
        InputStream inputStream2 = null;
        try {
            inputStream = context.getAssets().open(str);
            try {
                int available = inputStream.available();
                if (available == 0) {
                    safelyCloseFile(inputStream);
                    return null;
                }
                byte[] bArr = new byte[available];
                for (int i = 0; i < available; i += inputStream.read(bArr, i, available - i)) {
                }
                safelyCloseFile(inputStream);
                return bArr;
            } catch (IOException e3) {
                e = e3;
                dn.b(dm.f, "read file from assets failed " + e.getMessage());
                safelyCloseFile(inputStream);
                return null;
            } catch (OutOfMemoryError e4) {
                e2 = e4;
                try {
                    dn.b(dm.f, "read file from assets failed " + e2.getMessage());
                    safelyCloseFile(inputStream);
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    inputStream2 = inputStream;
                    safelyCloseFile(inputStream2);
                    throw th;
                }
            }
        } catch (IOException e5) {
            e = e5;
            inputStream = null;
            dn.b(dm.f, "read file from assets failed " + e.getMessage());
            safelyCloseFile(inputStream);
            return null;
        } catch (OutOfMemoryError e6) {
            e2 = e6;
            inputStream = null;
            dn.b(dm.f, "read file from assets failed " + e2.getMessage());
            safelyCloseFile(inputStream);
            return null;
        } catch (Throwable th3) {
            th = th3;
            safelyCloseFile(inputStream2);
            throw th;
        }
    }

    public static String getName(String str) {
        if (str == null) {
            return null;
        }
        return str.substring(indexOfLastSeparator(str) + 1);
    }

    public static int indexOfLastSeparator(String str) {
        if (str == null) {
            return -1;
        }
        return Math.max(str.lastIndexOf(47), str.lastIndexOf(92));
    }

    public static boolean isSafeEntryName(String str) {
        return !str.contains("..") && !str.contains(FILE_PATH_ENTRY_SEPARATOR1) && !str.contains("%");
    }

    public static byte[] compress(String str, String str2) {
        Throwable th;
        IOException e;
        GZIPOutputStream gZIPOutputStream = null;
        if (str == null || str.length() == 0) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            GZIPOutputStream gZIPOutputStream2 = new GZIPOutputStream(byteArrayOutputStream);
            try {
                gZIPOutputStream2.write(str.getBytes(str2));
                gZIPOutputStream2.close();
                safelyCloseFile(gZIPOutputStream2);
            } catch (IOException e2) {
                e = e2;
                gZIPOutputStream = gZIPOutputStream2;
                try {
                    Log.e("gzip compress error.", e.getMessage());
                    safelyCloseFile(gZIPOutputStream);
                    return byteArrayOutputStream.toByteArray();
                } catch (Throwable th2) {
                    th = th2;
                    safelyCloseFile(gZIPOutputStream);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                gZIPOutputStream = gZIPOutputStream2;
                safelyCloseFile(gZIPOutputStream);
                throw th;
            }
        } catch (IOException e3) {
            e = e3;
            Log.e("gzip compress error.", e.getMessage());
            safelyCloseFile(gZIPOutputStream);
            return byteArrayOutputStream.toByteArray();
        }
        return byteArrayOutputStream.toByteArray();
    }

    public static byte[] compress(byte[] bArr) {
        Throwable th;
        IOException e;
        GZIPOutputStream gZIPOutputStream = null;
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            GZIPOutputStream gZIPOutputStream2 = new GZIPOutputStream(byteArrayOutputStream);
            try {
                gZIPOutputStream2.write(bArr);
                gZIPOutputStream2.close();
                safelyCloseFile(gZIPOutputStream2);
            } catch (IOException e2) {
                e = e2;
                gZIPOutputStream = gZIPOutputStream2;
                try {
                    Log.e("gzip compress error.", e.getMessage());
                    safelyCloseFile(gZIPOutputStream);
                    return byteArrayOutputStream.toByteArray();
                } catch (Throwable th2) {
                    th = th2;
                    safelyCloseFile(gZIPOutputStream);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                gZIPOutputStream = gZIPOutputStream2;
                safelyCloseFile(gZIPOutputStream);
                throw th;
            }
        } catch (IOException e3) {
            e = e3;
            Log.e("gzip compress error.", e.getMessage());
            safelyCloseFile(gZIPOutputStream);
            return byteArrayOutputStream.toByteArray();
        }
        return byteArrayOutputStream.toByteArray();
    }

    public static String uncompressToString(byte[] bArr) {
        return uncompressToString(bArr, "UTF-8");
    }

    public static String uncompressToString(byte[] bArr, String str) {
        Throwable th;
        IOException e;
        InputStream inputStream;
        InputStream inputStream2 = null;
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            inputStream = getZipInputStream(bArr);
            if (inputStream != null) {
                try {
                    byte[] bArr2 = new byte[256];
                    while (true) {
                        int read = inputStream.read(bArr2);
                        if (read >= 0) {
                            byteArrayOutputStream.write(bArr2, 0, read);
                        } else {
                            String byteArrayOutputStream2 = byteArrayOutputStream.toString(str);
                            safelyCloseFile(inputStream);
                            return byteArrayOutputStream2;
                        }
                    }
                } catch (IOException e2) {
                    e = e2;
                    try {
                        Log.e("gzip compress error.", e.getMessage());
                        safelyCloseFile(inputStream);
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        inputStream2 = inputStream;
                    }
                }
            }
        } catch (IOException e3) {
            e = e3;
            inputStream = null;
            Log.e("gzip compress error.", e.getMessage());
            safelyCloseFile(inputStream);
            return null;
        } catch (Throwable th3) {
            th = th3;
            safelyCloseFile(inputStream2);
            throw th;
        }
        safelyCloseFile(inputStream);
        return null;
    }

    private static InputStream getZipInputStream(byte[] bArr) throws IOException {
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bArr);
        if (isGzip(bArr)) {
            return new GZIPInputStream(byteArrayInputStream);
        }
        return new ZipInputStream(byteArrayInputStream);
    }

    private static void safelyCloseFile(InputStream inputStream) {
        if (inputStream != null) {
            try {
                if (inputStream instanceof ZipInputStream) {
                    ((ZipInputStream) inputStream).closeEntry();
                }
                inputStream.close();
            } catch (Throwable unused) {
            }
        }
    }

    private static void safelyCloseFile(OutputStream outputStream) {
        if (outputStream != null) {
            try {
                outputStream.close();
            } catch (Throwable unused) {
            }
        }
    }

    private static byte[] readByteByStream(InputStream inputStream) throws IOException {
        if (inputStream == null) {
            return null;
        }
        byte[] bArr = new byte[1024];
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        while (true) {
            try {
                int read = inputStream.read(bArr);
                if (read != -1) {
                    byteArrayOutputStream.write(bArr, 0, read);
                } else {
                    byte[] byteArray = byteArrayOutputStream.toByteArray();
                    safelyCloseFile(byteArrayOutputStream);
                    return byteArray;
                }
            } catch (IOException e) {
                throw e;
            } catch (Throwable th) {
                safelyCloseFile(byteArrayOutputStream);
                throw th;
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v1, types: [java.util.Map<java.lang.String, byte[]>] */
    /* JADX WARN: Type inference failed for: r2v2, types: [java.io.InputStream] */
    /* JADX WARN: Type inference failed for: r2v3 */
    /* JADX WARNING: Unknown variable types count: 1 */
    public static Map<String, byte[]> uncompressToByteWithKeys(byte[] bArr, String[] strArr) {
        Throwable th;
        HashMap hashMap = new HashMap();
        if (bArr == null || bArr.length == 0) {
            return hashMap;
        }
        ?? r2 = 0;
        try {
            InputStream zipInputStream = getZipInputStream(bArr);
            try {
                if (zipInputStream instanceof ZipInputStream) {
                    ZipInputStream zipInputStream2 = (ZipInputStream) zipInputStream;
                    while (true) {
                        ZipEntry nextEntry = zipInputStream2.getNextEntry();
                        if (nextEntry == null) {
                            break;
                        }
                        if (!nextEntry.isDirectory()) {
                            try {
                                String name = nextEntry.getName();
                                if (isSafeEntryName(name)) {
                                    if (strArr != null) {
                                        int length = strArr.length;
                                        int i = 0;
                                        while (true) {
                                            if (i >= length) {
                                                break;
                                            }
                                            String str = strArr[i];
                                            if (name.equals(str)) {
                                                byte[] readByteByStream = readByteByStream(zipInputStream2);
                                                if (readByteByStream != null) {
                                                    hashMap.put(str, readByteByStream);
                                                }
                                            } else {
                                                i++;
                                            }
                                        }
                                    } else {
                                        byte[] readByteByStream2 = readByteByStream(zipInputStream2);
                                        if (readByteByStream2 != null) {
                                            hashMap.put(name, readByteByStream2);
                                        }
                                    }
                                } else {
                                    Log.e("gzip compress error.", "gzip name contains ../ ".concat(String.valueOf(name)));
                                    safelyCloseFile(zipInputStream);
                                    return r2;
                                }
                            } catch (IOException e) {
                                e.printStackTrace();
                            }
                        }
                        zipInputStream2.closeEntry();
                    }
                }
                safelyCloseFile(zipInputStream);
            } catch (Throwable th2) {
                th = th2;
                r2 = zipInputStream;
                try {
                    Log.e("gzip compress error.", th.getMessage());
                    return hashMap;
                } finally {
                    safelyCloseFile((InputStream) r2);
                }
            }
        } catch (Throwable th3) {
            th = th3;
            Log.e("gzip compress error.", th.getMessage());
            return hashMap;
        }
        return hashMap;
    }

    public static Pair<String, byte[]> uncompressToByte(byte[] bArr) {
        InputStream inputStream;
        Throwable th;
        String str;
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            inputStream = getZipInputStream(bArr);
            try {
                if (inputStream instanceof ZipInputStream) {
                    str = ((ZipInputStream) inputStream).getNextEntry().getName();
                    if (!isSafeEntryName(str)) {
                        Log.e("gzip compress error.", "gzip name contains ../ ".concat(String.valueOf(str)));
                        safelyCloseFile(inputStream);
                        return null;
                    }
                } else {
                    str = "";
                }
                if (inputStream != null) {
                    byte[] bArr2 = new byte[256];
                    while (true) {
                        int read = inputStream.read(bArr2);
                        if (read >= 0) {
                            byteArrayOutputStream.write(bArr2, 0, read);
                        } else {
                            Pair<String, byte[]> pair = new Pair<>(str, byteArrayOutputStream.toByteArray());
                            safelyCloseFile(inputStream);
                            return pair;
                        }
                    }
                }
            } catch (Throwable th2) {
                th = th2;
                try {
                    Log.e("gzip compress error.", th.getMessage());
                    safelyCloseFile(inputStream);
                    return null;
                } catch (Throwable th3) {
                    safelyCloseFile(inputStream);
                    throw th3;
                }
            }
        } catch (Throwable th4) {
            th = th4;
            inputStream = null;
            Log.e("gzip compress error.", th.getMessage());
            safelyCloseFile(inputStream);
            return null;
        }
        safelyCloseFile(inputStream);
        return null;
    }

    public static byte[] uncompress(byte[] bArr) {
        InputStream inputStream;
        Throwable th;
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            inputStream = getZipInputStream(bArr);
            if (inputStream != null) {
                try {
                    byte[] bArr2 = new byte[256];
                    while (true) {
                        int read = inputStream.read(bArr2);
                        if (read >= 0) {
                            byteArrayOutputStream.write(bArr2, 0, read);
                        } else {
                            byte[] byteArray = byteArrayOutputStream.toByteArray();
                            safelyCloseFile(inputStream);
                            return byteArray;
                        }
                    }
                } catch (Throwable th2) {
                    th = th2;
                    try {
                        Log.e("gzip compress error.", th.getMessage());
                        safelyCloseFile(inputStream);
                        return null;
                    } catch (Throwable th3) {
                        safelyCloseFile(inputStream);
                        throw th3;
                    }
                }
            }
        } catch (Throwable th4) {
            th = th4;
            inputStream = null;
            Log.e("gzip compress error.", th.getMessage());
            safelyCloseFile(inputStream);
            return null;
        }
        safelyCloseFile(inputStream);
        return null;
    }

    public static byte[] uncompressToByteArray(byte[] bArr) {
        GZIPInputStream gZIPInputStream;
        Throwable th;
        if (bArr == null || bArr.length == 0) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bArr);
        try {
            gZIPInputStream = new GZIPInputStream(byteArrayInputStream);
            try {
                byte[] bArr2 = new byte[256];
                while (true) {
                    int read = gZIPInputStream.read(bArr2);
                    if (read >= 0) {
                        byteArrayOutputStream.write(bArr2, 0, read);
                    } else {
                        byte[] byteArray = byteArrayOutputStream.toByteArray();
                        GLFileUtil.closeQuietly(byteArrayOutputStream);
                        GLFileUtil.closeQuietly(byteArrayInputStream);
                        GLFileUtil.closeQuietly(gZIPInputStream);
                        return byteArray;
                    }
                }
            } catch (Throwable th2) {
                th = th2;
                try {
                    dl.a(th);
                    th.printStackTrace();
                    return null;
                } finally {
                    GLFileUtil.closeQuietly(byteArrayOutputStream);
                    GLFileUtil.closeQuietly(byteArrayInputStream);
                    GLFileUtil.closeQuietly(gZIPInputStream);
                }
            }
        } catch (Throwable th3) {
            th = th3;
            gZIPInputStream = null;
            dl.a(th);
            th.printStackTrace();
            return null;
        }
    }

    public static boolean isGzip(byte[] bArr) {
        return ((bArr[1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) | (bArr[0] << 8)) == 8075;
    }

    public static void decompress(InputStream inputStream, String str) throws Exception {
        decompress(inputStream, str, 0, null);
    }

    private static void decompress(InputStream inputStream, String str, long j, ZipCompressProgressListener zipCompressProgressListener) throws Exception {
        CheckedInputStream checkedInputStream = new CheckedInputStream(inputStream, new CRC32());
        ZipInputStream zipInputStream = new ZipInputStream(checkedInputStream);
        decompress(null, new File(str), zipInputStream, j, zipCompressProgressListener, null);
        zipInputStream.close();
        checkedInputStream.close();
    }

    private static void decompress(File file, File file2, ZipInputStream zipInputStream, long j, ZipCompressProgressListener zipCompressProgressListener, UnZipFileBrake unZipFileBrake) throws Exception {
        boolean z = false;
        int i = 0;
        while (true) {
            ZipEntry nextEntry = zipInputStream.getNextEntry();
            if (nextEntry == null) {
                break;
            } else if (unZipFileBrake == null || !unZipFileBrake.mIsAborted) {
                String name = nextEntry.getName();
                if (TextUtils.isEmpty(name) || !isSafeEntryName(name)) {
                    z = true;
                } else {
                    File file3 = new File(file2.getPath() + File.separator + name);
                    fileProber(file3);
                    if (nextEntry.isDirectory()) {
                        file3.mkdirs();
                    } else {
                        i += decompressFile(file3, zipInputStream, (long) i, j, zipCompressProgressListener, unZipFileBrake);
                    }
                    zipInputStream.closeEntry();
                }
            } else {
                zipInputStream.closeEntry();
                return;
            }
        }
        z = true;
        if (z && file != null) {
            try {
                file.delete();
            } catch (Exception unused) {
            }
        }
    }

    private static void fileProber(File file) {
        File parentFile = file.getParentFile();
        if (!parentFile.exists()) {
            fileProber(parentFile);
            parentFile.mkdir();
        }
    }

    private static int decompressFile(File file, ZipInputStream zipInputStream, long j, long j2, ZipCompressProgressListener zipCompressProgressListener, UnZipFileBrake unZipFileBrake) throws Exception {
        BufferedOutputStream bufferedOutputStream = new BufferedOutputStream(new FileOutputStream(file));
        byte[] bArr = new byte[1024];
        int i = 0;
        while (true) {
            int read = zipInputStream.read(bArr, 0, 1024);
            if (read == -1) {
                bufferedOutputStream.close();
                return i;
            } else if (unZipFileBrake == null || !unZipFileBrake.mIsAborted) {
                bufferedOutputStream.write(bArr, 0, read);
                i += read;
                if (j2 > 0 && zipCompressProgressListener != null) {
                    long j3 = ((((long) i) + j) * 100) / j2;
                    if (unZipFileBrake == null || !unZipFileBrake.mIsAborted) {
                        zipCompressProgressListener.onFinishProgress(j3);
                    }
                }
            } else {
                bufferedOutputStream.close();
                return i;
            }
        }
    }
}
