package io.dcloud.feature.iBeacon;

import android.bluetooth.BluetoothDevice;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONArray;

public class IBeaconContainer {
    private static JSONArray WxBeaconUUID;
    private Map<String, IBeaconRecord> iBeaconRecordMap = new HashMap();
    private long mExpireProcessTimeStampMillis = 0;
    private long mExpireTimeMillis = 8000;
    private int mRssiMinFilter = -75;

    public synchronized void update(BluetoothDevice bluetoothDevice, int i, byte[] bArr) {
        IBeaconRecord fromScanData;
        if (i >= this.mRssiMinFilter && i < -1 && (fromScanData = IBeaconRecord.fromScanData(bluetoothDevice, bArr, i)) != null) {
            JSONArray jSONArray = WxBeaconUUID;
            if (jSONArray == null || jSONArray.length() <= 0) {
                this.iBeaconRecordMap.put(fromScanData.address, fromScanData);
            } else {
                for (int i2 = 0; i2 < WxBeaconUUID.length(); i2++) {
                    if (WxBeaconUUID.optString(i2).equalsIgnoreCase(fromScanData.getUuid())) {
                        this.iBeaconRecordMap.put(fromScanData.address, fromScanData);
                    }
                }
            }
        }
        processExpireBeacons();
    }

    public static void setWxBeaconUUID(JSONArray jSONArray) {
        WxBeaconUUID = jSONArray;
    }

    public synchronized Map<String, IBeaconRecord> getBeacons() {
        processExpireBeacons();
        return new HashMap(this.iBeaconRecordMap);
    }

    private void processExpireBeacons() {
        long timeInMillis = Calendar.getInstance().getTimeInMillis();
        if (timeInMillis - this.mExpireProcessTimeStampMillis >= 1000) {
            HashMap hashMap = new HashMap();
            for (Map.Entry<String, IBeaconRecord> entry : this.iBeaconRecordMap.entrySet()) {
                if (timeInMillis - entry.getValue().timeStampMillis <= this.mExpireTimeMillis) {
                    hashMap.put(entry.getKey(), entry.getValue());
                }
            }
            this.iBeaconRecordMap.clear();
            this.iBeaconRecordMap.putAll(hashMap);
            this.mExpireProcessTimeStampMillis = timeInMillis;
        }
    }
}
