package io.dcloud.feature.weex_amap.adapter.cluster;

import com.alibaba.fastjson.JSONArray;
import com.amap.api.maps.model.LatLng;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import io.dcloud.feature.weex_amap.adapter.marker.IUniMarker;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class Cluster {
    private boolean isMultiplexing = false;
    private List<ClusterItem> mClusterItems;
    private ClusterRender mClusterRender;
    private String mId;
    private LatLng mLatLng;
    private IUniMarker mMarker;
    private int oldCont = 0;

    Cluster(String str, LatLng latLng) {
        this.mId = str;
        this.mLatLng = latLng;
        this.mClusterItems = Collections.synchronizedList(new ArrayList());
    }

    /* access modifiers changed from: package-private */
    public void addClusterItem(ClusterItem clusterItem) {
        this.mClusterItems.add(clusterItem);
    }

    /* access modifiers changed from: package-private */
    public void removeClusterItem(ClusterItem clusterItem) {
        if (this.mClusterItems.contains(clusterItem)) {
            this.mClusterItems.remove(clusterItem);
        }
    }

    /* access modifiers changed from: package-private */
    public void clearClusterItems() {
        List<ClusterItem> list = this.mClusterItems;
        if (list != null) {
            this.oldCont = list.size();
            this.mClusterItems.clear();
        }
    }

    /* access modifiers changed from: package-private */
    public int getClusterCount() {
        return this.mClusterItems.size();
    }

    /* access modifiers changed from: package-private */
    public boolean isMarker() {
        return this.mClusterItems.size() == 1;
    }

    public LatLng getCenterLatLng() {
        return this.mLatLng;
    }

    /* access modifiers changed from: package-private */
    public void setMarker(IUniMarker iUniMarker) {
        this.mMarker = iUniMarker;
    }

    /* access modifiers changed from: package-private */
    public IUniMarker getMarker() {
        return this.mMarker;
    }

    /* access modifiers changed from: package-private */
    public List<ClusterItem> getClusterItems() {
        return this.mClusterItems;
    }

    public ClusterItem getClusterItem(int i) {
        if (this.mClusterItems.size() > i) {
            return this.mClusterItems.get(i);
        }
        return null;
    }

    public String getId() {
        return this.mId;
    }

    public JSONArray getMarkerIds() {
        JSONArray jSONArray = new JSONArray();
        synchronized (this.mClusterItems) {
            for (ClusterItem clusterItem : this.mClusterItems) {
                if (clusterItem != null) {
                    jSONArray.add(clusterItem.getId());
                }
            }
        }
        return jSONArray;
    }

    public boolean isMultiplexing() {
        return this.isMultiplexing;
    }

    public void setMultiplexing(boolean z) {
        this.isMultiplexing = z;
    }

    public void setClusterRender(ClusterRender clusterRender) {
        this.mClusterRender = clusterRender;
    }

    public ClusterRender getClusterRender() {
        return this.mClusterRender;
    }

    public void updateClusterForRender(WXMapView wXMapView, UniSDKInstance uniSDKInstance) {
        ClusterRender clusterRender;
        IUniMarker iUniMarker = this.mMarker;
        if (iUniMarker != null && (iUniMarker instanceof ClusterMarker) && (clusterRender = this.mClusterRender) != null) {
            ((ClusterMarker) iUniMarker).updateClusterForRender(uniSDKInstance, wXMapView, clusterRender);
        }
    }

    public int getOldCont() {
        return this.oldCont;
    }

    public boolean isContUpdate() {
        List<ClusterItem> list = this.mClusterItems;
        if (list == null || this.oldCont == list.size()) {
            return false;
        }
        return true;
    }
}
