package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.text.TextUtils;
import android.widget.TextView;
import com.alibaba.fastjson.JSONObject;
import com.facebook.common.util.UriUtil;
import com.taobao.weex.common.Constants;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.uniapp.utils.UniViewUtils;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.ui.ArrowTextView;

public class AbsMarkerTextView {
    private String bgColor = "#fff";
    private String borderColor;
    private int borderRadius = 0;
    private int borderWidth = 0;
    private String color = "#000";
    private String content;
    private String display;
    private float fontSize = 11.0f;
    private float mViewPort;
    private int padding = 0;
    private int textAlign = 3;

    public void destroy() {
    }

    public AbsMarkerTextView(JSONObject jSONObject, float f) {
        this.mViewPort = f;
        setContent(jSONObject);
        setColor(jSONObject);
        setFontSize(jSONObject);
        setBorderRadius(jSONObject);
        setBorderWidth(jSONObject);
        setBorderColor(jSONObject);
        setBgColor(jSONObject);
        setPadding(jSONObject);
        setDisplay(jSONObject);
        setTextAlign(jSONObject);
    }

    public void setContent(JSONObject jSONObject) {
        if (jSONObject.containsKey(UriUtil.LOCAL_CONTENT_SCHEME)) {
            this.content = jSONObject.getString(UriUtil.LOCAL_CONTENT_SCHEME);
        }
    }

    public void setColor(JSONObject jSONObject) {
        if (jSONObject.containsKey("color")) {
            this.color = jSONObject.getString("color");
        }
    }

    public void setFontSize(JSONObject jSONObject) {
        if (jSONObject.containsKey(Constants.Name.FONT_SIZE)) {
            this.fontSize = UniUtils.getFloat(jSONObject.get(Constants.Name.FONT_SIZE), Float.valueOf(10.0f)).floatValue();
        }
    }

    public void setBorderRadius(JSONObject jSONObject) {
        if (jSONObject.containsKey(Constants.Name.BORDER_RADIUS)) {
            this.borderRadius = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(jSONObject.get(Constants.Name.BORDER_RADIUS)), this.mViewPort);
        }
    }

    public void setBorderWidth(JSONObject jSONObject) {
        if (jSONObject.containsKey(Constants.Name.BORDER_WIDTH)) {
            int i = UniUtils.getInt(jSONObject.get(Constants.Name.BORDER_WIDTH));
            this.borderWidth = i;
            this.padding = (int) UniViewUtils.getRealSubPxByWidth((float) i, this.mViewPort);
        }
    }

    public void setBorderColor(JSONObject jSONObject) {
        if (jSONObject.containsKey(Constants.Name.BORDER_COLOR)) {
            this.borderColor = jSONObject.getString(Constants.Name.BORDER_COLOR);
        }
    }

    public void setBgColor(JSONObject jSONObject) {
        if (jSONObject.containsKey("bgColor")) {
            this.bgColor = jSONObject.getString("bgColor");
        }
    }

    public void setPadding(JSONObject jSONObject) {
        if (jSONObject.containsKey("padding")) {
            int intValue = jSONObject.getIntValue("padding");
            this.padding = intValue;
            this.padding = (int) UniViewUtils.getRealSubPxByWidth((float) intValue, this.mViewPort);
        }
    }

    public void setDisplay(JSONObject jSONObject) {
        if (jSONObject.containsKey("display")) {
            this.display = jSONObject.getString("display");
        }
    }

    public boolean isAlwaysDisPlay() {
        return !TextUtils.isEmpty(this.display) && this.display.equals("ALWAYS");
    }

    public void setTextAlign(JSONObject jSONObject) {
        if (jSONObject.containsKey(Constants.Name.TEXT_ALIGN)) {
            this.textAlign = 3;
            String string = jSONObject.getString(Constants.Name.TEXT_ALIGN);
            string.hashCode();
            if (string.equals("center")) {
                this.textAlign = 17;
            } else if (string.equals("right")) {
                this.textAlign = 5;
            }
        }
    }

    public void update(JSONObject jSONObject) {
        setContent(jSONObject);
        setColor(jSONObject);
        setFontSize(jSONObject);
        setBorderRadius(jSONObject);
        setBorderWidth(jSONObject);
        setBorderColor(jSONObject);
        setBgColor(jSONObject);
        setPadding(jSONObject);
        setDisplay(jSONObject);
        setTextAlign(jSONObject);
    }

    public TextView getTextView(Context context, boolean z) {
        ArrowTextView arrowTextView = new ArrowTextView(context, z);
        arrowTextView.setBgColor(MapResourceUtils.getColor(this.bgColor));
        arrowTextView.setTextPadding(this.padding);
        arrowTextView.setGravity(this.textAlign);
        arrowTextView.setRadius(this.borderRadius);
        arrowTextView.setStrokeWidth(this.borderWidth);
        if (!TextUtils.isEmpty(this.borderColor)) {
            arrowTextView.setStrokeColor(MapResourceUtils.getColor(this.borderColor));
        }
        arrowTextView.setText(this.content);
        arrowTextView.setIncludeFontPadding(false);
        if (!TextUtils.isEmpty(this.color)) {
            arrowTextView.setTextColor(MapResourceUtils.getColor(this.color));
        }
        float f = this.fontSize;
        if (f > 0.0f) {
            arrowTextView.setTextSize(0, UniViewUtils.getRealPxByWidth(f, this.mViewPort));
        }
        return arrowTextView;
    }
}
