package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.widget.LinearLayout;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.utils.overlay.MovingPointOverlay;
import com.taobao.weex.common.Constants;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.List;

public class MarkerLabel extends AbsMarkerTextView {
    Context mContext;
    JSONObject mData;
    private int mHeight = -2;
    MovingPointOverlay mLabelSmoothMarker = null;
    private Marker mMarker;
    private Marker mRootMarker;
    private float mViewProt;
    private int mWidth = -2;
    private float x;
    private float y;

    public void setRotateAngle(float f) {
    }

    public MarkerLabel(Context context, Marker marker, JSONObject jSONObject, WXMapView wXMapView, float f) {
        super(jSONObject, f);
        this.mContext = context;
        this.mRootMarker = marker;
        this.mViewProt = f;
        setData(jSONObject);
        createMarker(this.mRootMarker.getPosition(), wXMapView);
    }

    public void createMarker(LatLng latLng, WXMapView wXMapView) {
        MarkerOptions markerOptions = new MarkerOptions();
        markerOptions.icon(getIcon());
        if (this.mWidth != 0 && this.mHeight != 0) {
            markerOptions.position(latLng);
            markerOptions.anchor(0.0f - (this.x / ((float) this.mWidth)), 0.0f - (this.y / ((float) this.mHeight)));
            this.mMarker = wXMapView.getMap().addMarker(markerOptions);
        }
    }

    public Marker getInstance() {
        return this.mMarker;
    }

    private void setData(JSONObject jSONObject) {
        this.mData = jSONObject;
        if (jSONObject.containsKey("anchorX")) {
            this.x = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(jSONObject.getString("anchorX")), this.mViewProt);
        } else if (jSONObject.containsKey(Constants.Name.X)) {
            this.x = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(jSONObject.getString(Constants.Name.X)), this.mViewProt);
        }
        if (jSONObject.containsKey("anchorY")) {
            this.y = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(jSONObject.getString("anchorY")), this.mViewProt);
        } else if (jSONObject.containsKey(Constants.Name.Y)) {
            this.y = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(jSONObject.getString(Constants.Name.Y)), this.mViewProt);
        }
        if (jSONObject.containsKey("width")) {
            this.mWidth = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(jSONObject.get("width")), this.mViewProt);
        }
        if (jSONObject.containsKey("height")) {
            this.mHeight = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(jSONObject.get("height")), this.mViewProt);
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.AbsMarkerTextView
    public void update(JSONObject jSONObject) {
        setData(jSONObject);
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setIcon(getIcon());
        }
    }

    private BitmapDescriptor getIcon() {
        LinearLayout linearLayout = new LinearLayout(this.mContext);
        linearLayout.addView(getTextView(this.mContext, false), new LinearLayout.LayoutParams(this.mWidth, this.mHeight));
        BitmapDescriptor fromView = BitmapDescriptorFactory.fromView(linearLayout);
        if (fromView != null) {
            this.mWidth = fromView.getWidth();
            this.mHeight = fromView.getHeight();
        }
        return fromView;
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.AbsMarkerTextView
    public void destroy() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.remove();
        }
    }

    public void setPosition(LatLng latLng) {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setPosition(latLng);
        }
    }

    public void moveAlongMarker(WXMapView wXMapView, int i, List<LatLng> list) {
        if (this.mMarker != null) {
            if (this.mLabelSmoothMarker == null) {
                this.mLabelSmoothMarker = new MovingPointOverlay(wXMapView.getMap(), getInstance());
            }
            this.mLabelSmoothMarker.stopMove();
            this.mLabelSmoothMarker.setPoints(list);
            this.mLabelSmoothMarker.setTotalDuration(i / 1000);
            this.mLabelSmoothMarker.startSmoothMove();
        }
    }
}
