package io.dcloud.feature.weex_amap.adapter.marker;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.Marker;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class MarkerMgr extends MapAbsMgr {
    ConcurrentHashMap<String, WXMarker> mMarkerCaches = new ConcurrentHashMap<>();
    ConcurrentHashMap<String, WXMarker> mMarkerTemporary = new ConcurrentHashMap<>();

    public MarkerMgr(WXSDKInstance wXSDKInstance, WXMapView wXMapView) {
        super(wXSDKInstance, wXMapView);
    }

    public synchronized void setMarkers(JSONArray jSONArray, boolean z) throws Exception {
        if (jSONArray != null) {
            try {
                if (jSONArray.size() > 0) {
                    this.mMarkerTemporary.clear();
                    this.mMap.addCluster(jSONArray);
                    for (int i = 0; i < jSONArray.size(); i++) {
                        JSONObject jSONObject = jSONArray.getJSONObject(i);
                        if (!jSONObject.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER)) {
                            if (!jSONObject.containsKey("clusterId")) {
                                String valueOf = String.valueOf(jSONObject.hashCode());
                                if (jSONObject.containsKey("id")) {
                                    valueOf = jSONObject.getString("id");
                                }
                                if (this.mMarkerCaches.containsKey(valueOf)) {
                                    WXMarker remove = this.mMarkerCaches.remove(valueOf);
                                    remove.updateMarkerOptions(jSONObject);
                                    remove.initCalloutAndLabel(this.mInstance.getContext(), this.mMap, jSONObject);
                                    this.mMarkerTemporary.put(valueOf, remove);
                                } else if (this.mMarkerTemporary.containsKey(valueOf)) {
                                    WXMarker remove2 = this.mMarkerTemporary.remove(valueOf);
                                    remove2.updateMarkerOptions(jSONObject);
                                    remove2.initCalloutAndLabel(this.mInstance.getContext(), this.mMap, jSONObject);
                                    this.mMarkerTemporary.put(valueOf, remove2);
                                } else {
                                    this.mMarkerTemporary.put(valueOf, new WXMarker(this.mInstance, this.mMap, jSONObject, valueOf));
                                }
                            }
                        }
                    }
                    if (z) {
                        destroyMarkers(this.mMarkerCaches);
                    }
                    this.mMarkerCaches.putAll(this.mMarkerTemporary);
                }
            } finally {
            }
        }
        if (z) {
            destroyMarkers(this.mMarkerCaches);
            this.mMarkerTemporary.clear();
        }
    }

    public WXMarker getWXMarker(Marker marker) {
        if (marker == null) {
            return null;
        }
        for (String str : this.mMarkerCaches.keySet()) {
            WXMarker wXMarker = this.mMarkerCaches.get(str);
            if (marker.equals(wXMarker.getInstance())) {
                return wXMarker;
            }
        }
        if (this.mMap == null || this.mMap.getClusterAddMarkers() == null) {
            return null;
        }
        for (IUniMarker iUniMarker : this.mMap.getClusterAddMarkers()) {
            if (iUniMarker instanceof WXMarker) {
                WXMarker wXMarker2 = (WXMarker) iUniMarker;
                if (marker.equals(wXMarker2.getInstance())) {
                    return wXMarker2;
                }
            }
        }
        return null;
    }

    public WXMarker getCalloutToWXMarker(Marker marker) {
        if (marker == null) {
            return null;
        }
        for (String str : this.mMarkerCaches.keySet()) {
            WXMarker wXMarker = this.mMarkerCaches.get(str);
            if (wXMarker.getCallout() != null && marker.equals(wXMarker.getCallout().getInstance())) {
                return wXMarker;
            }
        }
        if (this.mMap == null || this.mMap.getClusterAddMarkers() == null) {
            return null;
        }
        for (IUniMarker iUniMarker : this.mMap.getClusterAddMarkers()) {
            if (iUniMarker instanceof WXMarker) {
                WXMarker wXMarker2 = (WXMarker) iUniMarker;
                if (wXMarker2.getCallout() != null && marker.equals(wXMarker2.getCallout().getInstance())) {
                    return wXMarker2;
                }
            }
        }
        return null;
    }

    public WXMarker getLabelToWXMarker(Marker marker) {
        if (marker == null) {
            return null;
        }
        for (String str : this.mMarkerCaches.keySet()) {
            WXMarker wXMarker = this.mMarkerCaches.get(str);
            if (wXMarker.getLabel() != null && marker.equals(wXMarker.getLabel().getInstance())) {
                return wXMarker;
            }
        }
        if (this.mMap == null || this.mMap.getClusterAddMarkers() == null) {
            return null;
        }
        for (IUniMarker iUniMarker : this.mMap.getClusterAddMarkers()) {
            if (iUniMarker instanceof WXMarker) {
                WXMarker wXMarker2 = (WXMarker) iUniMarker;
                if (wXMarker2.getLabel() != null && marker.equals(wXMarker2.getLabel().getInstance())) {
                    return wXMarker2;
                }
            }
        }
        return null;
    }

    private void destroyMarkers(Map<String, WXMarker> map) {
        for (String str : map.keySet()) {
            WXMarker wXMarker = map.get(str);
            if (wXMarker != null) {
                wXMarker.destroy();
            }
        }
        map.clear();
    }

    public void removeMarkers(JSONArray jSONArray) {
        if (jSONArray != null) {
            for (int i = 0; i < jSONArray.size(); i++) {
                this.mMap.removeCluster(jSONArray);
                WXMarker marker = getMarker(jSONArray.getString(i));
                if (marker != null) {
                    marker.destroy();
                }
            }
        }
    }

    private WXMarker getMarker(String str) {
        if (this.mMarkerTemporary.containsKey(str)) {
            return this.mMarkerTemporary.get(str);
        }
        if (this.mMarkerCaches.containsKey(str)) {
            return this.mMarkerCaches.get(str);
        }
        return null;
    }

    public void destroy() {
        ConcurrentHashMap<String, WXMarker> concurrentHashMap = this.mMarkerCaches;
        if (concurrentHashMap != null) {
            for (String str : concurrentHashMap.keySet()) {
                WXMarker wXMarker = this.mMarkerCaches.get(str);
                if (wXMarker != null) {
                    wXMarker.destroy();
                }
            }
            this.mMarkerCaches.clear();
        }
        if (this.mMap != null) {
            this.mMap.clearCluster();
        }
    }

    public void hideMarkerCallout() {
        WXMarker wXMarker;
        try {
            ConcurrentHashMap<String, WXMarker> concurrentHashMap = this.mMarkerCaches;
            if (concurrentHashMap != null) {
                for (String str : concurrentHashMap.keySet()) {
                    WXMarker wXMarker2 = this.mMarkerCaches.get(str);
                    if (wXMarker2 != null) {
                        if (wXMarker2.getCallout() != null) {
                            if (!wXMarker2.getCallout().isAlwaysDisPlay()) {
                                wXMarker2.getCallout().setVisible(false);
                            }
                        } else if (wXMarker2.getInstance().isInfoWindowShown()) {
                            wXMarker2.getInstance().hideInfoWindow();
                        }
                    }
                }
            }
            if (!(this.mMap == null || this.mMap.getClusterAddMarkers() == null)) {
                for (IUniMarker iUniMarker : this.mMap.getClusterAddMarkers()) {
                    if ((iUniMarker instanceof WXMarker) && (wXMarker = (WXMarker) iUniMarker) != null) {
                        if (wXMarker.getCallout() != null && !wXMarker.getCallout().isAlwaysDisPlay()) {
                            wXMarker.getCallout().setVisible(false);
                        } else if (wXMarker.getInstance().isInfoWindowShown()) {
                            wXMarker.getInstance().hideInfoWindow();
                        }
                    }
                }
            }
        } catch (Exception unused) {
        }
    }

    public void refreshCalloutVisible() {
        try {
            ConcurrentHashMap<String, WXMarker> concurrentHashMap = this.mMarkerCaches;
            if (concurrentHashMap != null) {
                for (String str : concurrentHashMap.keySet()) {
                    WXMarker wXMarker = this.mMarkerCaches.get(str);
                    if (!(wXMarker == null || wXMarker.getCallout() == null)) {
                        wXMarker.getCallout().updateVisible();
                    }
                }
            }
            if (!(this.mMap == null || this.mMap.getClusterAddMarkers() == null)) {
                for (IUniMarker iUniMarker : this.mMap.getClusterAddMarkers()) {
                    if (iUniMarker instanceof WXMarker) {
                        WXMarker wXMarker2 = (WXMarker) iUniMarker;
                        if (wXMarker2.getCallout() != null) {
                            wXMarker2.getCallout().updateVisible();
                        }
                    }
                }
            }
        } catch (Exception unused) {
        }
    }

    public void translateMarker(JSONObject jSONObject, JSCallback jSCallback) {
        if (jSONObject != null) {
            WXMarker marker = getMarker(jSONObject.getString("markerId"));
            if (marker != null) {
                marker.translateMarker(jSONObject, jSCallback);
            }
        } else if (jSCallback != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("type", Constants.Event.FAIL);
            jSCallback.invokeAndKeepAlive(hashMap);
        }
    }

    public void moveAlongMarker(JSONObject jSONObject, JSCallback jSCallback) {
        if (jSONObject != null) {
            WXMarker marker = getMarker(jSONObject.getString("markerId"));
            HashMap hashMap = new HashMap();
            if (marker != null) {
                marker.moveAlongMarker(this.mMap, jSONObject, jSCallback);
                return;
            }
            hashMap.put("type", Constants.Event.FAIL);
            if (jSCallback != null) {
                jSCallback.invoke(hashMap);
            }
        } else if (jSCallback != null) {
            HashMap hashMap2 = new HashMap();
            hashMap2.put("type", Constants.Event.FAIL);
            jSCallback.invokeAndKeepAlive(hashMap2);
        }
    }
}
