package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.text.TextUtils;
import android.widget.ImageView;
import android.widget.LinearLayout;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.animation.Animation;
import com.amap.api.maps.model.animation.AnimationSet;
import com.amap.api.maps.model.animation.RotateAnimation;
import com.amap.api.maps.model.animation.TranslateAnimation;
import com.amap.api.maps.utils.overlay.MovingPointOverlay;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import io.dcloud.feature.weex.adapter.FrescoLoadUtil;
import io.dcloud.feature.weex_amap.R;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class WXMarker implements IUniMarker {
    private MarkerCallout mCallout;
    private int mHeight = -1;
    private WXSDKInstance mInstance;
    private boolean mJoinCluster = false;
    private MarkerLabel mLabel;
    private Marker mMarker;
    MovingPointOverlay mSmoothMarker = null;
    private int mWidth = -1;
    private String mid;

    public int getWidth() {
        return this.mWidth;
    }

    public boolean isJoinCluster() {
        return this.mJoinCluster;
    }

    public int getHeight() {
        return this.mHeight;
    }

    public WXMarker(WXSDKInstance wXSDKInstance, WXMapView wXMapView, JSONObject jSONObject, String str) {
        this.mInstance = wXSDKInstance;
        this.mid = str;
        this.mMarker = wXMapView.getMap().addMarker(createMarkerOptions(jSONObject));
        initCalloutAndLabel(this.mInstance.getContext(), wXMapView, jSONObject);
    }

    public String getId() {
        return this.mid;
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.IUniMarker
    public Marker getInstance() {
        return this.mMarker;
    }

    public void setCallout(MarkerCallout markerCallout) {
        this.mCallout = markerCallout;
    }

    public MarkerCallout getCallout() {
        return this.mCallout;
    }

    public MarkerLabel getLabel() {
        return this.mLabel;
    }

    public void isShowInfoWindow() {
        MarkerCallout markerCallout = this.mCallout;
        if (markerCallout != null && markerCallout.isAlwaysDisPlay()) {
            this.mCallout.setVisible(true);
        }
    }

    private MarkerOptions createMarkerOptions(JSONObject jSONObject) {
        MarkerOptions markerOptions = new MarkerOptions();
        setPosition(jSONObject, markerOptions);
        setTitle(jSONObject, markerOptions);
        setZIndex(jSONObject, markerOptions);
        setIconInfo(jSONObject, markerOptions);
        setRotate(jSONObject, markerOptions);
        setAlphe(jSONObject, markerOptions);
        setAnchor(jSONObject, markerOptions);
        setSnippet(jSONObject, markerOptions);
        if (jSONObject.containsKey(Constant.JSONKEY.JOIN_CLUSTER)) {
            this.mJoinCluster = jSONObject.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER);
        }
        return markerOptions;
    }

    public void updateMarkerOptions(JSONObject jSONObject) {
        if (getInstance() != null) {
            setPosition(jSONObject, null);
            setTitle(jSONObject, null);
            setZIndex(jSONObject, null);
            setIconInfo(jSONObject, null);
            setRotate(jSONObject, null);
            setAlphe(jSONObject, null);
            setAnchor(jSONObject, null);
            setSnippet(jSONObject, null);
            if (jSONObject.containsKey(Constant.JSONKEY.JOIN_CLUSTER)) {
                this.mJoinCluster = jSONObject.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER);
            }
        }
    }

    private void setPosition(JSONObject jSONObject, MarkerOptions markerOptions) {
        LatLng latLng = new LatLng(jSONObject.getDouble(Constant.JSONKEY.LATITUDE).doubleValue(), jSONObject.getDouble(Constant.JSONKEY.LONGITUDE).doubleValue());
        if (getInstance() != null) {
            try {
                getInstance().setPosition(latLng);
                MarkerCallout markerCallout = this.mCallout;
                if (markerCallout != null) {
                    markerCallout.setPosition(latLng);
                }
                MarkerLabel markerLabel = this.mLabel;
                if (markerLabel != null) {
                    markerLabel.setPosition(latLng);
                }
            } catch (Exception unused) {
            }
        } else if (markerOptions != null) {
            markerOptions.position(latLng);
        }
    }

    private void setTitle(JSONObject jSONObject, MarkerOptions markerOptions) {
        if (jSONObject.containsKey("title")) {
            String string = jSONObject.getString("title");
            if (getInstance() != null && !TextUtils.isEmpty(getInstance().getTitle()) && !getInstance().getTitle().equals(string)) {
                getInstance().setTitle(string);
            } else if (markerOptions != null) {
                markerOptions.title(string);
            }
        }
    }

    private void setZIndex(JSONObject jSONObject, MarkerOptions markerOptions) {
        if (jSONObject.containsKey(Constant.JSONKEY.ZINDEX)) {
            float floatValue = jSONObject.getFloat(Constant.JSONKEY.ZINDEX).floatValue();
            if (getInstance() != null && floatValue != getInstance().getZIndex()) {
                getInstance().setZIndex(floatValue);
            } else if (markerOptions != null) {
                markerOptions.zIndex(floatValue);
            }
            if (getCallout() != null) {
                getCallout().getInstance().setZIndex(floatValue + 1.0f);
            }
            if (getLabel() != null) {
                getLabel().getInstance().setZIndex(floatValue + 1.0f);
            }
        }
    }

    private void setIconInfo(JSONObject jSONObject, MarkerOptions markerOptions) {
        if (jSONObject.containsKey("width")) {
            this.mWidth = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(jSONObject.get("width")), this.mInstance.getInstanceViewPortWidthWithFloat());
        }
        if (jSONObject.containsKey("height")) {
            this.mHeight = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(jSONObject.get("height")), this.mInstance.getInstanceViewPortWidthWithFloat());
        }
        if (this.mHeight == 0 || this.mWidth == 0) {
            loadImageViewIcon(null, 1, 1, markerOptions);
        } else if (jSONObject.containsKey(Constant.JSONKEY.ICONPATH)) {
            String string = jSONObject.getString(Constant.JSONKEY.ICONPATH);
            if (!Constant.TRANSPARENT.equals(string)) {
                loadImageToIcon(this.mInstance.rewriteUri(Uri.parse(string), "image"), this.mWidth, this.mHeight, markerOptions, jSONObject);
            }
        } else {
            loadImageViewIcon(BitmapFactory.decodeResource(this.mInstance.getContext().getResources(), R.drawable.dcloud_map_marker_ic), this.mWidth, this.mHeight, markerOptions);
        }
    }

    private void setRotate(JSONObject jSONObject, MarkerOptions markerOptions) {
        if (jSONObject.containsKey("rotate")) {
            float f = -jSONObject.getFloat("rotate").floatValue();
            if (getInstance() != null && getInstance().getRotateAngle() != f) {
                getInstance().setRotateAngle(f);
                MarkerLabel markerLabel = this.mLabel;
                if (markerLabel != null) {
                    markerLabel.setRotateAngle(f);
                }
                MarkerCallout markerCallout = this.mCallout;
                if (markerCallout != null) {
                    markerCallout.setRotateAngle(f);
                }
            } else if (markerOptions != null) {
                markerOptions.rotateAngle(f);
            }
        }
    }

    private void setAlphe(JSONObject jSONObject, MarkerOptions markerOptions) {
        if (jSONObject.containsKey(Constant.JSONKEY.ALPHE)) {
            float floatValue = jSONObject.getFloat(Constant.JSONKEY.ALPHE).floatValue();
            if (getInstance() != null && getInstance().getAlpha() != floatValue) {
                getInstance().setAlpha(floatValue);
            } else if (markerOptions != null) {
                markerOptions.alpha(floatValue);
            }
        }
    }

    private void setAnchor(JSONObject jSONObject, MarkerOptions markerOptions) {
        JSONObject jSONObject2;
        if (jSONObject.containsKey("anchor") && (jSONObject2 = jSONObject.getJSONObject("anchor")) != null) {
            if (getInstance() != null) {
                getInstance().setAnchor(jSONObject2.getFloat(Constants.Name.X).floatValue(), jSONObject2.getFloat(Constants.Name.Y).floatValue());
            } else {
                markerOptions.anchor(jSONObject2.getFloat(Constants.Name.X).floatValue(), jSONObject2.getFloat(Constants.Name.Y).floatValue());
            }
        }
    }

    private void setSnippet(JSONObject jSONObject, MarkerOptions markerOptions) {
        if (jSONObject.containsKey(Constant.JSONKEY.ARIA_LABEL)) {
            String string = jSONObject.getString(Constant.JSONKEY.ARIA_LABEL);
            if (getInstance() != null) {
                getInstance().setSnippet(string);
            } else {
                markerOptions.snippet(string);
            }
        }
    }

    private void loadImageToIcon(Uri uri, int i, int i2, final MarkerOptions markerOptions, final JSONObject jSONObject) {
        FrescoLoadUtil.getInstance().loadImageBitmap(this.mInstance.getContext(), uri.toString(), i, i2, new BitmapLoadCallback<Bitmap>() {
            /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass1 */

            @Override // io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback
            public void onFailure(String str, Throwable th) {
            }

            public void onSuccess(String str, Bitmap bitmap) {
                WXMarker.this.loadIcon(bitmap, markerOptions, jSONObject);
            }
        });
    }

    private void loadImageViewIcon(Bitmap bitmap, int i, int i2, MarkerOptions markerOptions) {
        ImageView imageView = new ImageView(this.mInstance.getContext());
        imageView.setScaleType(ImageView.ScaleType.FIT_XY);
        imageView.setLayoutParams(new LinearLayout.LayoutParams(i, i2));
        if (bitmap != null) {
            imageView.setImageBitmap(bitmap);
        }
        BitmapDescriptor fromView = BitmapDescriptorFactory.fromView(imageView);
        if (getInstance() != null) {
            getInstance().setIcon(fromView);
        } else if (markerOptions != null) {
            markerOptions.icon(fromView);
        }
        if (getCallout() != null) {
            getCallout().update();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void loadIcon(Bitmap bitmap, MarkerOptions markerOptions, JSONObject jSONObject) {
        BitmapDescriptor fromBitmap = BitmapDescriptorFactory.fromBitmap(bitmap);
        if (getInstance() != null) {
            getInstance().setIcon(fromBitmap);
        } else if (markerOptions != null) {
            markerOptions.icon(fromBitmap);
        }
        if (getCallout() != null && jSONObject != null) {
            getCallout().update();
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.IUniMarker
    public void destroy() {
        MovingPointOverlay movingPointOverlay = this.mSmoothMarker;
        if (movingPointOverlay != null) {
            movingPointOverlay.setMoveListener(null);
            this.mSmoothMarker.destroy();
        }
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.destroy();
        }
        MarkerCallout markerCallout = this.mCallout;
        if (markerCallout != null) {
            markerCallout.destroy();
        }
        MarkerLabel markerLabel = this.mLabel;
        if (markerLabel != null) {
            markerLabel.destroy();
        }
    }

    public void initCalloutAndLabel(Context context, WXMapView wXMapView, JSONObject jSONObject) {
        if (getCallout() == null) {
            setCallout(createMarkerCallout(context, wXMapView, jSONObject));
        } else if (jSONObject.containsKey(Constant.JSONKEY.CALLOUT)) {
            getCallout().update(jSONObject.getJSONObject(Constant.JSONKEY.CALLOUT));
        } else {
            getCallout().destroy();
            this.mCallout = null;
        }
        isShowInfoWindow();
        if (jSONObject.containsKey(Constant.JSONKEY.LABEL)) {
            MarkerLabel markerLabel = this.mLabel;
            if (markerLabel != null) {
                markerLabel.update(jSONObject.getJSONObject(Constant.JSONKEY.LABEL));
            } else {
                this.mLabel = new MarkerLabel(context, this.mMarker, jSONObject.getJSONObject(Constant.JSONKEY.LABEL), wXMapView, this.mInstance.getInstanceViewPortWidthWithFloat());
            }
            this.mLabel.getInstance().setZIndex(getInstance().getZIndex() + 1.0f);
        }
    }

    private MarkerCallout createMarkerCallout(Context context, WXMapView wXMapView, JSONObject jSONObject) {
        if (jSONObject.containsKey(Constant.JSONKEY.CUSTOM_CALLOUT)) {
            MarkerCustomCallout markerCustomCallout = new MarkerCustomCallout(context, this, jSONObject.getJSONObject(Constant.JSONKEY.CUSTOM_CALLOUT), wXMapView, this.mInstance.getInstanceViewPortWidthWithFloat());
            markerCustomCallout.getInstance().setZIndex(getInstance().getZIndex() + 1.0f);
            return markerCustomCallout;
        } else if (!jSONObject.containsKey(Constant.JSONKEY.CALLOUT)) {
            return null;
        } else {
            MarkerCallout markerCallout = new MarkerCallout(context, this, jSONObject.getJSONObject(Constant.JSONKEY.CALLOUT), wXMapView, this.mInstance.getInstanceViewPortWidthWithFloat());
            markerCallout.getInstance().setZIndex(getInstance().getZIndex() + 1.0f);
            return markerCallout;
        }
    }

    public void moveAlongMarker(WXMapView wXMapView, JSONObject jSONObject, final JSCallback jSCallback) {
        JSONArray jSONArray;
        int intValue = UniUtils.getInteger(jSONObject.get("duration"), 0).intValue();
        if (intValue < 1000) {
            intValue = 1000;
        }
        final HashMap hashMap = new HashMap();
        if (intValue > 0) {
            if (this.mSmoothMarker == null) {
                this.mSmoothMarker = new MovingPointOverlay(wXMapView.getMap(), getInstance());
            }
            this.mSmoothMarker.stopMove();
            List<LatLng> list = null;
            if (jSONObject.containsKey("path") && (jSONArray = jSONObject.getJSONArray("path")) != null && (list = getMovePoints(jSONArray)) != null && list.size() > 0) {
                this.mSmoothMarker.setPoints(list);
            }
            if (list != null) {
                this.mSmoothMarker.setTotalDuration(intValue / 1000);
                this.mSmoothMarker.setMoveListener(new MovingPointOverlay.MoveListener() {
                    /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass2 */

                    @Override // com.amap.api.maps.utils.overlay.MovingPointOverlay.MoveListener
                    public void move(double d) {
                        if (d <= 0.0d) {
                            if (jSCallback != null) {
                                hashMap.put("type", WXImage.SUCCEED);
                                jSCallback.invoke(hashMap);
                            }
                            WXMarker.this.mSmoothMarker.setMoveListener(null);
                        }
                    }
                });
                MarkerLabel markerLabel = this.mLabel;
                if (markerLabel != null) {
                    markerLabel.moveAlongMarker(wXMapView, intValue, list);
                }
                MarkerCallout markerCallout = this.mCallout;
                if (markerCallout != null) {
                    markerCallout.moveAlongMarker(wXMapView, intValue, list);
                }
                this.mSmoothMarker.startSmoothMove();
                return;
            }
        }
        hashMap.put("type", Constants.Event.FAIL);
        if (jSCallback != null) {
            jSCallback.invoke(hashMap);
        }
    }

    public void translateMarker(JSONObject jSONObject, JSCallback jSCallback) {
        LatLng crateLatLng = MapResourceUtils.crateLatLng(jSONObject.getJSONObject("destination"));
        boolean booleanValue = jSONObject.containsKey("moveWithRotate") ? jSONObject.getBoolean("moveWithRotate").booleanValue() : false;
        long j = 1000;
        if (jSONObject.containsKey("duration")) {
            j = UniUtils.getLong(jSONObject.get("duration"));
        }
        Marker instance = getInstance();
        if (jSONObject.containsKey("rotate")) {
            float f = -UniUtils.parseFloat(jSONObject.get("rotate"));
            rotateToTranslateAnimation(instance, f, j, crateLatLng, booleanValue, jSCallback);
            MarkerLabel markerLabel = this.mLabel;
            if (markerLabel != null) {
                rotateToTranslateAnimation(markerLabel.getInstance(), f, j, crateLatLng, booleanValue, null);
            }
            MarkerCallout markerCallout = this.mCallout;
            if (markerCallout != null) {
                rotateToTranslateAnimation(markerCallout.getInstance(), this.mCallout.getInstance().getRotateAngle(), j, crateLatLng, booleanValue, null);
            }
        } else {
            translateAnimation(crateLatLng, j, instance, jSCallback);
            MarkerLabel markerLabel2 = this.mLabel;
            if (markerLabel2 != null) {
                translateAnimation(crateLatLng, j, markerLabel2.getInstance(), null);
            }
            MarkerCallout markerCallout2 = this.mCallout;
            if (markerCallout2 != null) {
                translateAnimation(crateLatLng, j, markerCallout2.getInstance(), null);
            }
        }
        if (jSCallback != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("type", WXImage.SUCCEED);
            jSCallback.invokeAndKeepAlive(hashMap);
        }
    }

    private void rotateToTranslateAnimation(final Marker marker, float f, long j, final LatLng latLng, boolean z, final JSCallback jSCallback) {
        if (z) {
            RotateAnimation rotateAnimation = new RotateAnimation(marker.getRotateAngle(), f);
            rotateAnimation.setDuration(j);
            TranslateAnimation translateAnimation = new TranslateAnimation(latLng);
            translateAnimation.setDuration(j);
            AnimationSet animationSet = new AnimationSet(true);
            animationSet.addAnimation(rotateAnimation);
            animationSet.addAnimation(translateAnimation);
            animationSet.setAnimationListener(new Animation.AnimationListener() {
                /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass3 */

                @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
                public void onAnimationStart() {
                }

                @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
                public void onAnimationEnd() {
                    if (jSCallback != null) {
                        HashMap hashMap = new HashMap();
                        hashMap.put("type", "animationEnd");
                        jSCallback.invokeAndKeepAlive(hashMap);
                    }
                }
            });
            marker.setAnimation(animationSet);
            marker.startAnimation();
            return;
        }
        double d = (double) j;
        Double.isNaN(d);
        long j2 = (long) (d * 0.3d);
        final long j3 = j - j2;
        RotateAnimation rotateAnimation2 = new RotateAnimation(marker.getRotateAngle(), f);
        rotateAnimation2.setDuration(j2);
        rotateAnimation2.setAnimationListener(new Animation.AnimationListener() {
            /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass4 */

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationStart() {
            }

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationEnd() {
                WXMarker.this.translateAnimation(latLng, j3, marker, jSCallback);
            }
        });
        marker.setAnimation(rotateAnimation2);
        marker.startAnimation();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void translateAnimation(LatLng latLng, long j, Marker marker, final JSCallback jSCallback) {
        TranslateAnimation translateAnimation = new TranslateAnimation(latLng);
        translateAnimation.setDuration(j);
        translateAnimation.setAnimationListener(new Animation.AnimationListener() {
            /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass5 */

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationStart() {
            }

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationEnd() {
                if (jSCallback != null) {
                    HashMap hashMap = new HashMap();
                    hashMap.put("type", "animationEnd");
                    jSCallback.invokeAndKeepAlive(hashMap);
                }
            }
        });
        marker.setAnimation(translateAnimation);
        marker.startAnimation();
    }

    public boolean isCalloutShown() {
        if (getCallout() != null) {
            return getCallout().getInstance().isVisible();
        }
        return false;
    }

    public void showCallout() {
        if (getCallout() != null && !getCallout().isAlwaysDisPlay()) {
            getCallout().setVisible(true);
        }
    }

    public void hideCallout() {
        if (getCallout() != null && !getCallout().isAlwaysDisPlay()) {
            getCallout().setVisible(false);
        }
    }

    private List<LatLng> getMovePoints(JSONArray jSONArray) {
        ArrayList arrayList = new ArrayList();
        if (jSONArray.size() > 0) {
            for (int i = 0; i < jSONArray.size(); i++) {
                JSONObject jSONObject = jSONArray.getJSONObject(i);
                if (jSONObject != null) {
                    arrayList.add(new LatLng(Double.valueOf(jSONObject.getDoubleValue(Constant.JSONKEY.LATITUDE)).doubleValue(), Double.valueOf(jSONObject.getDoubleValue(Constant.JSONKEY.LONGITUDE)).doubleValue()));
                }
            }
        }
        return arrayList;
    }
}
