package io.dcloud.feature.weex_amap.adapter.polygon;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.Polygon;
import com.amap.api.maps.model.PolygonOptions;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.ArrayList;
import java.util.Iterator;

public class PolygonMgr extends MapAbsMgr {
    ArrayList<Polygon> mPolygonCaches = new ArrayList<>();

    public PolygonMgr(WXSDKInstance wXSDKInstance, WXMapView wXMapView) {
        super(wXSDKInstance, wXMapView);
    }

    public void setPolygon(JSONArray jSONArray) {
        if (jSONArray == null || jSONArray.size() <= 0) {
            clearPolygon();
            return;
        }
        ArrayList arrayList = new ArrayList();
        for (int i = 0; i < jSONArray.size(); i++) {
            PolygonOptions createPolygonOptions = createPolygonOptions(jSONArray.getJSONObject(i));
            if (createPolygonOptions != null) {
                arrayList.add(this.mMap.getMap().addPolygon(createPolygonOptions));
            }
        }
        clearPolygon();
        if (arrayList.size() > 0) {
            this.mPolygonCaches.addAll(arrayList);
        }
    }

    private PolygonOptions createPolygonOptions(JSONObject jSONObject) {
        PolygonOptions polygonOptions = null;
        if (jSONObject != null && jSONObject.containsKey("points")) {
            polygonOptions = new PolygonOptions();
            polygonOptions.addAll(MapResourceUtils.crateLatLngs(jSONObject.getJSONArray("points")));
            if (jSONObject.containsKey(Constant.Name.STROKE_WIDTH)) {
                polygonOptions.strokeWidth(WXViewUtils.getRealSubPxByWidth(UniUtils.getFloat(jSONObject.get(Constant.Name.STROKE_WIDTH)), this.mInstance.getInstanceViewPortWidthWithFloat()));
            }
            if (jSONObject.containsKey(Constant.Name.STROKE_COLOR)) {
                polygonOptions.strokeColor(MapResourceUtils.getColor(jSONObject.getString(Constant.Name.STROKE_COLOR)));
            }
            if (jSONObject.containsKey(Constant.Name.FILL_COLOR)) {
                polygonOptions.fillColor(MapResourceUtils.getColor(jSONObject.getString(Constant.Name.FILL_COLOR)));
            }
            if (jSONObject.containsKey(Constant.JSONKEY.ZINDEX)) {
                polygonOptions.zIndex(jSONObject.getFloat(Constant.JSONKEY.ZINDEX).floatValue());
            }
        }
        return polygonOptions;
    }

    public void clearPolygon() {
        ArrayList<Polygon> arrayList = this.mPolygonCaches;
        if (arrayList != null) {
            Iterator<Polygon> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().remove();
            }
            this.mPolygonCaches.clear();
        }
    }
}
