package io.dcloud.feature.weex_amap.component;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.location.Location;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.MotionEvent;
import android.view.View;
import android.widget.FrameLayout;
import androidx.core.app.ActivityCompat;
import androidx.core.app.NotificationCompat;
import androidx.core.content.ContextCompat;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.location.AMapLocationClient;
import com.amap.api.location.AMapLocationClientOption;
import com.amap.api.maps.AMap;
import com.amap.api.maps.CameraUpdateFactory;
import com.amap.api.maps.MapsInitializer;
import com.amap.api.maps.UiSettings;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.CameraPosition;
import com.amap.api.maps.model.CustomMapStyleOptions;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MyLocationStyle;
import com.amap.api.maps.model.Poi;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.language.LanguageUtil;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import io.dcloud.feature.uniapp.bridge.UniJSCallback;
import io.dcloud.feature.uniapp.dom.UniCSSConstants;
import io.dcloud.feature.uniapp.layout.UniContentBoxMeasurement;
import io.dcloud.feature.uniapp.ui.action.AbsComponentData;
import io.dcloud.feature.uniapp.ui.component.AbsVContainer;
import io.dcloud.feature.uniapp.ui.component.UniComponentProp;
import io.dcloud.feature.uniapp.ui.component.UniVContainer;
import io.dcloud.feature.uniapp.utils.UniLogUtils;
import io.dcloud.feature.uniapp.utils.UniViewUtils;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import io.dcloud.feature.weex.adapter.FrescoLoadUtil;
import io.dcloud.feature.weex.extend.DCCoverViewComponent;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapInterface;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import io.dcloud.feature.weex_amap.adapter.circle.CircleMgr;
import io.dcloud.feature.weex_amap.adapter.cluster.Cluster;
import io.dcloud.feature.weex_amap.adapter.cluster.OnClusterClickListener;
import io.dcloud.feature.weex_amap.adapter.cluster.OnClusterCreateListener;
import io.dcloud.feature.weex_amap.adapter.control.ControlMgr;
import io.dcloud.feature.weex_amap.adapter.ground.GroundMgr;
import io.dcloud.feature.weex_amap.adapter.marker.MarkerMgr;
import io.dcloud.feature.weex_amap.adapter.marker.WXMarker;
import io.dcloud.feature.weex_amap.adapter.polygon.PolygonMgr;
import io.dcloud.feature.weex_amap.adapter.polyline.PolylineMgr;
import io.dcloud.feature.weex_amap.ui.MapLayout;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.concurrent.atomic.AtomicBoolean;

public class WXAMapViewComponent extends UniVContainer<FrameLayout> implements MapInterface {
    private static final int REQUEST_CODE_MAPVIEW = 11224;
    private static final String TAG = "WXAMapViewComponent";
    private static String[] permissions = {"android.permission.ACCESS_FINE_LOCATION", "android.permission.ACCESS_COARSE_LOCATION"};
    private String defBackgroundColor;
    private boolean isBuilding3D;
    private boolean isChangeStart;
    private boolean isCompassEnable;
    private boolean isEnableIndoorMap;
    private boolean isEnablePoi;
    private boolean isEnableSatellite;
    private boolean isEnableTraffic;
    private AtomicBoolean isInited;
    private AtomicBoolean isMapLoaded;
    private boolean isMyLocationEnable;
    private boolean isOverLookingEnable;
    private boolean isRotateEnable;
    private boolean isScrollEnable;
    boolean isSetUpdate;
    private boolean isShowAnimationEnd;
    private boolean isShowScale;
    private boolean isZoomEnable;
    private AMap mAMap;
    private Activity mActivity;
    String mCameraType;
    private CircleMgr mCircleMgr;
    private ControlMgr mControlMgr;
    private float mDefHeight;
    private float mDefWidth;
    boolean mDragged;
    private GroundMgr mGroundMgr;
    private long mLoadTime;
    private AMapLocationClient mLocationClient;
    private AMapLocationClientOption mLocationOption;
    private Point mMapCenterPoint;
    private FrameLayout mMapContainer;
    private WXMapView mMapView;
    private MarkerMgr mMarkerMgr;
    private Location mMyLocation;
    AMap.OnMyLocationChangeListener mMyLocationCallBack;
    private PolygonMgr mPolygonMgr;
    private PolylineMgr mPolylineMgr;
    private UiSettings mUiSettings;
    private float mZoomLevel;
    private MyLocationStyle myLocationStyle;
    private Queue<MapOperationTask> paddingTasks;

    /* access modifiers changed from: package-private */
    public interface MapOperationTask {
        void execute(WXMapView wXMapView);
    }

    @UniJSMethod
    public void addCustomLayer(String str, UniJSCallback uniJSCallback) {
    }

    @UniJSMethod
    public void removeCustomLayer(JSONObject jSONObject, UniJSCallback uniJSCallback) {
    }

    public WXAMapViewComponent(UniSDKInstance uniSDKInstance, AbsVContainer absVContainer, AbsComponentData absComponentData) {
        super(uniSDKInstance, absVContainer, absComponentData);
        this.isZoomEnable = true;
        this.isBuilding3D = true;
        this.isCompassEnable = false;
        this.isScrollEnable = true;
        this.isRotateEnable = false;
        this.isMyLocationEnable = false;
        this.isOverLookingEnable = false;
        this.isEnableSatellite = false;
        this.isEnableTraffic = false;
        this.isShowScale = false;
        this.isEnablePoi = true;
        this.isEnableIndoorMap = false;
        this.mZoomLevel = 16.0f;
        this.isMapLoaded = new AtomicBoolean(false);
        this.isInited = new AtomicBoolean(false);
        this.paddingTasks = new LinkedList();
        this.defBackgroundColor = "#f1f1f1";
        this.mLoadTime = 0;
        this.isChangeStart = false;
        this.mDragged = false;
        this.mCameraType = "drag";
        this.isSetUpdate = false;
        this.mDefHeight = 0.0f;
        this.mDefWidth = 0.0f;
        this.isShowAnimationEnd = false;
        this.mLoadTime = System.currentTimeMillis();
        this.mDefHeight = UniViewUtils.getRealPxByWidth(150.0f, getInstance().getInstanceViewPortWidthWithFloat());
        this.mDefWidth = UniViewUtils.getRealPxByWidth(300.0f, getInstance().getInstanceViewPortWidthWithFloat());
        if (!absComponentData.getStyles().containsKey("backgroundColor")) {
            absComponentData.getStyles().put("backgroundColor", (Object) this.defBackgroundColor);
        }
        if (!absComponentData.getStyles().containsKey(Constants.Name.FLEX)) {
            setContentBoxMeasurement(new UniContentBoxMeasurement() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass1 */

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void layoutAfter(float f, float f2) {
                }

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void layoutBefore() {
                }

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void measureInternal(float f, float f2, int i, int i2) {
                    if (UniCSSConstants.isUndefined(f2)) {
                        f2 = WXAMapViewComponent.this.mDefHeight;
                    }
                    this.mMeasureHeight = f2;
                }
            });
        }
        getInstance().addFrameViewEventListener(new WXSDKInstance.FrameViewEventListener() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass2 */

            @Override // com.taobao.weex.WXSDKInstance.FrameViewEventListener
            public void onShowAnimationEnd() {
                WXAMapViewComponent.this.isShowAnimationEnd = true;
                if (WXAMapViewComponent.this.mMapView != null) {
                    WXAMapViewComponent.this.mMapView.setVisibility(0);
                    UniLogUtils.e(WXAMapViewComponent.TAG, "Map VISIBLE");
                }
                WXAMapViewComponent.this.getInstance().removeFrameViewEventListener(this);
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public FrameLayout initComponentHostView(Context context) {
        AppRuntime.checkPrivacyComplianceAndPrompt(context, "nvue-map");
        this.mMapContainer = new MapLayout(context);
        if (context instanceof Activity) {
            this.mActivity = (Activity) context;
        }
        createMap();
        return this.mMapContainer;
    }

    private void createMap() {
        FrameLayout frameLayout = this.mMapContainer;
        if (frameLayout != null) {
            int i = frameLayout.getChildCount() > 0 ? 0 : -1;
            try {
                MapsInitializer.initialize(getContext());
                PlatformUtil.invokeMethod("com.amap.api.maps.MapsInitializer", "updatePrivacyShow", null, new Class[]{Context.class, Boolean.TYPE, Boolean.TYPE}, new Object[]{getContext(), true, true});
                PlatformUtil.invokeMethod("com.amap.api.maps.MapsInitializer", "updatePrivacyAgree", null, new Class[]{Context.class, Boolean.TYPE}, new Object[]{getContext(), true});
                this.mMapView = new WXMapView(getContext(), getInstance());
                if (this.mMarkerMgr == null) {
                    this.mMarkerMgr = new MarkerMgr(getInstance(), this.mMapView);
                }
                this.mMapContainer.addView(this.mMapView, i, new FrameLayout.LayoutParams(-1, -1));
                this.mMapView.onCreate(null);
                this.mMapView.setVisibility(4);
                UniLogUtils.e(TAG, "Create MapView " + this.mMapView.toString());
                initMap();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void setHostLayoutParams(FrameLayout frameLayout, int i, int i2, int i3, int i4, int i5, int i6) {
        super.setHostLayoutParams((View) frameLayout, i, i2, i3, i4, i5, i6);
        if (!this.isMapLoaded.get() && !this.isInited.get()) {
            this.isInited.set(true);
            this.mMapContainer.postDelayed(new Runnable() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass3 */

                public void run() {
                    if (WXAMapViewComponent.this.getInstance() == null) {
                        return;
                    }
                    if (WXAMapViewComponent.this.isShowAnimationEnd || WXAMapViewComponent.this.getInstance().isFrameViewShow()) {
                        WXAMapViewComponent.this.mMapView.setVisibility(0);
                    }
                }
            }, 0);
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.MapInterface
    public void initMap() {
        this.isMapLoaded.set(false);
        if (this.mAMap == null) {
            this.mMapCenterPoint = new Point();
            AMap map = this.mMapView.getMap();
            this.mAMap = map;
            map.setMinZoomLevel(3.0f);
            this.mAMap.setMaxZoomLevel(20.0f);
            String currentLocaleLanguage = LanguageUtil.getCurrentLocaleLanguage(getContext());
            if (TextUtils.isEmpty(currentLocaleLanguage) || currentLocaleLanguage.startsWith("zh")) {
                this.mAMap.setMapLanguage("zh_cn");
            } else {
                this.mAMap.setMapLanguage("en");
            }
            setCenter(getAttrs().get(Constant.JSONKEY.LATITUDE), getAttrs().get(Constant.JSONKEY.LONGITUDE));
            this.mAMap.setOnMapLoadedListener(new AMap.OnMapLoadedListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass4 */

                @Override // com.amap.api.maps.AMap.OnMapLoadedListener
                public void onMapLoaded() {
                    UniLogUtils.e(WXAMapViewComponent.TAG, "Map loaded");
                    WXAMapViewComponent.this.isMapLoaded.set(true);
                    WXAMapViewComponent.this.mMapView.postDelayed(new Runnable() {
                        /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass4.AnonymousClass1 */

                        public void run() {
                            WXAMapViewComponent.this.execPaddingTasks();
                        }
                    }, 16);
                    WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.UPDATED, null);
                }
            });
            this.mAMap.setOnMapClickListener(new AMap.OnMapClickListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass5 */

                @Override // com.amap.api.maps.AMap.OnMapClickListener
                public void onMapClick(LatLng latLng) {
                    WXAMapViewComponent.this.mMarkerMgr.hideMarkerCallout();
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put(Constant.JSONKEY.LONGITUDE, (Object) Double.valueOf(latLng.longitude));
                    jSONObject.put(Constant.JSONKEY.LATITUDE, (Object) Double.valueOf(latLng.latitude));
                    WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BINDTAP, jSONObject);
                }
            });
            this.mAMap.setOnMarkerClickListener(new AMap.OnMarkerClickListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass6 */

                @Override // com.amap.api.maps.AMap.OnMarkerClickListener
                public boolean onMarkerClick(Marker marker) {
                    if (marker == null) {
                        return false;
                    }
                    if (WXAMapViewComponent.this.mMapView != null && WXAMapViewComponent.this.mMapView.onMarkerClick(marker)) {
                        return true;
                    }
                    JSONObject jSONObject = new JSONObject();
                    WXMarker wXMarker = WXAMapViewComponent.this.mMarkerMgr.getWXMarker(marker);
                    if (wXMarker != null) {
                        jSONObject.put("markerId", MapResourceUtils.getId(wXMarker.getId()));
                        if (wXMarker.getCallout() != null) {
                            WXAMapViewComponent.this.mMarkerMgr.hideMarkerCallout();
                            if (!wXMarker.getCallout().isAlwaysDisPlay()) {
                                if (wXMarker.isCalloutShown()) {
                                    wXMarker.hideCallout();
                                } else {
                                    wXMarker.showCallout();
                                }
                            }
                        } else if (marker.isInfoWindowShown()) {
                            marker.hideInfoWindow();
                        } else {
                            marker.showInfoWindow();
                        }
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_MARKER_TAP, jSONObject);
                        return true;
                    }
                    WXMarker calloutToWXMarker = WXAMapViewComponent.this.mMarkerMgr.getCalloutToWXMarker(marker);
                    if (calloutToWXMarker != null) {
                        jSONObject.put("markerId", MapResourceUtils.getId(calloutToWXMarker.getId()));
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_CALLOUT_TAP, jSONObject);
                        return true;
                    }
                    WXMarker labelToWXMarker = WXAMapViewComponent.this.mMarkerMgr.getLabelToWXMarker(marker);
                    if (labelToWXMarker != null) {
                        jSONObject.put("markerId", MapResourceUtils.getId(labelToWXMarker.getId()));
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_LABEL_TAP, jSONObject);
                        return true;
                    } else if (labelToWXMarker != null || !WXAMapViewComponent.this.equalsMyLocationMarker(marker.getPosition())) {
                        return false;
                    } else {
                        JSONObject jSONObject2 = new JSONObject();
                        jSONObject2.put(Constant.JSONKEY.LONGITUDE, (Object) Double.valueOf(marker.getPosition().longitude));
                        jSONObject2.put(Constant.JSONKEY.LATITUDE, (Object) Double.valueOf(marker.getPosition().latitude));
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_ANCHOR_POINT_TAP, jSONObject2);
                        return true;
                    }
                }
            });
            this.mAMap.setOnCameraChangeListener(new AMap.OnCameraChangeListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass7 */

                @Override // com.amap.api.maps.AMap.OnCameraChangeListener
                public void onCameraChange(CameraPosition cameraPosition) {
                    if (WXAMapViewComponent.this.mMapView != null) {
                        WXAMapViewComponent.this.mMapView.onCameraChange(cameraPosition);
                    }
                    WXAMapViewComponent.this.mMapCenterPoint.update(cameraPosition.target.latitude, cameraPosition.target.longitude);
                    if (!WXAMapViewComponent.this.isChangeStart && WXAMapViewComponent.this.isMapLoaded.get()) {
                        if (WXAMapViewComponent.this.mDragged) {
                            WXAMapViewComponent.this.mCameraType = Constant.Name.GESTURE;
                        } else {
                            WXAMapViewComponent.this.mCameraType = "update";
                        }
                        WXAMapViewComponent.this.mZoomLevel = cameraPosition.zoom;
                        WXAMapViewComponent.this.isChangeStart = true;
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BINDREGION_CHANGE, "begin");
                    }
                }

                @Override // com.amap.api.maps.AMap.OnCameraChangeListener
                public void onCameraChangeFinish(CameraPosition cameraPosition) {
                    if (WXAMapViewComponent.this.isChangeStart && WXAMapViewComponent.this.isMapLoaded.get()) {
                        if (WXAMapViewComponent.this.mMapView != null) {
                            WXAMapViewComponent.this.mMapView.onCameraChangeFinish(cameraPosition);
                        }
                        WXAMapViewComponent.this.isChangeStart = false;
                        if (WXAMapViewComponent.this.isSetUpdate) {
                            WXAMapViewComponent.this.mCameraType = "update";
                        } else if (cameraPosition.zoom != WXAMapViewComponent.this.mZoomLevel) {
                            WXAMapViewComponent.this.mCameraType = "scale";
                        } else {
                            WXAMapViewComponent.this.mCameraType = "drag";
                        }
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BINDREGION_CHANGE, "end");
                    }
                    WXAMapViewComponent.this.isSetUpdate = false;
                }
            });
            this.mAMap.setOnMapTouchListener(new AMap.OnMapTouchListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass8 */

                @Override // com.amap.api.maps.AMap.OnMapTouchListener
                public void onTouch(MotionEvent motionEvent) {
                    int action = motionEvent.getAction();
                    if (action == 1) {
                        if (WXAMapViewComponent.this.mDragged) {
                            WXAMapViewComponent.this.getInstance().fireEvent(WXAMapViewComponent.this.getRef(), Constant.EVENT.DRAG_CHANGE);
                        }
                        WXAMapViewComponent.this.mDragged = false;
                    } else if (action == 2) {
                        WXAMapViewComponent.this.mDragged = true;
                        WXAMapViewComponent.this.isSetUpdate = false;
                    }
                }
            });
            this.mAMap.setOnPOIClickListener(new AMap.OnPOIClickListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass9 */

                @Override // com.amap.api.maps.AMap.OnPOIClickListener
                public void onPOIClick(Poi poi) {
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put("name", (Object) poi.getName());
                    jSONObject.put(Constant.JSONKEY.LONGITUDE, (Object) Double.valueOf(poi.getCoordinate().longitude));
                    jSONObject.put(Constant.JSONKEY.LATITUDE, (Object) Double.valueOf(poi.getCoordinate().latitude));
                    WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_POI_TAP, jSONObject);
                }
            });
            setUpMap();
        }
    }

    private void setUpMap() {
        this.mAMap.showBuildings(this.isBuilding3D);
        this.mAMap.moveCamera(CameraUpdateFactory.zoomTo(this.mZoomLevel));
        UiSettings uiSettings = this.mAMap.getUiSettings();
        this.mUiSettings = uiSettings;
        uiSettings.setZoomGesturesEnabled(this.isZoomEnable);
        this.mUiSettings.setCompassEnabled(this.isCompassEnable);
        this.mUiSettings.setRotateGesturesEnabled(this.isRotateEnable);
        this.mUiSettings.setScrollGesturesEnabled(this.isScrollEnable);
        this.mUiSettings.setZoomControlsEnabled(false);
        this.mUiSettings.setTiltGesturesEnabled(this.isOverLookingEnable);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateAttrs(Map<String, Object> map) {
        super.updateAttrs(map);
        if (map.containsKey(Constant.JSONKEY.LONGITUDE) || map.containsKey(Constant.JSONKEY.LATITUDE)) {
            updateCenter(getAttrs().get(Constant.JSONKEY.LATITUDE), getAttrs().get(Constant.JSONKEY.LONGITUDE));
        }
    }

    public void updateCenter(final Object obj, final Object obj2) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass10 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.setCenter(obj, obj2);
            }
        });
    }

    @Override // io.dcloud.feature.weex_amap.adapter.MapInterface
    public void setCenter(Object obj, Object obj2) {
        LatLng crateLatLng = MapResourceUtils.crateLatLng(obj, obj2);
        if (crateLatLng != null) {
            this.mMapCenterPoint.update(crateLatLng.latitude, crateLatLng.longitude);
            this.mAMap.moveCamera(CameraUpdateFactory.changeLatLng(crateLatLng));
        }
    }

    @UniComponentProp(name = "scale")
    public void setScale(final float f) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass11 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.mZoomLevel = f;
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.mAMap.moveCamera(CameraUpdateFactory.zoomTo(f));
                WXAMapViewComponent.this.mMarkerMgr.refreshCalloutVisible();
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SHOW_COMPASS)
    public void setCompass(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass12 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isCompassEnable = z;
                WXAMapViewComponent.this.mUiSettings.setCompassEnabled(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_SATELLITE)
    public void setEnableSatellite(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass13 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isEnableSatellite = z;
                if (WXAMapViewComponent.this.isEnableSatellite) {
                    AMap aMap = WXAMapViewComponent.this.mAMap;
                    AMap unused = WXAMapViewComponent.this.mAMap;
                    aMap.setMapType(2);
                    return;
                }
                WXAMapViewComponent.this.mAMap.setMapType(1);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_TRAFFIC)
    public void setEnableTraffic(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass14 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isEnableTraffic = z;
                WXAMapViewComponent.this.mAMap.setTrafficEnabled(WXAMapViewComponent.this.isEnableTraffic);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SHOW_SCALE)
    public void showScale(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass15 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isShowScale = z;
                WXAMapViewComponent.this.mUiSettings.setScaleControlsEnabled(WXAMapViewComponent.this.isShowScale);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_ZOOM)
    public void setZoomEnable(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass16 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isZoomEnable = z;
                WXAMapViewComponent.this.mUiSettings.setZoomGesturesEnabled(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_SCROLL)
    public void setScrollEnable(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass17 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isScrollEnable = z;
                WXAMapViewComponent.this.mUiSettings.setScrollGesturesEnabled(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_ROTATE)
    public void setRotateEnable(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass18 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isRotateEnable = z;
                WXAMapViewComponent.this.mUiSettings.setRotateGesturesEnabled(z);
            }
        });
    }

    @UniComponentProp(name = "rotate")
    public void setRotate(final float f) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass19 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.mAMap.moveCamera(CameraUpdateFactory.changeBearing(f));
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SKEW)
    public void setSkew(final float f) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass20 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.mAMap.moveCamera(CameraUpdateFactory.changeTilt(f));
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_OVERLOOKING)
    public void setOverLookingEnable(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass21 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isOverLookingEnable = z;
                WXAMapViewComponent.this.mUiSettings.setTiltGesturesEnabled(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_POI)
    public void setEnablePoi(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass22 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isEnablePoi = z;
                wXMapView.getMap().showMapText(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_BUILDING)
    public void setEnableBuilding(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass23 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isBuilding3D = z;
                wXMapView.getMap().showBuildings(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_INDOOR_MAP)
    public void setEnableIndoorMap(final boolean z) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass24 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                WXAMapViewComponent.this.isEnableIndoorMap = z;
                wXMapView.getMap().showIndoorMap(z);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.KEYS)
    public void setApiKey(String str) throws Exception {
        String string = JSON.parseObject(str).getString(WXEnvironment.OS);
        if (!TextUtils.isEmpty(string)) {
            MapsInitializer.setApiKey(string);
            AMapLocationClient.setApiKey(string);
            UniLogUtils.d(TAG, "Set API key success");
        }
    }

    @UniComponentProp(name = Constant.Name.MARKERS)
    public void setMarkers(final JSONArray jSONArray) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass25 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mMarkerMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mMarkerMgr = new MarkerMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                try {
                    WXAMapViewComponent.this.mMarkerMgr.setMarkers(jSONArray, true);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }

    @UniComponentProp(name = Constant.Name.POLYLINE)
    public void setPolyline(final JSONArray jSONArray) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass26 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mPolylineMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mPolylineMgr = new PolylineMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                WXAMapViewComponent.this.mPolylineMgr.setPolyline(jSONArray);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.POLYGONS)
    public void setPolygon(final JSONArray jSONArray) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass27 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mPolygonMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mPolygonMgr = new PolygonMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                WXAMapViewComponent.this.mPolygonMgr.setPolygon(jSONArray);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.CIRCLES)
    public void setCircles(final JSONArray jSONArray) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass28 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mCircleMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mCircleMgr = new CircleMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                WXAMapViewComponent.this.mCircleMgr.setCircles(jSONArray);
            }
        });
    }

    @UniComponentProp(name = "controls")
    public void setcontrols(final JSONArray jSONArray) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass29 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mControlMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mControlMgr = new ControlMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.getRef(), WXAMapViewComponent.this.mMapView, WXAMapViewComponent.this.mMapContainer);
                }
                WXAMapViewComponent.this.mControlMgr.setControls(jSONArray);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SETTING)
    public void setSetting(final JSONObject jSONObject) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass30 */

            /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
            /* JADX WARNING: Removed duplicated region for block: B:53:0x00bc A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:54:0x00be A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:55:0x00cb A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:56:0x00d8 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:57:0x00e5 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:58:0x00f2 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:59:0x00ff A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:60:0x010b A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:61:0x0117 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:62:0x0123 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:63:0x0131 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:64:0x013d A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:65:0x0149 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:66:0x0155 A[Catch:{ Exception -> 0x016f }] */
            /* JADX WARNING: Removed duplicated region for block: B:67:0x0161 A[Catch:{ Exception -> 0x016f }] */
            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                Iterator<String> it;
                char c;
                Iterator<String> it2 = jSONObject.keySet().iterator();
                while (it2.hasNext()) {
                    String next = it2.next();
                    try {
                        it = it2;
                        switch (next.hashCode()) {
                            case -1914923955:
                                if (next.equals(Constant.Name.SHOW_SCALE)) {
                                    c = 3;
                                    switch (c) {
                                        case 0:
                                            WXAMapViewComponent.this.setSkew(jSONObject.getFloatValue(Constant.Name.SKEW));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 1:
                                            WXAMapViewComponent.this.setRotate(jSONObject.getFloatValue("rotate"));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 2:
                                            WXAMapViewComponent.this.showMyLocation(jSONObject.getBooleanValue(Constant.Name.SHOW_LOCATION));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 3:
                                            WXAMapViewComponent.this.showScale(jSONObject.getBooleanValue(Constant.Name.SHOW_SCALE));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 4:
                                            WXAMapViewComponent.this.setApiKey(jSONObject.getString(Constant.Name.KEYS));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 5:
                                            WXAMapViewComponent.this.setLayerStyle(jSONObject.getString("styleId"));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 6:
                                            WXAMapViewComponent.this.setZoomEnable(jSONObject.getBooleanValue(Constant.Name.ENABLE_ZOOM));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 7:
                                            WXAMapViewComponent.this.setScrollEnable(jSONObject.getBooleanValue(Constant.Name.ENABLE_SCROLL));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\b':
                                            WXAMapViewComponent.this.setRotateEnable(jSONObject.getBooleanValue(Constant.Name.ENABLE_ROTATE));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\t':
                                            WXAMapViewComponent.this.setCompass(jSONObject.getBooleanValue(Constant.Name.SHOW_COMPASS));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\n':
                                            WXAMapViewComponent.this.setEnableBuilding(jSONObject.getBooleanValue(Constant.Name.ENABLE_BUILDING));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 11:
                                            WXAMapViewComponent.this.setOverLookingEnable(jSONObject.getBooleanValue(Constant.Name.ENABLE_OVERLOOKING));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\f':
                                            WXAMapViewComponent.this.setEnableSatellite(jSONObject.getBooleanValue(Constant.Name.ENABLE_SATELLITE));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\r':
                                            WXAMapViewComponent.this.setEnableTraffic(jSONObject.getBooleanValue(Constant.Name.ENABLE_TRAFFIC));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        default:
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -1720352578:
                                if (next.equals(Constant.Name.ENABLE_ROTATE)) {
                                    c = '\b';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -1702852048:
                                if (next.equals(Constant.Name.ENABLE_SCROLL)) {
                                    c = 7;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -1086756521:
                                if (next.equals(Constant.Name.ENABLE_BUILDING)) {
                                    c = '\n';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -925180581:
                                if (next.equals("rotate")) {
                                    c = 1;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -891537377:
                                if (next.equals(Constant.Name.KEYS)) {
                                    c = 4;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -58850592:
                                if (next.equals(Constant.Name.LAYER_STYLE)) {
                                    c = 5;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 3532042:
                                if (next.equals(Constant.Name.SKEW)) {
                                    c = 0;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 52161274:
                                if (next.equals(Constant.Name.ENABLE_TRAFFIC)) {
                                    c = '\r';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 491538168:
                                if (next.equals(Constant.Name.ENABLE_SATELLITE)) {
                                    c = '\f';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1049072082:
                                if (next.equals(Constant.Name.SHOW_LOCATION)) {
                                    c = 2;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1302710284:
                                if (next.equals(Constant.Name.ENABLE_OVERLOOKING)) {
                                    c = 11;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1338643285:
                                if (next.equals(Constant.Name.SHOW_COMPASS)) {
                                    c = '\t';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1893417974:
                                try {
                                    if (next.equals(Constant.Name.ENABLE_ZOOM)) {
                                        c = 6;
                                        switch (c) {
                                        }
                                    }
                                    c = 65535;
                                    switch (c) {
                                    }
                                } catch (Exception unused) {
                                    break;
                                }
                            default:
                                c = 65535;
                                switch (c) {
                                }
                        }
                    } catch (Exception unused2) {
                        it = it2;
                    }
                    it2 = it;
                }
                WXAMapViewComponent.this.isSetUpdate = true;
            }
        });
    }

    @UniComponentProp(name = Constant.Name.MIN_SCALE)
    public void setMinScale(final String str) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass31 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                int i = WXUtils.getInt(str);
                if (i >= 3 && i < 20) {
                    wXMapView.getMap().setMinZoomLevel((float) i);
                }
            }
        });
    }

    @UniComponentProp(name = Constant.Name.MAX_SCALE)
    public void setMaxScale(final String str) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass32 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                int i = WXUtils.getInt(str);
                if (i > 3 && i <= 20) {
                    wXMapView.getMap().setMaxZoomLevel((float) i);
                }
            }
        });
    }

    @UniComponentProp(name = Constant.Name.LAYER_STYLE)
    public void setLayerStyle(final String str) {
        if (!PdrUtil.isEmpty(str)) {
            postTask(new MapOperationTask() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass33 */

                @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
                public void execute(WXMapView wXMapView) {
                    CustomMapStyleOptions customMapStyleOptions = new CustomMapStyleOptions();
                    customMapStyleOptions.setEnable(true);
                    customMapStyleOptions.setStyleId(str);
                    wXMapView.getMap().setCustomMapStyle(customMapStyleOptions);
                }
            });
        }
    }

    @UniComponentProp(name = Constant.Name.SHOW_LOCATION)
    public void showMyLocation(final boolean z) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass34 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (!z) {
                    wXMapView.getMap().setMyLocationEnabled(false);
                    wXMapView.getMap().setOnMyLocationChangeListener(null);
                } else if (WXAMapViewComponent.this.mMyLocationCallBack == null && WXAMapViewComponent.this.requestPermissions()) {
                    WXAMapViewComponent.this.mMyLocationCallBack = new AMap.OnMyLocationChangeListener() {
                        /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass34.AnonymousClass1 */

                        @Override // com.amap.api.maps.AMap.OnMyLocationChangeListener
                        public void onMyLocationChange(Location location) {
                            if (!WXAMapViewComponent.this.equalsLocation(WXAMapViewComponent.this.mMyLocation, location)) {
                                WXAMapViewComponent.this.mMyLocation = location;
                                WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_USER_LOCATION_CHANGE, location);
                            }
                        }
                    };
                    wXMapView.getMap().setMyLocationEnabled(true);
                    wXMapView.getMap().setOnMyLocationChangeListener(WXAMapViewComponent.this.mMyLocationCallBack);
                    if (WXAMapViewComponent.this.myLocationStyle == null) {
                        WXAMapViewComponent.this.myLocationStyle = new MyLocationStyle();
                    }
                    wXMapView.getMap().setMyLocationStyle(WXAMapViewComponent.this.myLocationStyle.myLocationType(5));
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean equalsLocation(Location location, Location location2) {
        return location != null && location2 != null && location.getLatitude() == location2.getLatitude() && location.getLongitude() == location2.getLongitude() && location.getBearing() == location2.getBearing();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean equalsMyLocationMarker(LatLng latLng) {
        AMap aMap;
        if (!(latLng == null || (aMap = this.mAMap) == null || !aMap.isMyLocationEnabled())) {
            Location myLocation = this.mAMap.getMyLocation();
            if (latLng.latitude == myLocation.getLatitude() && latLng.longitude == myLocation.getLongitude()) {
                return true;
            }
            return false;
        }
        return false;
    }

    @UniComponentProp(name = Constant.Name.INCLUDE_POINTS)
    public void setincludePoints(JSONArray jSONArray) throws Exception {
        setincludePoints(jSONArray, 0);
    }

    public void setincludePoints(final JSONArray jSONArray, final int i) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass35 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                ArrayList<LatLng> crateLatLngs = MapResourceUtils.crateLatLngs(jSONArray);
                if (crateLatLngs.size() > 0) {
                    LatLngBounds.Builder builder = new LatLngBounds.Builder();
                    Iterator<LatLng> it = crateLatLngs.iterator();
                    while (it.hasNext()) {
                        builder.include(it.next());
                    }
                    wXMapView.getMap().animateCamera(CameraUpdateFactory.newLatLngBounds(builder.build(), i));
                }
                WXAMapViewComponent.this.isSetUpdate = true;
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireEventMapEvent(String str, Object obj) {
        Map<String, Object> hashMap = new HashMap<>();
        str.hashCode();
        char c = 65535;
        switch (str.hashCode()) {
            case -1959236561:
                if (str.equals(Constant.EVENT.BIND_LABEL_TAP)) {
                    c = 0;
                    break;
                }
                break;
            case -1903828621:
                if (str.equals(Constant.EVENT.BIND_CALLOUT_TAP)) {
                    c = 1;
                    break;
                }
                break;
            case -1777599032:
                if (str.equals(Constant.EVENT.BIND_ANCHOR_POINT_TAP)) {
                    c = 2;
                    break;
                }
                break;
            case -1185205340:
                if (str.equals(Constant.EVENT.BINDREGION_CHANGE)) {
                    c = 3;
                    break;
                }
                break;
            case -982748903:
                if (str.equals(Constant.EVENT.BIND_POI_TAP)) {
                    c = 4;
                    break;
                }
                break;
            case -933820119:
                if (str.equals(Constant.EVENT.BIND_MARKER_TAP)) {
                    c = 5;
                    break;
                }
                break;
            case -234430277:
                if (str.equals(Constant.EVENT.UPDATED)) {
                    c = 6;
                    break;
                }
                break;
            case 114595:
                if (str.equals(Constant.EVENT.BINDTAP)) {
                    c = 7;
                    break;
                }
                break;
            case 599278640:
                if (str.equals(Constant.EVENT.BIND_USER_LOCATION_CHANGE)) {
                    c = '\b';
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                if (containsEvent(Constant.EVENT.BIND_LABEL_TAP)) {
                    if (obj != null) {
                        hashMap.put("detail", obj);
                    }
                    fireEvent(Constant.EVENT.BIND_LABEL_TAP, hashMap);
                    return;
                }
                return;
            case 1:
                if (obj != null) {
                    hashMap.put("detail", obj);
                }
                fireEvent(Constant.EVENT.BIND_CALLOUT_TAP, hashMap);
                return;
            case 2:
                if (containsEvent(Constant.EVENT.BIND_ANCHOR_POINT_TAP) && obj != null) {
                    hashMap.put("detail", obj);
                    fireEvent(Constant.EVENT.BIND_ANCHOR_POINT_TAP, hashMap);
                    return;
                }
                return;
            case 3:
                if (containsEvent(Constant.EVENT.BINDREGION_CHANGE)) {
                    hashMap.put("type", obj);
                    hashMap.put("causedBy", this.mCameraType);
                    if (((String) obj).equals("end")) {
                        JSONObject jSONObject = new JSONObject();
                        jSONObject.put("rotate", (Object) Float.valueOf(this.mAMap.getCameraPosition().bearing));
                        jSONObject.put(Constant.Name.SKEW, (Object) Float.valueOf(this.mAMap.getCameraPosition().tilt));
                        hashMap.put("detail", jSONObject);
                    }
                    fireEvent(Constant.EVENT.BINDREGION_CHANGE, hashMap);
                    return;
                }
                return;
            case 4:
                if (containsEvent(Constant.EVENT.BIND_POI_TAP)) {
                    hashMap.put("detail", obj);
                    fireEvent(Constant.EVENT.BIND_POI_TAP, hashMap);
                    return;
                }
                return;
            case 5:
                if (obj != null) {
                    hashMap.put("detail", obj);
                }
                fireEvent(Constant.EVENT.BIND_MARKER_TAP, hashMap);
                return;
            case 6:
                if (containsEvent(Constant.EVENT.UPDATED)) {
                    hashMap.put("timeStamp", Long.valueOf(System.currentTimeMillis() - this.mLoadTime));
                    hashMap.put("type", Constant.EVENT.UPDATED);
                    fireEvent(Constant.EVENT.UPDATED, hashMap);
                    return;
                }
                return;
            case 7:
                if (containsEvent(Constant.EVENT.BINDTAP)) {
                    if (obj != null) {
                        hashMap.put("detail", obj);
                    }
                    hashMap.put("type", Constant.EVENT.BINDTAP);
                    fireEvent(Constant.EVENT.BINDTAP, hashMap);
                    return;
                }
                return;
            case '\b':
                if (containsEvent(Constant.EVENT.BIND_USER_LOCATION_CHANGE) && obj != null && (obj instanceof Location)) {
                    Location location = (Location) obj;
                    hashMap.put(Constant.JSONKEY.LATITUDE, Double.valueOf(location.getLatitude()));
                    hashMap.put(Constant.JSONKEY.LONGITUDE, Double.valueOf(location.getLongitude()));
                    fireEvent(Constant.EVENT.BIND_USER_LOCATION_CHANGE, hashMap);
                    return;
                }
                return;
            default:
                return;
        }
    }

    @UniJSMethod
    public void getCenterLocation(UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        if (this.isMapLoaded.get()) {
            hashMap.put("type", WXImage.SUCCEED);
            hashMap.put(Constant.JSONKEY.LATITUDE, Double.valueOf(this.mMapCenterPoint.latitude));
            hashMap.put(Constant.JSONKEY.LONGITUDE, Double.valueOf(this.mMapCenterPoint.longitude));
        } else {
            hashMap.put("type", Constants.Event.FAIL);
        }
        if (uniJSCallback != null) {
            uniJSCallback.invoke(hashMap);
        }
    }

    @UniJSMethod
    public void getRegion(UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        if (this.isMapLoaded.get()) {
            LatLngBounds latLngBounds = this.mAMap.getProjection().getVisibleRegion().latLngBounds;
            hashMap.put("type", WXImage.SUCCEED);
            hashMap.put("northeast", latLngBounds.northeast);
            hashMap.put("southwest", latLngBounds.southwest);
        } else {
            hashMap.put("type", Constants.Event.FAIL);
        }
        if (uniJSCallback != null) {
            uniJSCallback.invoke(hashMap);
        }
    }

    @UniJSMethod
    public void getScale(UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        if (this.isMapLoaded.get()) {
            hashMap.put("type", WXImage.SUCCEED);
            hashMap.put("scale", Float.valueOf(this.mAMap.getCameraPosition().zoom));
        } else {
            hashMap.put("type", Constants.Event.FAIL);
        }
        if (uniJSCallback != null) {
            uniJSCallback.invoke(hashMap);
        }
    }

    @UniJSMethod
    public void getRotate(UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        if (this.isMapLoaded.get()) {
            hashMap.put("type", WXImage.SUCCEED);
            hashMap.put("rotate", Float.valueOf(this.mAMap.getCameraPosition().bearing));
        } else {
            hashMap.put("type", Constants.Event.FAIL);
        }
        if (uniJSCallback != null) {
            uniJSCallback.invoke(hashMap);
        }
    }

    @UniJSMethod
    public void getSkew(UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        if (this.isMapLoaded.get()) {
            hashMap.put("type", WXImage.SUCCEED);
            hashMap.put(Constant.Name.SKEW, Float.valueOf(this.mAMap.getCameraPosition().tilt));
        } else {
            hashMap.put("type", Constants.Event.FAIL);
        }
        if (uniJSCallback != null) {
            uniJSCallback.invoke(hashMap);
        }
    }

    @UniJSMethod
    public void includePoints(JSONObject jSONObject, UniJSCallback uniJSCallback) throws Exception {
        HashMap hashMap = new HashMap();
        if (!this.isMapLoaded.get() || jSONObject == null) {
            hashMap.put("type", Constants.Event.FAIL);
        } else {
            JSONArray jSONArray = jSONObject.getJSONArray("points");
            JSONArray jSONArray2 = jSONObject.getJSONArray("padding");
            int i = 20;
            if (jSONArray2 != null) {
                i = jSONArray2.getIntValue(0);
            }
            setincludePoints(jSONArray, i);
            hashMap.put("type", WXImage.SUCCEED);
            hashMap.put("scale", Float.valueOf(this.mZoomLevel));
        }
        if (uniJSCallback != null) {
            uniJSCallback.invoke(hashMap);
        }
    }

    @UniJSMethod
    public void moveToLocation(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass36 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                LatLng latLng;
                HashMap hashMap = new HashMap();
                Location myLocation = wXMapView.getMap().getMyLocation();
                JSONObject jSONObject = jSONObject;
                if (jSONObject != null) {
                    latLng = MapResourceUtils.crateLatLng(jSONObject);
                } else {
                    latLng = myLocation != null ? new LatLng(myLocation.getLatitude(), myLocation.getLongitude()) : null;
                }
                if (latLng != null) {
                    wXMapView.getMap().animateCamera(CameraUpdateFactory.changeLatLng(latLng));
                    hashMap.put("type", WXImage.SUCCEED);
                } else {
                    hashMap.put("type", Constants.Event.FAIL);
                }
                UniJSCallback uniJSCallback = uniJSCallback;
                if (uniJSCallback != null) {
                    uniJSCallback.invoke(hashMap);
                }
            }
        });
    }

    @UniJSMethod
    public void translateMarker(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass37 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    WXAMapViewComponent.this.mMarkerMgr.translateMarker(jSONObject, uniJSCallback);
                }
            }
        });
    }

    @UniJSMethod
    public void initMarkerCluster(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass38 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                HashMap hashMap = new HashMap();
                if (wXMapView.getClusterOverlay() == null) {
                    wXMapView.createClusterOverlay(jSONObject);
                    hashMap.put("type", WXImage.SUCCEED);
                    UniJSCallback uniJSCallback = uniJSCallback;
                    if (uniJSCallback != null) {
                        uniJSCallback.invoke(hashMap);
                        return;
                    }
                    return;
                }
                hashMap.put("type", WXImage.SUCCEED);
                UniJSCallback uniJSCallback2 = uniJSCallback;
                if (uniJSCallback2 != null) {
                    uniJSCallback2.invoke(hashMap);
                }
            }
        });
    }

    @UniJSMethod
    public void addMarkers(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass39 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mMarkerMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mMarkerMgr = new MarkerMgr(wXAMapViewComponent.getInstance(), wXMapView);
                }
                HashMap hashMap = new HashMap();
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    if (jSONObject.containsKey("clear") && jSONObject.getBoolean("clear").booleanValue()) {
                        WXAMapViewComponent.this.mMarkerMgr.destroy();
                    }
                    if (jSONObject.containsKey(Constant.Name.MARKERS)) {
                        try {
                            WXAMapViewComponent.this.mMarkerMgr.setMarkers(jSONObject.getJSONArray(Constant.Name.MARKERS), false);
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                    hashMap.put("type", WXImage.SUCCEED);
                    UniJSCallback uniJSCallback = uniJSCallback;
                    if (uniJSCallback != null) {
                        uniJSCallback.invoke(hashMap);
                    }
                }
            }
        });
    }

    @UniJSMethod
    public void removeMarkers(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass40 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    HashMap hashMap = new HashMap();
                    if (jSONObject.containsKey("markerIds")) {
                        try {
                            WXAMapViewComponent.this.mMarkerMgr.removeMarkers(jSONObject.getJSONArray("markerIds"));
                            hashMap.put("type", WXImage.SUCCEED);
                            UniJSCallback uniJSCallback = uniJSCallback;
                            if (uniJSCallback != null) {
                                uniJSCallback.invoke(hashMap);
                            }
                        } catch (Exception e) {
                            e.printStackTrace();
                            hashMap.put("type", Constants.Event.FAIL);
                            UniJSCallback uniJSCallback2 = uniJSCallback;
                            if (uniJSCallback2 != null) {
                                uniJSCallback2.invoke(hashMap);
                            }
                        }
                    } else {
                        hashMap.put("type", Constants.Event.FAIL);
                        UniJSCallback uniJSCallback3 = uniJSCallback;
                        if (uniJSCallback3 != null) {
                            uniJSCallback3.invoke(hashMap);
                        }
                    }
                }
            }
        });
    }

    @UniJSMethod
    public void on(final String str, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass41 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(final WXMapView wXMapView) {
                String str = str;
                str.hashCode();
                if (str.equals("markerClusterCreate")) {
                    wXMapView.setClusterCreateListener(new OnClusterCreateListener() {
                        /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass41.AnonymousClass1 */
                        String mCreateCallBackData;

                        @Override // io.dcloud.feature.weex_amap.adapter.cluster.OnClusterCreateListener
                        public void onClusterCreate(List<Cluster> list) {
                            if (list.size() > 0) {
                                JSONArray jSONArray = new JSONArray();
                                for (Cluster cluster : list) {
                                    jSONArray.add(wXMapView.getClusterInfo(cluster));
                                }
                                if (this.mCreateCallBackData == null) {
                                    JSONObject jSONObject = new JSONObject();
                                    jSONObject.put("clusters", (Object) jSONArray);
                                    uniJSCallback.invokeAndKeepAlive(jSONObject);
                                    this.mCreateCallBackData = jSONArray.toJSONString();
                                } else if (!jSONArray.toJSONString().equals(this.mCreateCallBackData)) {
                                    JSONObject jSONObject2 = new JSONObject();
                                    jSONObject2.put("clusters", (Object) jSONArray);
                                    uniJSCallback.invokeAndKeepAlive(jSONObject2);
                                    this.mCreateCallBackData = jSONArray.toJSONString();
                                }
                            } else {
                                this.mCreateCallBackData = null;
                            }
                        }
                    });
                } else if (str.equals("markerClusterClick")) {
                    wXMapView.setClusterClickListener(new OnClusterClickListener() {
                        /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass41.AnonymousClass2 */

                        @Override // io.dcloud.feature.weex_amap.adapter.cluster.OnClusterClickListener
                        public void onClick(Marker marker, Cluster cluster) {
                            if (uniJSCallback != null) {
                                uniJSCallback.invokeAndKeepAlive(wXMapView.getClusterInfo(cluster));
                            }
                        }
                    });
                }
            }
        });
    }

    @UniJSMethod
    public void moveAlong(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass42 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    HashMap hashMap = new HashMap();
                    if (jSONObject.containsKey("markerId")) {
                        WXAMapViewComponent.this.mMarkerMgr.moveAlongMarker(jSONObject, uniJSCallback);
                        return;
                    }
                    hashMap.put("type", Constants.Event.FAIL);
                    UniJSCallback uniJSCallback = uniJSCallback;
                    if (uniJSCallback != null) {
                        uniJSCallback.invoke(hashMap);
                    }
                }
            }
        });
    }

    @UniJSMethod
    public void getUserLocation(final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass43 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                Location myLocation = wXMapView.getMap().getMyLocation();
                HashMap hashMap = new HashMap();
                if (myLocation != null) {
                    hashMap.put("type", WXImage.SUCCEED);
                    hashMap.put(Constant.JSONKEY.LATITUDE, Double.valueOf(myLocation.getLatitude()));
                    hashMap.put(Constant.JSONKEY.LONGITUDE, Double.valueOf(myLocation.getLongitude()));
                    uniJSCallback.invoke(hashMap);
                    return;
                }
                hashMap.put("type", Constants.Event.FAIL);
                uniJSCallback.invoke(hashMap);
            }
        });
    }

    @UniJSMethod
    public void addGroundOverlay(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass44 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mGroundMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mGroundMgr = new GroundMgr(wXAMapViewComponent.getInstance(), wXMapView);
                }
                WXAMapViewComponent.this.mGroundMgr.addGroundOverlay(jSONObject, uniJSCallback);
            }
        });
    }

    @UniJSMethod
    public void updateGroundOverlay(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass45 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                if (WXAMapViewComponent.this.mGroundMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mGroundMgr = new GroundMgr(wXAMapViewComponent.getInstance(), wXMapView);
                }
                WXAMapViewComponent.this.mGroundMgr.updateGroundOverlay(jSONObject, uniJSCallback);
            }
        });
    }

    @UniJSMethod
    public void removeGroundOverlay(final JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass46 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView wXMapView) {
                JSONObject jSONObject = jSONObject;
                if (jSONObject != null && jSONObject.containsKey("id")) {
                    if (WXAMapViewComponent.this.mGroundMgr == null) {
                        WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                        wXAMapViewComponent.mGroundMgr = new GroundMgr(wXAMapViewComponent.getInstance(), wXMapView);
                    }
                    WXAMapViewComponent.this.mGroundMgr.removeGroundOverlay(jSONObject.getString("id"), uniJSCallback);
                } else if (uniJSCallback != null) {
                    HashMap hashMap = new HashMap();
                    hashMap.put("type", Constants.Event.FAIL);
                    hashMap.put(NotificationCompat.CATEGORY_MESSAGE, "Parameter exception");
                    uniJSCallback.invoke(hashMap);
                }
            }
        });
    }

    @UniJSMethod
    public void openMapApp(JSONObject jSONObject, UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        try {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("geo:");
            stringBuffer.append(jSONObject.getDoubleValue(Constant.JSONKEY.LATITUDE));
            stringBuffer.append(",");
            stringBuffer.append(jSONObject.getDoubleValue(Constant.JSONKEY.LATITUDE));
            stringBuffer.append(Operators.CONDITION_IF_STRING);
            stringBuffer.append("q=");
            stringBuffer.append(jSONObject.getString("destination"));
            getInstance().getContext().startActivity(new Intent("android.intent.action.VIEW", Uri.parse(stringBuffer.toString())));
            hashMap.put("type", WXImage.SUCCEED);
            if (uniJSCallback != null) {
                uniJSCallback.invoke(hashMap);
            }
        } catch (Exception unused) {
            hashMap.put("type", Constants.Event.FAIL);
            if (uniJSCallback != null) {
                uniJSCallback.invoke(hashMap);
            }
        }
    }

    @UniJSMethod
    public void setLocMarkerIcon(JSONObject jSONObject, final UniJSCallback uniJSCallback) {
        final HashMap hashMap = new HashMap();
        String string = jSONObject.getString(Constant.JSONKEY.ICONPATH);
        if (PdrUtil.isEmpty(string)) {
            hashMap.put("type", Constants.Event.FAIL);
            hashMap.put(NotificationCompat.CATEGORY_MESSAGE, "iconPath is null");
            if (uniJSCallback != null) {
                uniJSCallback.invoke(hashMap);
                return;
            }
            return;
        }
        Uri rewriteUri = getInstance().rewriteUri(Uri.parse(string), "image");
        if (rewriteUri == null) {
            hashMap.put("type", Constants.Event.FAIL);
            hashMap.put(NotificationCompat.CATEGORY_MESSAGE, "iconPath exception");
            if (uniJSCallback != null) {
                uniJSCallback.invoke(hashMap);
                return;
            }
            return;
        }
        FrescoLoadUtil.getInstance().loadImageBitmap(getContext(), rewriteUri.toString(), new BitmapLoadCallback<Bitmap>() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass47 */

            public void onSuccess(String str, final Bitmap bitmap) {
                MessageHandler.post(new Runnable() {
                    /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass47.AnonymousClass1 */

                    public void run() {
                        if (WXAMapViewComponent.this.myLocationStyle == null || bitmap == null || WXAMapViewComponent.this.mMapView == null || WXAMapViewComponent.this.mMapView.getMap() == null) {
                            hashMap.put("type", Constants.Event.FAIL);
                            hashMap.put(NotificationCompat.CATEGORY_MESSAGE, "unknown error");
                            if (uniJSCallback != null) {
                                uniJSCallback.invoke(hashMap);
                                return;
                            }
                            return;
                        }
                        WXAMapViewComponent.this.myLocationStyle.myLocationIcon(BitmapDescriptorFactory.fromBitmap(bitmap));
                        WXAMapViewComponent.this.mMapView.getMap().setMyLocationStyle(WXAMapViewComponent.this.myLocationStyle.myLocationType(5));
                        hashMap.put("type", WXImage.SUCCEED);
                        if (uniJSCallback != null) {
                            uniJSCallback.invoke(hashMap);
                        }
                    }
                });
            }

            @Override // io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback
            public void onFailure(String str, Throwable th) {
                hashMap.put("type", Constants.Event.FAIL);
                hashMap.put(NotificationCompat.CATEGORY_MESSAGE, th.toString());
                UniJSCallback uniJSCallback = uniJSCallback;
                if (uniJSCallback != null) {
                    uniJSCallback.invoke(hashMap);
                }
            }
        });
        if (this.myLocationStyle == null) {
            this.myLocationStyle = new MyLocationStyle();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityCreate() {
        super.onActivityCreate();
        UniLogUtils.e(TAG, "onActivityCreate");
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityPause() {
        WXMapView wXMapView = this.mMapView;
        if (wXMapView != null) {
            wXMapView.onPause();
        }
        UniLogUtils.e(TAG, "onActivityPause");
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        WXMapView wXMapView = this.mMapView;
        if (wXMapView != null) {
            wXMapView.onResume();
        }
        UniLogUtils.e(TAG, "onActivityResume");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean requestPermissions() {
        if (Build.VERSION.SDK_INT < 23) {
            return true;
        }
        Activity activity = this.mActivity;
        if (activity != null) {
            if (checkPermissions(activity, permissions)) {
                return true;
            }
            PermissionUtil.requestSystemPermissions(this.mActivity, permissions, REQUEST_CODE_MAPVIEW, new PermissionUtil.Request() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass48 */

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String str) {
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String str) {
                    for (int i = 0; i < WXAMapViewComponent.permissions.length; i++) {
                        if ("android.permission.ACCESS_FINE_LOCATION".equals(WXAMapViewComponent.permissions[i])) {
                            WXAMapViewComponent.this.showMyLocation(true);
                        }
                    }
                }
            });
        }
        return false;
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityDestroy() {
        onActivityPause();
        WXMapView wXMapView = this.mMapView;
        if (wXMapView != null) {
            wXMapView.setVisibility(8);
            MarkerMgr markerMgr = this.mMarkerMgr;
            if (markerMgr != null) {
                markerMgr.destroy();
            }
            GroundMgr groundMgr = this.mGroundMgr;
            if (groundMgr != null) {
                groundMgr.destroy();
            }
            this.mMapView.destroy();
            this.mMapContainer.removeView(this.mMapView);
            this.mMyLocation = null;
            this.mAMap.clear();
        }
        AMapLocationClient aMapLocationClient = this.mLocationClient;
        if (aMapLocationClient != null) {
            aMapLocationClient.onDestroy();
        }
        UniLogUtils.e(TAG, "onActivityDestroy");
    }

    public boolean checkPermissions(Activity activity, String[] strArr) {
        boolean z = true;
        if (strArr != null && strArr.length > 0) {
            for (String str : strArr) {
                if (ContextCompat.checkSelfPermission(activity, str) != 0) {
                    ActivityCompat.shouldShowRequestPermissionRationale(activity, str);
                    z = false;
                }
            }
        }
        return z;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void execPaddingTasks() {
        WXMapView wXMapView;
        if (getInstance() != null && getHostView() != null) {
            while (!this.paddingTasks.isEmpty()) {
                MapOperationTask poll = this.paddingTasks.poll();
                if (!(poll == null || (wXMapView = this.mMapView) == null || wXMapView.getMap() == null)) {
                    UniLogUtils.d(TAG, "Exec padding task " + poll.toString());
                    poll.execute(this.mMapView);
                }
            }
        }
    }

    public void postTask(MapOperationTask mapOperationTask) {
        if (this.mMapView == null || !this.isMapLoaded.get()) {
            UniLogUtils.d(TAG, "Padding task " + mapOperationTask.toString());
            this.paddingTasks.offer(mapOperationTask);
            return;
        }
        UniLogUtils.d(TAG, "Exec task " + mapOperationTask.toString());
        mapOperationTask.execute(this.mMapView);
    }

    /* access modifiers changed from: package-private */
    public class Point {
        private double latitude;
        private double longitude;

        public Point() {
        }

        public void update(double d, double d2) {
            this.latitude = d;
            this.longitude = d2;
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View view, int i) {
        if (view != null && getRealView() != null) {
            int childCount = getRealView().getChildCount();
            if (childCount >= 1 && (getRealView().getChildAt(0) instanceof WXMapView)) {
                i = i >= childCount ? 1 : i + 1;
            } else if (i >= childCount) {
                i = -1;
            }
            if (i == -1) {
                getRealView().addView(view);
            } else {
                getRealView().addView(view, i);
            }
            UniSDKInstance instance = getInstance();
            if (instance != null) {
                instance.getApmForInstance().hasAddView = true;
            }
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent wXComponent, int i) {
        Object obj;
        super.addChild(wXComponent, i);
        if ((wXComponent instanceof DCCoverViewComponent) && wXComponent != null && wXComponent.getAttrs() != null && wXComponent.getAttrs().containsKey("slot") && this.mMapView != null && (obj = wXComponent.getAttrs().get("slot")) != null && obj.equals(Constant.JSONKEY.CALLOUT)) {
            this.mMapView.setCoverViewCalloutComponetRef(wXComponent.getRef());
        }
    }
}
