package io.dcloud.js.map.amap.adapter;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import com.amap.api.maps.model.LatLng;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.ITypeofAble;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameItem;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.ViewOptions;
import io.dcloud.common.adapter.util.ViewRect;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.js.map.amap.IFMapDispose;
import io.dcloud.js.map.amap.JsMapManager;
import io.dcloud.js.map.amap.JsMapObject;
import java.util.ArrayList;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class DHMapFrameItem extends AdaFrameItem implements IFMapDispose, ISysEventListener, ITypeofAble {
    public static final int MSG_ADD_OVERLAY = 3;
    public static final int MSG_APPEND = 12;
    public static final int MSG_CENTER_ZOOM = 11;
    public static final int MSG_CLEAR_OVERLAY = 5;
    public static final int MSG_CREATE = 0;
    public static final int MSG_REMOVE_OVERLAY = 4;
    public static final int MSG_RESET = 6;
    public static final int MSG_SCALE = 1;
    public static final int MSG_SET_MAPTYPE = 8;
    public static final int MSG_SHOWLOCATION = 7;
    public static final int MSG_SHOWZOOMCONTROLS = 10;
    public static final int MSG_UPDATE_CENTER = 2;
    public static final int MSG_VISIBLE = 9;
    private String PERCENTAGE = "%";
    private MapPoint mCenter;
    private IWebview mContainerWebview;
    JsMapObject mJsMapView = null;
    private MapHandler mMapHandler;
    private DHMapView mMapView;
    private JSONArray mOptions;
    private ArrayList<Object> mOverlaysId;
    private String mPosition = "static";
    private LinearLayout mRootView;
    private boolean mShowUserLocation;
    private boolean mShowZoomControls;
    private boolean mTraffic;
    public String mUUID;
    private IWebview mWebview;
    private int mZoom = 12;
    private String mapType;

    public DHMapFrameItem(Context context, IWebview iWebview, JsMapObject jsMapObject) {
        super(context);
        this.mWebview = iWebview;
        this.mContainerWebview = iWebview;
        this.mJsMapView = jsMapObject;
        LinearLayout linearLayout = new LinearLayout(context);
        this.mRootView = linearLayout;
        setMainView(linearLayout);
        this.mMapHandler = new MapHandler(Looper.getMainLooper());
        this.mOverlaysId = new ArrayList<>();
        IApp obtainApp = this.mWebview.obtainFrameView().obtainApp();
        obtainApp.registerSysEventListener(this, ISysEventListener.SysEventType.onPause);
        obtainApp.registerSysEventListener(this, ISysEventListener.SysEventType.onResume);
        obtainApp.registerSysEventListener(this, ISysEventListener.SysEventType.onStop);
        obtainApp.registerSysEventListener(this, ISysEventListener.SysEventType.onSaveInstanceState);
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType sysEventType, Object obj) {
        if (PdrUtil.isEmpty(this.mMapView)) {
            return false;
        }
        if (sysEventType == ISysEventListener.SysEventType.onPause) {
            this.mMapView.onPause();
            this.mMapView.locationStop();
            return true;
        } else if (sysEventType == ISysEventListener.SysEventType.onResume) {
            this.mMapView.onResume();
            this.mMapView.locationReStart();
            return true;
        } else if (sysEventType == ISysEventListener.SysEventType.onStop) {
            this.mMapView.onDestroy();
            return true;
        } else if (sysEventType != ISysEventListener.SysEventType.onSaveInstanceState) {
            return false;
        } else {
            if (obj instanceof Bundle) {
                this.mMapView.onSaveInstanceState((Bundle) obj);
            }
            return true;
        }
    }

    private void setMapView(DHMapView dHMapView) {
        this.mMapView = dHMapView;
        this.mRootView.addView(dHMapView);
        this.mJsMapView.onAddToMapView(this.mMapView);
        this.mMapView.onCreate(null);
    }

    public DHMapView getMapView() {
        return this.mMapView;
    }

    public void setCenter(MapPoint mapPoint) {
        if (mapPoint != null) {
            this.mCenter = mapPoint;
            Message obtain = Message.obtain();
            obtain.what = 2;
            obtain.obj = this.mCenter;
            this.mMapHandler.sendMessage(obtain);
        }
    }

    public void setZoom(String str) {
        if (str == null) {
            str = "12";
        }
        try {
            int parseInt = Integer.parseInt(str);
            this.mZoom = parseInt;
            Message obtain = Message.obtain();
            obtain.what = 1;
            obtain.obj = Integer.valueOf(parseInt);
            this.mMapHandler.sendMessage(obtain);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void centerAndZoom(MapPoint mapPoint, String str) {
        if (str == null) {
            str = "12";
        }
        try {
            int parseInt = Integer.parseInt(str);
            if (mapPoint != null) {
                this.mCenter = mapPoint;
            }
            this.mZoom = parseInt;
            Message obtain = Message.obtain();
            obtain.what = 11;
            obtain.obj = new Object[]{Integer.valueOf(this.mZoom), this.mCenter};
            this.mMapHandler.sendMessage(obtain);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void setMapType(String str) {
        this.mapType = str;
        Message obtain = Message.obtain();
        obtain.what = 8;
        if ("MAPTYPE_SATELLITE".equals(str)) {
            obtain.obj = 1;
        } else {
            obtain.obj = 0;
        }
        this.mMapHandler.sendMessage(obtain);
    }

    public boolean isShowUserLocation() {
        return this.mShowUserLocation;
    }

    public void setShowUserLocation(String str) {
        this.mShowUserLocation = Boolean.parseBoolean(str);
        Message obtain = Message.obtain();
        obtain.what = 7;
        obtain.obj = Boolean.valueOf(this.mShowUserLocation);
        this.mMapHandler.sendMessage(obtain);
    }

    public void getUserLocation(IWebview iWebview, String str) {
        this.mMapView.getUserLocation(iWebview, str);
    }

    public void getCurrentCenter(IWebview iWebview, String str) {
        this.mMapView.getCurrentCenter(iWebview, str);
    }

    public boolean isShowZoomControls() {
        return this.mShowZoomControls;
    }

    public void setShowZoomControls(String str) {
        this.mShowZoomControls = Boolean.parseBoolean(str);
        Message obtain = Message.obtain();
        obtain.what = 10;
        obtain.obj = Boolean.valueOf(this.mShowZoomControls);
        this.mMapHandler.sendMessage(obtain);
    }

    public boolean isTraffic() {
        return this.mTraffic;
    }

    public void setTraffic(boolean z) {
        this.mTraffic = z;
        int i = z ? 1001 : 1002;
        Message obtain = Message.obtain();
        obtain.what = 8;
        obtain.obj = Integer.valueOf(i);
        this.mMapHandler.sendMessage(obtain);
    }

    public void addOverlay(Object obj) {
        if (obj != null) {
            this.mOverlaysId.add(obj);
            Message obtain = Message.obtain();
            obtain.what = 3;
            obtain.obj = obj;
            this.mMapHandler.sendMessage(obtain);
        }
    }

    public void removeOverlay(Object obj) {
        if (obj != null) {
            this.mOverlaysId.remove(obj);
            Message obtain = Message.obtain();
            obtain.what = 4;
            obtain.obj = obj;
            this.mMapHandler.sendMessage(obtain);
        }
    }

    public void clearOverlays() {
        Message obtain = Message.obtain();
        obtain.what = 5;
        this.mMapHandler.sendMessage(obtain);
    }

    public void reset() {
        if (this.mCenter != null) {
            Message obtain = Message.obtain();
            obtain.what = 6;
            obtain.obj = new Object[]{Integer.valueOf(this.mZoom), this.mCenter};
            this.mMapHandler.sendMessage(obtain);
        }
    }

    public void show() {
        Message obtain = Message.obtain();
        obtain.what = 9;
        obtain.obj = true;
        this.mMapHandler.sendMessage(obtain);
    }

    public void hide() {
        Message obtain = Message.obtain();
        obtain.what = 9;
        obtain.obj = false;
        this.mMapHandler.sendMessage(obtain);
    }

    public void createMap(JSONArray jSONArray) {
        this.mOptions = jSONArray;
        createMapFrameItem(jSONArray);
    }

    public void resize(JSONArray jSONArray) {
        ViewOptions obtainFrameOptions = ((AdaFrameItem) this.mContainerWebview.obtainFrameView()).obtainFrameOptions();
        JSONObject optJSONObject = this.mOptions.optJSONObject(0);
        if (this.mOptions.length() > 4) {
            try {
                this.mOptions.put(1, jSONArray.optInt(0));
                this.mOptions.put(2, jSONArray.optInt(1));
                this.mOptions.put(3, jSONArray.optInt(2));
                this.mOptions.put(4, jSONArray.optInt(3));
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        obtainMainView().setLayoutParams(getMapLayoutParams(obtainFrameOptions, optJSONObject, this.mOptions));
    }

    public void appendToFrameView(AdaFrameView adaFrameView) {
        if (!(getMapView() == null || getMapView().getParent() == null)) {
            removeMapFrameItem(this.mContainerWebview);
        }
        this.mContainerWebview = adaFrameView.obtainWebView();
        addToFrameItem(this.mOptions);
    }

    public void removeMapFrameItem(IWebview iWebview) {
        if (this.mPosition.equals(AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE)) {
            iWebview.obtainFrameView().removeFrameItem(this);
        } else {
            iWebview.removeFrameItem(this);
        }
    }

    public void setStyles(JSONObject jSONObject) {
        JSONUtil.combinJSONObject(JSONUtil.getJSONObject(this.mOptions, 0), jSONObject);
        if (this.mMapView != null) {
            if (jSONObject.has("center")) {
                this.mMapView.setCenter(new MapPoint(jSONObject.optJSONObject("center").optString(Constant.JSONKEY.LATITUDE), jSONObject.optJSONObject("center").optString(Constant.JSONKEY.LONGITUDE)));
            }
            if (jSONObject.has("zoom")) {
                this.mMapView.setZoom(jSONObject.optInt("zoom"));
            }
            if (jSONObject.has("type")) {
                this.mMapView.setMapType(jSONObject.optString("type").equals("MAPTYPE_SATELLITE") ? 1 : 0);
            }
            if (jSONObject.has("traffic")) {
                setTraffic(jSONObject.optBoolean("traffic"));
            }
            if (jSONObject.has("zoomControls")) {
                this.mMapView.showZoomControls(jSONObject.optBoolean("zoomControls"));
            }
            if (jSONObject.has("top") || jSONObject.has("left") || jSONObject.has("width") || jSONObject.has("height") || jSONObject.has("position")) {
                ViewGroup.LayoutParams mapLayoutParams = getMapLayoutParams(((AdaFrameItem) this.mContainerWebview.obtainFrameView()).obtainFrameOptions(), JSONUtil.getJSONObject(this.mOptions, 0), this.mOptions);
                if (jSONObject.has("position")) {
                    String optString = jSONObject.optString("position", this.mPosition);
                    if (!optString.equals(this.mPosition)) {
                        if (this.mPosition.equals(AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE)) {
                            this.mContainerWebview.obtainFrameView().removeFrameItem(this);
                            this.mContainerWebview.addFrameItem(this, mapLayoutParams);
                        } else {
                            this.mContainerWebview.removeFrameItem(this);
                            this.mContainerWebview.obtainFrameView().addFrameItem(this, mapLayoutParams);
                        }
                        this.mPosition = optString;
                        return;
                    }
                    obtainMainView().setLayoutParams(mapLayoutParams);
                    return;
                }
                obtainMainView().setLayoutParams(mapLayoutParams);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public class MapHandler extends Handler {
        public MapHandler(Looper looper) {
            super(looper);
        }

        public void handleMessage(Message message) {
            switch (message.what) {
                case 0:
                    DHMapFrameItem.this.createMapFrameItem((JSONArray) message.obj);
                    break;
                case 1:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setZoom(((Integer) message.obj).intValue());
                        break;
                    }
                    break;
                case 2:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setCenter((MapPoint) message.obj);
                        break;
                    }
                    break;
                case 3:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.addOverlay(message.obj);
                        break;
                    }
                    break;
                case 4:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.removeOverlay(message.obj);
                        break;
                    }
                    break;
                case 5:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.clearOverlays();
                        break;
                    }
                    break;
                case 6:
                case 11:
                    if (DHMapFrameItem.this.mMapView != null) {
                        Object[] objArr = (Object[]) message.obj;
                        DHMapFrameItem.this.mMapView.setCenterAndZoom((MapPoint) objArr[1], ((Integer) objArr[0]).intValue());
                        break;
                    }
                    break;
                case 7:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.showUserLocation(((Boolean) message.obj).booleanValue());
                        break;
                    }
                    break;
                case 8:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setMapType(((Integer) message.obj).intValue());
                        break;
                    }
                    break;
                case 9:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setVisible(((Boolean) message.obj).booleanValue());
                        break;
                    }
                    break;
                case 10:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.showZoomControls(((Boolean) message.obj).booleanValue());
                        break;
                    }
                    break;
                case 12:
                    DHMapFrameItem.this.addToFrameItem(message.obj);
                    break;
            }
            if (DHMapFrameItem.this.mMapView != null) {
                DHMapFrameItem.this.mMapView.refreshDrawableState();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void createMapFrameItem(JSONArray jSONArray) {
        JSONObject optJSONObject = jSONArray.optJSONObject(0);
        LatLng latLng = optJSONObject.optJSONObject("center") != null ? new LatLng(optJSONObject.optJSONObject("center").optDouble(Constant.JSONKEY.LATITUDE), optJSONObject.optJSONObject("center").optDouble(Constant.JSONKEY.LONGITUDE)) : null;
        this.mPosition = optJSONObject.optString("position", this.mPosition);
        DHMapView dHMapView = new DHMapView(getActivity(), this.mWebview, latLng, optJSONObject.optInt("zoom"), optJSONObject.optString("type").equals("MAPTYPE_SATELLITE") ? 2 : 1, optJSONObject.optBoolean("traffic"), optJSONObject.optBoolean("zoomControls"), this.mRootView);
        dHMapView.mUUID = this.mUUID;
        setMapView(dHMapView);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addToFrameItem(Object obj) {
        JSONArray jSONArray = (JSONArray) obj;
        JSONObject optJSONObject = jSONArray.optJSONObject(0);
        AdaFrameItem adaFrameItem = (AdaFrameItem) this.mContainerWebview.obtainFrameView();
        ViewGroup.LayoutParams mapLayoutParams = getMapLayoutParams(adaFrameItem.obtainFrameOptions(), optJSONObject, jSONArray);
        int i = 1;
        this.mContainerWebview.obtainFrameView().setNeedRender(true);
        if (AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE.equals(this.mPosition)) {
            if (adaFrameItem instanceof AdaFrameView) {
                if (((ViewGroup) adaFrameItem.obtainMainView()).getChildCount() <= 0) {
                    i = -1;
                }
                ((AdaFrameView) adaFrameItem).addFrameItem(this, i, mapLayoutParams);
            } else {
                this.mContainerWebview.obtainFrameView().addFrameItem(this, mapLayoutParams);
            }
            Logger.d(Logger.MAP_TAG, "addMapView webview_name=" + this.mWebview.obtainFrameId());
            return;
        }
        if (DeviceInfo.sDeviceSdkVer >= 11) {
            this.mContainerWebview.obtainWindowView().setLayerType(0, null);
        }
        this.mContainerWebview.addFrameItem(this, mapLayoutParams);
    }

    private ViewGroup.LayoutParams getMapLayoutParams(ViewRect viewRect, JSONObject jSONObject, JSONArray jSONArray) {
        float scale = this.mContainerWebview.getScale();
        if (jSONArray == null || jSONArray.length() <= 4) {
            return AdaFrameItem.LayoutParamsUtil.createLayoutParams(PdrUtil.convertToScreenInt(JSONUtil.getString(jSONObject, "left"), viewRect.width, 0, scale, true), PdrUtil.convertToScreenInt(JSONUtil.getString(jSONObject, "top"), viewRect.height, 0, scale, true), PdrUtil.convertToScreenInt(JSONUtil.getString(jSONObject, "width"), viewRect.width, viewRect.width, scale, true), PdrUtil.convertToScreenInt(JSONUtil.getString(jSONObject, "height"), viewRect.height, viewRect.height, scale, true));
        }
        int optInt = (int) (((float) jSONArray.optInt(1)) * scale);
        int optInt2 = (int) (((float) jSONArray.optInt(2)) * scale);
        int min = Math.min((int) (((float) jSONArray.optInt(3)) * scale), viewRect.width);
        int min2 = Math.min((int) (((float) jSONArray.optInt(4)) * scale), viewRect.height);
        updateViewRect((AdaFrameItem) this.mWebview.obtainFrameView(), new int[]{optInt, optInt2, min, min2}, new int[]{viewRect.width, viewRect.height});
        Logger.d("mapview", "_l=" + optInt + ";_t=" + optInt2 + ";_w=" + min + ";_h=" + min2);
        return AdaFrameItem.LayoutParamsUtil.createLayoutParams(optInt, optInt2, min, min2);
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onPopFromStack(boolean z) {
        super.onPopFromStack(z);
        if (z) {
            this.mMapView.mAutoPopFromStack = true;
        }
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onPushToStack(boolean z) {
        super.onPushToStack(z);
        if (z) {
            this.mMapView.mAutoPopFromStack = false;
            this.mMapView.onResume();
        }
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem, io.dcloud.js.map.amap.IFMapDispose
    public void dispose() {
        if (!PdrUtil.isEmpty(this.mMapView)) {
            this.mMapView.dispose();
            this.mRootView.setVisibility(8);
            this.mMapView.onDestroy();
            JsMapManager.getJsMapManager().removeJsMapView(this.mContainerWebview.obtainApp().obtainAppId(), this.mUUID);
            if (this.mPosition.equals("static")) {
                this.mContainerWebview.removeFrameItem(this);
            } else {
                this.mContainerWebview.obtainFrameView().removeFrameItem(this);
            }
            this.mMapView.mAutoPopFromStack = false;
            this.mMapView = null;
            this.mContainerWebview = null;
        }
    }

    @Override // io.dcloud.js.map.amap.IFMapDispose
    public void close() {
        if (!PdrUtil.isEmpty(this.mMapView)) {
            this.mMapView.dispose();
            this.mRootView.setVisibility(8);
            this.mRootView.post(new Runnable() {
                /* class io.dcloud.js.map.amap.adapter.DHMapFrameItem.AnonymousClass1 */

                public void run() {
                    DHMapFrameItem.this.mMapView.onDestroy();
                    JsMapManager.getJsMapManager().removeJsMapView(DHMapFrameItem.this.mContainerWebview.obtainApp().obtainAppId(), DHMapFrameItem.this.mUUID);
                    if (DHMapFrameItem.this.mPosition.equals("static")) {
                        DHMapFrameItem.this.mContainerWebview.removeFrameItem(DHMapFrameItem.this);
                    } else {
                        DHMapFrameItem.this.mContainerWebview.obtainFrameView().removeFrameItem(DHMapFrameItem.this);
                    }
                    DHMapFrameItem.this.mMapView.mAutoPopFromStack = false;
                    DHMapFrameItem.this.mMapView = null;
                    DHMapFrameItem.this.mContainerWebview = null;
                }
            });
        }
    }

    public String getBounds() {
        return this.mMapView.getBounds();
    }

    public JSONObject getMapOptions() {
        JSONArray jSONArray = this.mOptions;
        if (jSONArray == null) {
            return null;
        }
        JSONObject optJSONObject = jSONArray.optJSONObject(0);
        try {
            optJSONObject.put("zoom", this.mZoom);
            JSONObject jSONObject = new JSONObject();
            MapPoint mapPoint = this.mCenter;
            if (mapPoint != null) {
                jSONObject.put(Constant.JSONKEY.LONGITUDE, mapPoint.getLongitude());
                jSONObject.put(Constant.JSONKEY.LATITUDE, this.mCenter.getLatitude());
                optJSONObject.put("center", jSONObject);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return optJSONObject;
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onResize() {
        super.onResize();
        if (this.mOptions != null && getMapView().getParent() != null) {
            boolean z = false;
            JSONObject optJSONObject = this.mOptions.optJSONObject(0);
            if (optJSONObject == null || optJSONObject.has("width") || optJSONObject.has("height") || optJSONObject.has("top") || optJSONObject.has("left")) {
                String string = JSONUtil.getString(optJSONObject, "width");
                String string2 = JSONUtil.getString(optJSONObject, "height");
                String string3 = JSONUtil.getString(optJSONObject, "top");
                String string4 = JSONUtil.getString(optJSONObject, "left");
                boolean z2 = true;
                if (!PdrUtil.isEmpty(string) && string.endsWith(this.PERCENTAGE)) {
                    z = true;
                }
                if (!PdrUtil.isEmpty(string2) && string2.endsWith(this.PERCENTAGE)) {
                    z = true;
                }
                if (!PdrUtil.isEmpty(string3) && string3.endsWith(this.PERCENTAGE)) {
                    z = true;
                }
                if (PdrUtil.isEmpty(string4) || !string4.endsWith(this.PERCENTAGE)) {
                    z2 = z;
                }
                if (z2) {
                    obtainMainView().setLayoutParams(getMapLayoutParams(((AdaFrameItem) this.mContainerWebview.obtainFrameView()).obtainFrameOptions(), optJSONObject, this.mOptions));
                }
            }
        }
    }
}
