package io.dcloud.js.map.amap.adapter;

import com.amap.api.maps.model.Circle;
import com.amap.api.maps.model.CircleOptions;

public class MapCircleProxy {
    private MapPoint mCenter;
    private int mFillColor = -16777216;
    private double mFillOpacity;
    private String mJsId;
    private double mLineWidth = 5.0d;
    Circle mMapCircle = null;
    private double mRadius;
    private int mStrokeColor = -16777216;
    private double mStrokeOpacity = 1.0d;

    private int combineOpacity(int i, double d) {
        return (((int) (d * 255.0d)) << 24) + i;
    }

    public MapCircleProxy(MapPoint mapPoint, double d) {
        this.mCenter = mapPoint;
        this.mRadius = d;
    }

    public double getRadius() {
        return this.mRadius;
    }

    public void setRadius(double d) {
        this.mRadius = d;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setRadius(d);
        }
    }

    public int getStrokeColor() {
        return this.mStrokeColor;
    }

    public void setStrokeColor(int i) {
        int i2 = i | -16777216;
        this.mStrokeColor = i2;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setStrokeColor(combineOpacity(i2, this.mStrokeOpacity));
        }
    }

    public MapPoint getCenter() {
        return this.mCenter;
    }

    public void setCenter(MapPoint mapPoint) {
        this.mCenter = mapPoint;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setCenter(mapPoint.getLatLng());
        }
    }

    public double getStrokeOpacity() {
        return this.mStrokeOpacity;
    }

    public void setStrokeOpacity(double d) {
        this.mStrokeOpacity = d;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setStrokeColor(combineOpacity(this.mStrokeColor, d));
        }
    }

    public int getFillColor() {
        return this.mFillColor;
    }

    public void setFillColor(int i) {
        this.mFillColor = i;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setFillColor(combineOpacity(i, this.mFillOpacity));
        }
    }

    public double getFillOpacity() {
        return this.mFillOpacity;
    }

    public void setFillOpacity(double d) {
        this.mFillOpacity = d;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setFillColor(combineOpacity(this.mFillColor, d));
        }
    }

    public double getLineWidth() {
        return this.mLineWidth;
    }

    public void setLineWidth(double d) {
        this.mLineWidth = d;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setStrokeWidth((float) ((int) d));
        }
    }

    public void initMapCircle(DHMapView dHMapView) {
        this.mMapCircle = dHMapView.getMap().addCircle(getCircleOptions());
    }

    private CircleOptions getCircleOptions() {
        return new CircleOptions().center(this.mCenter.getLatLng()).radius(this.mRadius).strokeColor(combineOpacity(this.mStrokeColor, this.mStrokeOpacity)).fillColor(combineOpacity(this.mFillColor, this.mFillOpacity)).strokeWidth((float) ((int) this.mLineWidth));
    }

    public Circle getCircle() {
        return this.mMapCircle;
    }
}
