package io.dcloud.js.map.amap.adapter;

import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Polygon;
import com.amap.api.maps.model.PolygonOptions;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class MapPolygonProxy {
    private int mFillColor = 0;
    private float mFillOpacity = 0.0f;
    private String mJsId;
    private float mLineWidth = 5.0f;
    private ArrayList<MapPoint> mMapPoints;
    Polygon mMapPolygonImpl = null;
    private float mScale = 1.0f;
    private int mStrokeColor = -16777216;
    private float mStrokeOpacity = 1.0f;

    private int combineOpacity(int i, double d) {
        return (((int) (d * 255.0d)) << 24) + i;
    }

    public MapPolygonProxy(ArrayList<MapPoint> arrayList, float f) {
        this.mMapPoints = arrayList;
        this.mScale = f;
    }

    public Polygon getPolygon() {
        return this.mMapPolygonImpl;
    }

    public void initMapPolygon(DHMapView dHMapView) {
        this.mMapPolygonImpl = dHMapView.getMap().addPolygon(getPolygonOptions());
    }

    public void setPath(ArrayList<MapPoint> arrayList) {
        this.mMapPoints = arrayList;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setPoints(createRectangle());
        }
    }

    public int getStrokeColor() {
        return this.mStrokeColor;
    }

    public void setStrokeColor(int i) {
        int i2 = i - 16777216;
        this.mStrokeColor = i2;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setStrokeColor(combineOpacity(i2, (double) this.mStrokeOpacity));
        }
    }

    public float getStrokeOpacity() {
        return this.mStrokeOpacity;
    }

    public void setStrokeOpacity(float f) {
        this.mStrokeOpacity = f;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setStrokeColor(combineOpacity(this.mStrokeColor, (double) f));
        }
    }

    public float getLineWidth() {
        return this.mLineWidth;
    }

    public void setLineWidth(float f) {
        this.mLineWidth = f;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setStrokeWidth(f * this.mScale);
        }
    }

    public int getFillColor() {
        return this.mFillColor;
    }

    public void setFillColor(int i) {
        int i2 = i | -16777216;
        this.mFillColor = i2;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setFillColor(combineOpacity(i2, (double) this.mFillOpacity));
        }
    }

    public float getFillOpacity() {
        return this.mFillOpacity;
    }

    public void setFillOpacity(float f) {
        this.mFillOpacity = f;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setFillColor(combineOpacity(this.mFillColor, (double) f));
        }
    }

    private PolygonOptions getPolygonOptions() {
        PolygonOptions polygonOptions = new PolygonOptions();
        polygonOptions.addAll(createRectangle());
        polygonOptions.strokeColor(combineOpacity(this.mStrokeColor, (double) this.mStrokeOpacity));
        polygonOptions.fillColor(combineOpacity(this.mFillColor, (double) this.mFillOpacity));
        polygonOptions.strokeWidth(this.mLineWidth * this.mScale);
        return polygonOptions;
    }

    private List<LatLng> createRectangle() {
        ArrayList arrayList = new ArrayList();
        ArrayList<MapPoint> arrayList2 = this.mMapPoints;
        if (arrayList2 != null && !arrayList2.isEmpty()) {
            Iterator<MapPoint> it = this.mMapPoints.iterator();
            while (it.hasNext()) {
                arrayList.add(it.next().getLatLng());
            }
        }
        return arrayList;
    }
}
