package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import com.amap.api.maps.AMap;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.route.BusPath;
import com.amap.api.services.route.BusStep;
import com.amap.api.services.route.Doorway;
import com.amap.api.services.route.RailwayStationItem;
import com.amap.api.services.route.RouteBusLineItem;
import com.amap.api.services.route.RouteRailwayItem;
import com.amap.api.services.route.TaxiItem;
import com.amap.api.services.route.WalkStep;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.js.map.amap.util.AMapUtil;
import io.dcloud.js.map.amap.util.ChString;
import java.util.ArrayList;
import java.util.List;

public class BusRouteOverlay extends RouteOverlay {
    private BusPath busPath;
    private LatLng latLng;

    public BusRouteOverlay(Context context, AMap aMap, BusPath busPath2, LatLonPoint latLonPoint, LatLonPoint latLonPoint2) {
        super(context);
        this.busPath = busPath2;
        this.startPoint = AMapUtil.convertToLatLng(latLonPoint);
        this.endPoint = AMapUtil.convertToLatLng(latLonPoint2);
        this.mAMap = aMap;
    }

    public void addToMap() {
        try {
            List<BusStep> steps = this.busPath.getSteps();
            for (int i = 0; i < steps.size(); i++) {
                BusStep busStep = steps.get(i);
                if (i < steps.size() - 1) {
                    BusStep busStep2 = steps.get(i + 1);
                    if (!(busStep.getWalk() == null || busStep.getBusLine() == null)) {
                        checkWalkToBusline(busStep);
                    }
                    if (!(busStep.getBusLine() == null || busStep2.getWalk() == null || busStep2.getWalk().getSteps().size() <= 0)) {
                        checkBusLineToNextWalk(busStep, busStep2);
                    }
                    if (!(busStep.getBusLine() == null || busStep2.getWalk() != null || busStep2.getBusLine() == null)) {
                        checkBusEndToNextBusStart(busStep, busStep2);
                    }
                    if (!(busStep.getBusLine() == null || busStep2.getWalk() != null || busStep2.getBusLine() == null)) {
                        checkBusToNextBusNoWalk(busStep, busStep2);
                    }
                    if (!(busStep.getBusLine() == null || busStep2.getRailway() == null)) {
                        checkBusLineToNextRailway(busStep, busStep2);
                    }
                    if (!(busStep2.getWalk() == null || busStep2.getWalk().getSteps().size() <= 0 || busStep.getRailway() == null)) {
                        checkRailwayToNextWalk(busStep, busStep2);
                    }
                    if (!(busStep2.getRailway() == null || busStep.getRailway() == null)) {
                        checkRailwayToNextRailway(busStep, busStep2);
                    }
                    if (!(busStep.getRailway() == null || busStep2.getTaxi() == null)) {
                        checkRailwayToNextTaxi(busStep, busStep2);
                    }
                }
                if (busStep.getWalk() != null && busStep.getWalk().getSteps().size() > 0) {
                    addWalkSteps(busStep);
                } else if (busStep.getBusLine() == null && busStep.getRailway() == null && busStep.getTaxi() == null) {
                    addWalkPolyline(this.latLng, this.endPoint);
                }
                if (busStep.getBusLine() != null) {
                    RouteBusLineItem busLine = busStep.getBusLine();
                    addBusLineSteps(busLine);
                    addBusStationMarkers(busLine);
                    if (i == steps.size() - 1) {
                        addWalkPolyline(AMapUtil.convertToLatLng(getLastBuslinePoint(busStep)), this.endPoint);
                    }
                }
                if (busStep.getRailway() != null) {
                    addRailwayStep(busStep.getRailway());
                    addRailwayMarkers(busStep.getRailway());
                    if (i == steps.size() - 1) {
                        addWalkPolyline(AMapUtil.convertToLatLng(busStep.getRailway().getArrivalstop().getLocation()), this.endPoint);
                    }
                }
                if (busStep.getTaxi() != null) {
                    addTaxiStep(busStep.getTaxi());
                    addTaxiMarkers(busStep.getTaxi());
                }
            }
            addStartAndEndMarker();
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void checkRailwayToNextTaxi(BusStep busStep, BusStep busStep2) {
        LatLonPoint location = busStep.getRailway().getArrivalstop().getLocation();
        LatLonPoint origin = busStep2.getTaxi().getOrigin();
        if (!location.equals(origin)) {
            addWalkPolyLineByLatLonPoints(location, origin);
        }
    }

    private void checkRailwayToNextRailway(BusStep busStep, BusStep busStep2) {
        LatLonPoint location = busStep.getRailway().getArrivalstop().getLocation();
        LatLonPoint location2 = busStep2.getRailway().getDeparturestop().getLocation();
        if (!location.equals(location2)) {
            addWalkPolyLineByLatLonPoints(location, location2);
        }
    }

    private void checkBusLineToNextRailway(BusStep busStep, BusStep busStep2) {
        LatLonPoint lastBuslinePoint = getLastBuslinePoint(busStep);
        LatLonPoint location = busStep2.getRailway().getDeparturestop().getLocation();
        if (!lastBuslinePoint.equals(location)) {
            addWalkPolyLineByLatLonPoints(lastBuslinePoint, location);
        }
    }

    private void checkRailwayToNextWalk(BusStep busStep, BusStep busStep2) {
        LatLonPoint location = busStep.getRailway().getArrivalstop().getLocation();
        LatLonPoint firstWalkPoint = getFirstWalkPoint(busStep2);
        if (!location.equals(firstWalkPoint)) {
            addWalkPolyLineByLatLonPoints(location, firstWalkPoint);
        }
    }

    private void addRailwayStep(RouteRailwayItem routeRailwayItem) {
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        arrayList2.add(routeRailwayItem.getDeparturestop());
        arrayList2.addAll(routeRailwayItem.getViastops());
        arrayList2.add(routeRailwayItem.getArrivalstop());
        for (int i = 0; i < arrayList2.size(); i++) {
            arrayList.add(AMapUtil.convertToLatLng(((RailwayStationItem) arrayList2.get(i)).getLocation()));
        }
        addRailwayPolyline(arrayList);
    }

    private void addTaxiStep(TaxiItem taxiItem) {
        addPolyLine(new PolylineOptions().width(getRouteWidth()).color(getBusColor()).add(AMapUtil.convertToLatLng(taxiItem.getOrigin())).add(AMapUtil.convertToLatLng(taxiItem.getDestination())));
    }

    private void addWalkSteps(BusStep busStep) {
        List<WalkStep> steps = busStep.getWalk().getSteps();
        for (int i = 0; i < steps.size(); i++) {
            WalkStep walkStep = steps.get(i);
            if (i == 0) {
                addWalkStationMarkers(AMapUtil.convertToLatLng(walkStep.getPolyline().get(0)), walkStep.getRoad(), getWalkSnippet(steps));
            }
            List<LatLng> convertArrList = AMapUtil.convertArrList(walkStep.getPolyline());
            this.latLng = convertArrList.get(convertArrList.size() - 1);
            addWalkPolyline(convertArrList);
            if (i < steps.size() - 1) {
                LatLng latLng2 = convertArrList.get(convertArrList.size() - 1);
                LatLng convertToLatLng = AMapUtil.convertToLatLng(steps.get(i + 1).getPolyline().get(0));
                if (!latLng2.equals(convertToLatLng)) {
                    addWalkPolyline(latLng2, convertToLatLng);
                }
            }
        }
    }

    private void addBusLineSteps(RouteBusLineItem routeBusLineItem) {
        addBusLineSteps(routeBusLineItem.getPolyline());
    }

    private void addBusLineSteps(List<LatLonPoint> list) {
        if (list.size() >= 1) {
            addPolyLine(new PolylineOptions().width(getRouteWidth()).color(getBusColor()).addAll(AMapUtil.convertArrList(list)));
        }
    }

    private void addWalkStationMarkers(LatLng latLng2, String str, String str2) {
        addStationMarker(new MarkerOptions().position(latLng2).title(str).snippet(str2).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getWalkBitmapDescriptor()));
    }

    private void addBusStationMarkers(RouteBusLineItem routeBusLineItem) {
        LatLng convertToLatLng = AMapUtil.convertToLatLng(routeBusLineItem.getDepartureBusStation().getLatLonPoint());
        String busLineName = routeBusLineItem.getBusLineName();
        addStationMarker(new MarkerOptions().position(convertToLatLng).title(busLineName).snippet(getBusSnippet(routeBusLineItem)).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getBusBitmapDescriptor()));
    }

    private void addTaxiMarkers(TaxiItem taxiItem) {
        LatLng convertToLatLng = AMapUtil.convertToLatLng(taxiItem.getOrigin());
        addStationMarker(new MarkerOptions().position(convertToLatLng).title(taxiItem.getmSname() + "打车").snippet("到终点").anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getDriveBitmapDescriptor()));
    }

    private void addRailwayMarkers(RouteRailwayItem routeRailwayItem) {
        String str = routeRailwayItem.getDeparturestop().getName() + ChString.GetOn;
        addStationMarker(new MarkerOptions().position(AMapUtil.convertToLatLng(routeRailwayItem.getDeparturestop().getLocation())).title(str).snippet(routeRailwayItem.getName()).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getBusBitmapDescriptor()));
        String str2 = routeRailwayItem.getArrivalstop().getName() + ChString.GetOff;
        addStationMarker(new MarkerOptions().position(AMapUtil.convertToLatLng(routeRailwayItem.getArrivalstop().getLocation())).title(str2).snippet(routeRailwayItem.getName()).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getBusBitmapDescriptor()));
    }

    private void checkBusToNextBusNoWalk(BusStep busStep, BusStep busStep2) {
        LatLng convertToLatLng = AMapUtil.convertToLatLng(getLastBuslinePoint(busStep));
        LatLng convertToLatLng2 = AMapUtil.convertToLatLng(getFirstBuslinePoint(busStep2));
        if (convertToLatLng2.latitude - convertToLatLng.latitude > 1.0E-4d || convertToLatLng2.longitude - convertToLatLng.longitude > 1.0E-4d) {
            drawLineArrow(convertToLatLng, convertToLatLng2);
        }
    }

    private void checkBusEndToNextBusStart(BusStep busStep, BusStep busStep2) {
        LatLng convertToLatLng = AMapUtil.convertToLatLng(getLastBuslinePoint(busStep));
        LatLng convertToLatLng2 = AMapUtil.convertToLatLng(getFirstBuslinePoint(busStep2));
        if (!convertToLatLng.equals(convertToLatLng2)) {
            drawLineArrow(convertToLatLng, convertToLatLng2);
        }
    }

    private void checkBusLineToNextWalk(BusStep busStep, BusStep busStep2) {
        LatLonPoint lastBuslinePoint = getLastBuslinePoint(busStep);
        LatLonPoint firstWalkPoint = getFirstWalkPoint(busStep2);
        if (!lastBuslinePoint.equals(firstWalkPoint)) {
            addWalkPolyLineByLatLonPoints(lastBuslinePoint, firstWalkPoint);
        }
    }

    private void checkWalkToBusline(BusStep busStep) {
        LatLonPoint lastWalkPoint = getLastWalkPoint(busStep);
        LatLonPoint firstBuslinePoint = getFirstBuslinePoint(busStep);
        if (!lastWalkPoint.equals(firstBuslinePoint)) {
            addWalkPolyLineByLatLonPoints(lastWalkPoint, firstBuslinePoint);
        }
    }

    private LatLonPoint getFirstWalkPoint(BusStep busStep) {
        return busStep.getWalk().getSteps().get(0).getPolyline().get(0);
    }

    private void addWalkPolyLineByLatLonPoints(LatLonPoint latLonPoint, LatLonPoint latLonPoint2) {
        addWalkPolyline(AMapUtil.convertToLatLng(latLonPoint), AMapUtil.convertToLatLng(latLonPoint2));
    }

    private void addWalkPolyline(LatLng latLng2, LatLng latLng3) {
        addPolyLine(new PolylineOptions().add(latLng2, latLng3).width(getRouteWidth()).color(getWalkColor()).setDottedLine(true));
    }

    private void addWalkPolyline(List<LatLng> list) {
        addPolyLine(new PolylineOptions().addAll(list).color(getWalkColor()).width(getRouteWidth()).setDottedLine(true));
    }

    private void addRailwayPolyline(List<LatLng> list) {
        addPolyLine(new PolylineOptions().addAll(list).color(getDriveColor()).width(getRouteWidth()));
    }

    private String getWalkSnippet(List<WalkStep> list) {
        float f = 0.0f;
        for (WalkStep walkStep : list) {
            f += walkStep.getDistance();
        }
        return ChString.ByFoot + f + ChString.Meter;
    }

    public void drawLineArrow(LatLng latLng2, LatLng latLng3) {
        addPolyLine(new PolylineOptions().add(latLng2, latLng3).width(3.0f).color(getBusColor()).width(getRouteWidth()));
    }

    private String getBusSnippet(RouteBusLineItem routeBusLineItem) {
        return Operators.BRACKET_START_STR + routeBusLineItem.getDepartureBusStation().getBusStationName() + "-->" + routeBusLineItem.getArrivalBusStation().getBusStationName() + ") 经过" + (routeBusLineItem.getPassStationNum() + 1) + ChString.Zhan;
    }

    private LatLonPoint getLastWalkPoint(BusStep busStep) {
        List<WalkStep> steps = busStep.getWalk().getSteps();
        List<LatLonPoint> polyline = steps.get(steps.size() - 1).getPolyline();
        return polyline.get(polyline.size() - 1);
    }

    private LatLonPoint getExitPoint(BusStep busStep) {
        Doorway exit = busStep.getExit();
        if (exit == null) {
            return null;
        }
        return exit.getLatLonPoint();
    }

    private LatLonPoint getLastBuslinePoint(BusStep busStep) {
        List<LatLonPoint> polyline = busStep.getBusLine().getPolyline();
        return polyline.get(polyline.size() - 1);
    }

    private LatLonPoint getEntrancePoint(BusStep busStep) {
        Doorway entrance = busStep.getEntrance();
        if (entrance == null) {
            return null;
        }
        return entrance.getLatLonPoint();
    }

    private LatLonPoint getFirstBuslinePoint(BusStep busStep) {
        return busStep.getBusLine().getPolyline().get(0);
    }
}
