package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import android.graphics.Color;
import com.amap.api.maps.AMap;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.route.DrivePath;
import com.amap.api.services.route.DriveStep;
import com.amap.api.services.route.TMC;
import io.dcloud.js.map.amap.adapter.AMapR;
import io.dcloud.js.map.amap.util.AMapUtil;
import java.util.ArrayList;
import java.util.List;

public class DrivingRouteOverlay extends RouteOverlay {
    private DrivePath drivePath;
    private boolean isColorfulline = true;
    private Context mContext;
    private List<LatLng> mLatLngsOfPath;
    private PolylineOptions mPolylineOptions;
    private PolylineOptions mPolylineOptionscolor;
    private float mWidth = 25.0f;
    private List<LatLonPoint> throughPointList;
    private List<Marker> throughPointMarkerList = new ArrayList();
    private boolean throughPointMarkerVisible = true;
    private List<TMC> tmcs;

    public void setIsColorfulline(boolean z) {
        this.isColorfulline = z;
    }

    public DrivingRouteOverlay(Context context, AMap aMap, DrivePath drivePath2, LatLonPoint latLonPoint, LatLonPoint latLonPoint2, List<LatLonPoint> list) {
        super(context);
        this.mContext = context;
        this.mAMap = aMap;
        this.drivePath = drivePath2;
        this.startPoint = AMapUtil.convertToLatLng(latLonPoint);
        this.endPoint = AMapUtil.convertToLatLng(latLonPoint2);
        this.throughPointList = list;
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public float getRouteWidth() {
        return this.mWidth;
    }

    public void setRouteWidth(float f) {
        this.mWidth = f;
    }

    public void addToMap() {
        initPolylineOptions();
        try {
            if (!(this.mAMap == null || this.mWidth == 0.0f)) {
                if (this.drivePath != null) {
                    this.mLatLngsOfPath = new ArrayList();
                    this.tmcs = new ArrayList();
                    List<DriveStep> steps = this.drivePath.getSteps();
                    this.mPolylineOptions.add(this.startPoint);
                    for (DriveStep driveStep : steps) {
                        List<LatLonPoint> polyline = driveStep.getPolyline();
                        this.tmcs.addAll(driveStep.getTMCs());
                        addDrivingStationMarkers(driveStep, convertToLatLng(polyline.get(0)));
                        for (LatLonPoint latLonPoint : polyline) {
                            this.mPolylineOptions.add(convertToLatLng(latLonPoint));
                            this.mLatLngsOfPath.add(convertToLatLng(latLonPoint));
                        }
                    }
                    this.mPolylineOptions.add(this.endPoint);
                    if (this.startMarker != null) {
                        this.startMarker.remove();
                        this.startMarker = null;
                    }
                    if (this.endMarker != null) {
                        this.endMarker.remove();
                        this.endMarker = null;
                    }
                    addStartAndEndMarker();
                    addThroughPointMarker();
                    if (!this.isColorfulline || this.tmcs.size() <= 0) {
                        showPolyline();
                        return;
                    }
                    colorWayUpdate(this.tmcs);
                    showcolorPolyline();
                }
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void initPolylineOptions() {
        this.mPolylineOptions = null;
        PolylineOptions polylineOptions = new PolylineOptions();
        this.mPolylineOptions = polylineOptions;
        polylineOptions.color(getDriveColor()).width(getRouteWidth());
    }

    private void showPolyline() {
        addPolyLine(this.mPolylineOptions);
    }

    private void showcolorPolyline() {
        addPolyLine(this.mPolylineOptionscolor);
    }

    private void colorWayUpdate(List<TMC> list) {
        if (!(this.mAMap == null || list == null || list.size() <= 0)) {
            this.mPolylineOptionscolor = null;
            PolylineOptions polylineOptions = new PolylineOptions();
            this.mPolylineOptionscolor = polylineOptions;
            polylineOptions.width(getRouteWidth());
            ArrayList arrayList = new ArrayList();
            this.mPolylineOptionscolor.add(this.startPoint);
            this.mPolylineOptionscolor.add(AMapUtil.convertToLatLng(list.get(0).getPolyline().get(0)));
            arrayList.add(Integer.valueOf(getDriveColor()));
            for (int i = 0; i < list.size(); i++) {
                TMC tmc = list.get(i);
                int i2 = getcolor(tmc.getStatus());
                List<LatLonPoint> polyline = tmc.getPolyline();
                for (int i3 = 1; i3 < polyline.size(); i3++) {
                    this.mPolylineOptionscolor.add(AMapUtil.convertToLatLng(polyline.get(i3)));
                    arrayList.add(Integer.valueOf(i2));
                }
            }
            this.mPolylineOptionscolor.add(this.endPoint);
            arrayList.add(Integer.valueOf(getDriveColor()));
            this.mPolylineOptionscolor.colorValues(arrayList);
        }
    }

    private int getcolor(String str) {
        if (str.equals("畅通")) {
            return -16711936;
        }
        if (str.equals("缓行")) {
            return -256;
        }
        if (str.equals("拥堵")) {
            return -65536;
        }
        if (str.equals("严重拥堵")) {
            return Color.parseColor("#990033");
        }
        return Color.parseColor("#537edc");
    }

    public LatLng convertToLatLng(LatLonPoint latLonPoint) {
        return new LatLng(latLonPoint.getLatitude(), latLonPoint.getLongitude());
    }

    private void addDrivingStationMarkers(DriveStep driveStep, LatLng latLng) {
        MarkerOptions position = new MarkerOptions().position(latLng);
        addStationMarker(position.title("方向:" + driveStep.getAction() + "\n道路:" + driveStep.getRoad()).snippet(driveStep.getInstruction()).visible(this.nodeIconVisible).anchor(0.5f, 0.5f).icon(getDriveBitmapDescriptor()));
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public LatLngBounds getLatLngBounds() {
        LatLngBounds.Builder builder = LatLngBounds.builder();
        builder.include(new LatLng(this.startPoint.latitude, this.startPoint.longitude));
        builder.include(new LatLng(this.endPoint.latitude, this.endPoint.longitude));
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                builder.include(new LatLng(this.throughPointList.get(i).getLatitude(), this.throughPointList.get(i).getLongitude()));
            }
        }
        return builder.build();
    }

    public void setThroughPointIconVisibility(boolean z) {
        try {
            this.throughPointMarkerVisible = z;
            List<Marker> list = this.throughPointMarkerList;
            if (list != null && list.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).setVisible(z);
                }
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void addThroughPointMarker() {
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                LatLonPoint latLonPoint = this.throughPointList.get(i);
                if (latLonPoint != null) {
                    this.throughPointMarkerList.add(this.mAMap.addMarker(new MarkerOptions().position(new LatLng(latLonPoint.getLatitude(), latLonPoint.getLongitude())).visible(this.throughPointMarkerVisible).icon(getThroughPointBitDes()).title("途经点")));
                }
            }
        }
    }

    private BitmapDescriptor getThroughPointBitDes() {
        return BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_THROUGH);
    }

    public static int calculateDistance(LatLng latLng, LatLng latLng2) {
        return calculateDistance(latLng.longitude, latLng.latitude, latLng2.longitude, latLng2.latitude);
    }

    public static int calculateDistance(double d, double d2, double d3, double d4) {
        double d5 = d * 0.01745329251994329d;
        double d6 = d2 * 0.01745329251994329d;
        double d7 = d3 * 0.01745329251994329d;
        double d8 = 0.01745329251994329d * d4;
        double sin = Math.sin(d5);
        double sin2 = Math.sin(d6);
        double cos = Math.cos(d5);
        double cos2 = Math.cos(d6);
        double sin3 = Math.sin(d7);
        double sin4 = Math.sin(d8);
        double cos3 = Math.cos(d7);
        double cos4 = Math.cos(d8);
        double[] dArr = {(cos * cos2) - (cos3 * cos4), (cos2 * sin) - (cos4 * sin3), sin2 - sin4};
        return (int) (Math.asin(Math.sqrt(((dArr[0] * dArr[0]) + (dArr[1] * dArr[1])) + (dArr[2] * dArr[2])) / 2.0d) * 1.27420015798544E7d);
    }

    public static LatLng getPointForDis(LatLng latLng, LatLng latLng2, double d) {
        double calculateDistance = (double) calculateDistance(latLng, latLng2);
        Double.isNaN(calculateDistance);
        double d2 = d / calculateDistance;
        return new LatLng(((latLng2.latitude - latLng.latitude) * d2) + latLng.latitude, ((latLng2.longitude - latLng.longitude) * d2) + latLng.longitude);
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public void removeFromMap() {
        try {
            super.removeFromMap();
            List<Marker> list = this.throughPointMarkerList;
            if (list != null && list.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).remove();
                }
                this.throughPointMarkerList.clear();
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }
}
