package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import android.graphics.Color;
import com.amap.api.maps.AMap;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.route.TMC;
import com.amap.api.services.route.TruckPath;
import com.amap.api.services.route.TruckStep;
import io.dcloud.js.map.amap.adapter.AMapR;
import io.dcloud.js.map.amap.util.AMapUtil;
import java.util.ArrayList;
import java.util.List;

public class TruckRouteColorfulOverLay extends RouteOverlay {
    private boolean isColorfulline = true;
    private Context mContext;
    private List<LatLng> mLatLngsOfPath;
    private PolylineOptions mPolylineOptions;
    private float mWidth = 17.0f;
    private List<LatLonPoint> throughPointList;
    private List<Marker> throughPointMarkerList = new ArrayList();
    private boolean throughPointMarkerVisible = true;
    private List<TMC> tmcs;
    private TruckPath truckPath;

    private void addLimitMarker(TruckStep truckStep, LatLng latLng) {
    }

    public void setIsColorfulline(boolean z) {
        this.isColorfulline = z;
    }

    public TruckRouteColorfulOverLay(Context context, AMap aMap, TruckPath truckPath2, LatLonPoint latLonPoint, LatLonPoint latLonPoint2, List<LatLonPoint> list) {
        super(context);
        this.mContext = context;
        this.mAMap = aMap;
        this.truckPath = truckPath2;
        this.startPoint = AMapUtil.convertToLatLng(latLonPoint);
        this.endPoint = AMapUtil.convertToLatLng(latLonPoint2);
        this.throughPointList = list;
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public float getRouteWidth() {
        return this.mWidth;
    }

    public void setRouteWidth(float f) {
        this.mWidth = f;
    }

    public void addToMap() {
        initPolylineOptions();
        try {
            if (this.mAMap != null && this.mWidth != 0.0f) {
                if (this.truckPath != null) {
                    this.mLatLngsOfPath = new ArrayList();
                    this.tmcs = new ArrayList();
                    List<TruckStep> steps = this.truckPath.getSteps();
                    this.mPolylineOptions.add(this.startPoint);
                    for (TruckStep truckStep : steps) {
                        List<LatLonPoint> polyline = truckStep.getPolyline();
                        this.tmcs.addAll(truckStep.getTMCs());
                        for (LatLonPoint latLonPoint : polyline) {
                            this.mPolylineOptions.add(convertToLatLng(latLonPoint));
                            this.mLatLngsOfPath.add(convertToLatLng(latLonPoint));
                        }
                    }
                    this.mPolylineOptions.add(this.endPoint);
                    if (this.startMarker != null) {
                        this.startMarker.remove();
                        this.startMarker = null;
                    }
                    if (this.endMarker != null) {
                        this.endMarker.remove();
                        this.endMarker = null;
                    }
                    addStartAndEndMarker();
                    addThroughPointMarker();
                    if (!this.isColorfulline || this.tmcs.size() <= 0) {
                        showPolyline();
                    } else {
                        colorWayUpdate(this.tmcs);
                    }
                }
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void initPolylineOptions() {
        this.mPolylineOptions = null;
        PolylineOptions polylineOptions = new PolylineOptions();
        this.mPolylineOptions = polylineOptions;
        polylineOptions.color(getDriveColor()).width(getRouteWidth());
    }

    private void showPolyline() {
        addPolyLine(this.mPolylineOptions);
    }

    private void colorWayUpdate(List<TMC> list) {
        List<LatLng> list2;
        if (this.mAMap != null && (list2 = this.mLatLngsOfPath) != null && list2.size() > 0 && list != null && list.size() > 0) {
            LatLng latLng = this.mLatLngsOfPath.get(0);
            ArrayList arrayList = new ArrayList();
            addPolyLine(new PolylineOptions().add(this.startPoint, latLng).setDottedLine(true));
            PolylineOptions polylineOptions = new PolylineOptions();
            List<LatLng> list3 = this.mLatLngsOfPath;
            addPolyLine(polylineOptions.add(list3.get(list3.size() - 1), this.endPoint).setDottedLine(true));
            int i = 0;
            int i2 = 0;
            double d = 0.0d;
            while (i < this.mLatLngsOfPath.size() && i2 < list.size()) {
                TMC tmc = list.get(i2);
                LatLng latLng2 = this.mLatLngsOfPath.get(i);
                double calculateDistance = (double) calculateDistance(latLng, latLng2);
                Double.isNaN(calculateDistance);
                d += calculateDistance;
                if (d > ((double) (tmc.getDistance() + 1))) {
                    double distance = (double) tmc.getDistance();
                    Double.isNaN(distance);
                    Double.isNaN(calculateDistance);
                    latLng = getPointForDis(latLng, latLng2, calculateDistance - (d - distance));
                    arrayList.add(latLng);
                    i--;
                } else {
                    arrayList.add(latLng2);
                    latLng = latLng2;
                }
                if (d >= ((double) tmc.getDistance()) || i == this.mLatLngsOfPath.size() - 1) {
                    if (i2 == list.size() - 1 && i < this.mLatLngsOfPath.size() - 1) {
                        while (true) {
                            i++;
                            if (i >= this.mLatLngsOfPath.size()) {
                                break;
                            }
                            arrayList.add(this.mLatLngsOfPath.get(i));
                        }
                    }
                    i2++;
                    if (tmc.getStatus().equals("畅通")) {
                        addPolyLine(new PolylineOptions().addAll(arrayList).width(this.mWidth).color(-16711936));
                    } else if (tmc.getStatus().equals("缓行")) {
                        addPolyLine(new PolylineOptions().addAll(arrayList).width(this.mWidth).color(-256));
                    } else if (tmc.getStatus().equals("拥堵")) {
                        addPolyLine(new PolylineOptions().addAll(arrayList).width(this.mWidth).color(-65536));
                    } else if (tmc.getStatus().equals("严重拥堵")) {
                        addPolyLine(new PolylineOptions().addAll(arrayList).width(this.mWidth).color(Color.parseColor("#990033")));
                    } else {
                        addPolyLine(new PolylineOptions().addAll(arrayList).width(this.mWidth).color(Color.parseColor("#537edc")));
                    }
                    arrayList.clear();
                    arrayList.add(latLng);
                    d = 0.0d;
                } else {
                    i2 = i2;
                }
                if (i == this.mLatLngsOfPath.size() - 1) {
                    addPolyLine(new PolylineOptions().add(latLng2, this.endPoint).setDottedLine(true));
                }
                i++;
            }
        }
    }

    public LatLng convertToLatLng(LatLonPoint latLonPoint) {
        return new LatLng(latLonPoint.getLatitude(), latLonPoint.getLongitude());
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public LatLngBounds getLatLngBounds() {
        LatLngBounds.Builder builder = LatLngBounds.builder();
        builder.include(new LatLng(this.startPoint.latitude, this.startPoint.longitude));
        builder.include(new LatLng(this.endPoint.latitude, this.endPoint.longitude));
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                builder.include(new LatLng(this.throughPointList.get(i).getLatitude(), this.throughPointList.get(i).getLongitude()));
            }
        }
        return builder.build();
    }

    public void setThroughPointIconVisibility(boolean z) {
        try {
            this.throughPointMarkerVisible = z;
            List<Marker> list = this.throughPointMarkerList;
            if (list != null && list.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).setVisible(z);
                }
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private void addThroughPointMarker() {
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                LatLonPoint latLonPoint = this.throughPointList.get(i);
                if (latLonPoint != null) {
                    this.throughPointMarkerList.add(this.mAMap.addMarker(new MarkerOptions().position(new LatLng(latLonPoint.getLatitude(), latLonPoint.getLongitude())).visible(this.throughPointMarkerVisible).icon(getThroughPointBitDes()).title("途经点")));
                }
            }
        }
    }

    private BitmapDescriptor getThroughPointBitDes() {
        return BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_THROUGH);
    }

    public static int calculateDistance(LatLng latLng, LatLng latLng2) {
        return calculateDistance(latLng.longitude, latLng.latitude, latLng2.longitude, latLng2.latitude);
    }

    public static int calculateDistance(double d, double d2, double d3, double d4) {
        double d5 = d * 0.01745329251994329d;
        double d6 = d2 * 0.01745329251994329d;
        double d7 = d3 * 0.01745329251994329d;
        double d8 = 0.01745329251994329d * d4;
        double sin = Math.sin(d5);
        double sin2 = Math.sin(d6);
        double cos = Math.cos(d5);
        double cos2 = Math.cos(d6);
        double sin3 = Math.sin(d7);
        double sin4 = Math.sin(d8);
        double cos3 = Math.cos(d7);
        double cos4 = Math.cos(d8);
        double[] dArr = {(cos * cos2) - (cos3 * cos4), (cos2 * sin) - (cos4 * sin3), sin2 - sin4};
        return (int) (Math.asin(Math.sqrt(((dArr[0] * dArr[0]) + (dArr[1] * dArr[1])) + (dArr[2] * dArr[2])) / 2.0d) * 1.27420015798544E7d);
    }

    public static LatLng getPointForDis(LatLng latLng, LatLng latLng2, double d) {
        double calculateDistance = (double) calculateDistance(latLng, latLng2);
        Double.isNaN(calculateDistance);
        double d2 = d / calculateDistance;
        return new LatLng(((latLng2.latitude - latLng.latitude) * d2) + latLng.latitude, ((latLng2.longitude - latLng.longitude) * d2) + latLng.longitude);
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public void removeFromMap() {
        try {
            super.removeFromMap();
            List<Marker> list = this.throughPointMarkerList;
            if (list != null && list.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).remove();
                }
                this.throughPointMarkerList.clear();
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }
}
