package io.dcloud.share.mm;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.ColorDrawable;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.Display;
import androidx.core.content.FileProvider;
import com.dcloud.android.widget.toast.ToastCompat;
import com.facebook.common.util.UriUtil;
import com.nostra13.dcloudimageloader.core.DisplayImageOptions;
import com.nostra13.dcloudimageloader.core.ImageLoaderL;
import com.nostra13.dcloudimageloader.core.assist.ImageScaleType;
import com.taobao.weex.ui.component.WXBasicComponentType;
import com.tencent.mm.opensdk.channel.MMessageActV2;
import com.tencent.mm.opensdk.modelbase.BaseResp;
import com.tencent.mm.opensdk.modelbiz.WXLaunchMiniProgram;
import com.tencent.mm.opensdk.modelbiz.WXOpenCustomerServiceChat;
import com.tencent.mm.opensdk.modelmsg.SendMessageToWX;
import com.tencent.mm.opensdk.modelmsg.WXImageObject;
import com.tencent.mm.opensdk.modelmsg.WXMediaMessage;
import com.tencent.mm.opensdk.modelmsg.WXMiniProgramObject;
import com.tencent.mm.opensdk.modelmsg.WXMusicObject;
import com.tencent.mm.opensdk.modelmsg.WXMusicVideoObject;
import com.tencent.mm.opensdk.modelmsg.WXTextObject;
import com.tencent.mm.opensdk.modelmsg.WXVideoObject;
import com.tencent.mm.opensdk.modelmsg.WXWebpageObject;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;
import io.dcloud.ProcessMediator;
import io.dcloud.RInformation;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.FeatureMessageDispatcher;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.IOUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.share.weixin.R;
import io.dcloud.share.IFShareApi;
import io.dcloud.share.IWeiXinFShareApi;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class WeiXinApiManager implements IWeiXinFShareApi {
    private static String APPID = null;
    public static final String AUTHORIZE_TEMPLATE = "{authenticated:%s,accessToken:'%s'}";
    private static final int ERROR_IMAGE_LIMIT = -102;
    private static final int ERROR_IMAGE_ONT_FOUND = -103;
    private static final int ERROR_NOTYPE = -100;
    private static final int ERROR_NOT_COMPLETE = -101;
    private static final int ERROR_NOT_SUPPORT_VERSION_CODE = -104;
    private static final String ERROR_NOT_SUPPORT_VERSION_MSG = "the current wechat client version does not support this function";
    public static final String KEY_APPID = "appid";
    private static final String TAG = "WeiXinApiManager";
    public static final int THUMB_SIZE = 150;
    private static final String WEIXIN_DES = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_plugin_desc);
    public static final String WEIXIN_ID = "weixin";
    private IWXAPI api;
    FeatureMessageDispatcher.MessageListener sSendCallbackMessageListener = new FeatureMessageDispatcher.MessageListener() {
        /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass1 */

        @Override // io.dcloud.common.DHInterface.FeatureMessageDispatcher.MessageListener
        public void onReceiver(Object obj) {
            if (obj instanceof BaseResp) {
                WeiXinApiManager.this.executeSendCallbackMsg((BaseResp) obj);
                FeatureMessageDispatcher.unregisterListener(WeiXinApiManager.this.sSendCallbackMessageListener);
            }
        }
    };
    Object[] sendCallbackMsg = null;

    @Override // io.dcloud.share.IFShareApi
    public String getId() {
        return WEIXIN_ID;
    }

    @Override // io.dcloud.share.IFShareApi
    public void initConfig() {
        initData();
    }

    public void initData() {
        APPID = AndroidResources.getMetaValue("WX_APPID");
    }

    private boolean hasFullConfigData() {
        return !TextUtils.isEmpty(APPID);
    }

    private boolean hasGeneralError(IWebview iWebview, String str) {
        if (!hasFullConfigData()) {
            Deprecated_JSUtil.execCallback(iWebview, str, StringUtil.format(DOMException.JSON_ERROR_INFO, -7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT)), JSUtil.ERROR, true, false);
            return true;
        } else if (PlatformUtil.isAppInstalled(iWebview.getContext(), "com.tencent.mm")) {
            return false;
        } else {
            Deprecated_JSUtil.execCallback(iWebview, str, StringUtil.format(DOMException.JSON_ERROR_INFO, -8, DOMException.toString(DOMException.MSG_CLIENT_UNINSTALLED)), JSUtil.ERROR, true, false);
            return true;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerSendCallbackMsg(Object[] objArr) {
        this.sendCallbackMsg = objArr;
    }

    /* access modifiers changed from: package-private */
    public void executeSendCallbackMsg(BaseResp baseResp) {
        Object[] objArr = this.sendCallbackMsg;
        if (objArr != null) {
            IWebview iWebview = (IWebview) objArr[0];
            String str = (String) objArr[1];
            if (baseResp == null) {
                return;
            }
            if (baseResp instanceof WXLaunchMiniProgram.Resp) {
                Deprecated_JSUtil.execCallback(iWebview, str, ((WXLaunchMiniProgram.Resp) baseResp).extMsg, JSUtil.OK, false, false);
            } else {
                onSendCallBack(iWebview, str, baseResp.errCode);
            }
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void send(final IWebview iWebview, final String str, final String str2) {
        if (!hasGeneralError(iWebview, str)) {
            new Thread() {
                /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass2 */

                /* JADX WARNING: Removed duplicated region for block: B:142:0x0293  */
                /* JADX WARNING: Removed duplicated region for block: B:144:0x02a2  */
                public void run() {
                    byte b;
                    String str;
                    String str2;
                    String str3;
                    char c;
                    int i;
                    boolean z;
                    byte b2;
                    String str4;
                    String str5;
                    Exception exc;
                    String str6;
                    Exception e;
                    String str7;
                    Exception e2;
                    try {
                        JSONObject jSONObject = new JSONObject(str2);
                        String optString = jSONObject.optString("type");
                        String optString2 = jSONObject.optString(UriUtil.LOCAL_CONTENT_SCHEME);
                        String optString3 = jSONObject.optString("title");
                        String optString4 = jSONObject.optString("href");
                        String optString5 = jSONObject.optString("media");
                        JSONArray optJSONArray = jSONObject.optJSONArray("thumbs");
                        JSONArray optJSONArray2 = jSONObject.optJSONArray("pictures");
                        JSONObject jSONObject2 = JSONUtil.getJSONObject(jSONObject, "extra");
                        SendMessageToWX.Req req = new SendMessageToWX.Req();
                        req.scene = 0;
                        if (jSONObject2 != null && !jSONObject2.isNull("scene")) {
                            String string = JSONUtil.getString(jSONObject2, "scene");
                            if ("WXSceneSession".equals(string)) {
                                req.scene = 0;
                            } else if ("WXSceneFavorite".equals(string)) {
                                req.scene = 2;
                            } else if ("WXSceneTimeline".equals(string) || "WXSenceTimeline".equals(string)) {
                                req.scene = 1;
                            }
                        }
                        String str8 = null;
                        try {
                            if (TextUtils.isEmpty(optString)) {
                                i = 2;
                                c = 1;
                                if (!PdrUtil.isEmpty(optString4)) {
                                    z = WeiXinApiManager.this.reqWebPageMsg(iWebview, req, optString4, optJSONArray != null ? optJSONArray.optString(0, null) : null, optString2, optString3);
                                } else if (optJSONArray2 == null || optJSONArray2.length() <= 0) {
                                    z = WeiXinApiManager.this.reqTextMsg(req, optString2, optString3);
                                } else {
                                    String optString6 = optJSONArray2.optString(0);
                                    if (optJSONArray != null) {
                                        try {
                                            if (!optJSONArray.isNull(0)) {
                                                str5 = optJSONArray.optString(0);
                                                str4 = iWebview.obtainFrameView().obtainApp().convert2AbsFullPath(iWebview.obtainFullUrl(), optString6);
                                                try {
                                                    str8 = iWebview.obtainFrameView().obtainApp().convert2AbsFullPath(iWebview.obtainFullUrl(), str5);
                                                    b2 = iWebview.obtainFrameView().obtainApp().obtainRunningAppMode();
                                                    try {
                                                        z = WeiXinApiManager.this.reqImageMsg(iWebview, req, optJSONArray2, optJSONArray, optString3, str);
                                                        str7 = str8;
                                                        str8 = optString6;
                                                        str = str7;
                                                        str3 = str5;
                                                        str2 = str4;
                                                        b = b2;
                                                    } catch (Exception e3) {
                                                        e2 = e3;
                                                        exc = e2;
                                                        str6 = str8;
                                                        str8 = optString6;
                                                        exc.printStackTrace();
                                                        str = str6;
                                                        str3 = str5;
                                                        str2 = str4;
                                                        b = b2;
                                                        z = false;
                                                        if (z) {
                                                        }
                                                    }
                                                } catch (Exception e4) {
                                                    e2 = e4;
                                                    b2 = 0;
                                                    exc = e2;
                                                    str6 = str8;
                                                    str8 = optString6;
                                                    exc.printStackTrace();
                                                    str = str6;
                                                    str3 = str5;
                                                    str2 = str4;
                                                    b = b2;
                                                    z = false;
                                                    if (z) {
                                                    }
                                                }
                                                if (z) {
                                                }
                                            }
                                        } catch (Exception e5) {
                                            e = e5;
                                            str5 = null;
                                            str4 = null;
                                            b2 = 0;
                                            str8 = optString6;
                                            exc = e;
                                            str6 = str4;
                                            exc.printStackTrace();
                                            str = str6;
                                            str3 = str5;
                                            str2 = str4;
                                            b = b2;
                                            z = false;
                                            if (z) {
                                            }
                                        }
                                    }
                                    str5 = optString6;
                                    try {
                                        str4 = iWebview.obtainFrameView().obtainApp().convert2AbsFullPath(iWebview.obtainFullUrl(), optString6);
                                        str8 = iWebview.obtainFrameView().obtainApp().convert2AbsFullPath(iWebview.obtainFullUrl(), str5);
                                        b2 = iWebview.obtainFrameView().obtainApp().obtainRunningAppMode();
                                        z = WeiXinApiManager.this.reqImageMsg(iWebview, req, optJSONArray2, optJSONArray, optString3, str);
                                        str7 = str8;
                                        str8 = optString6;
                                        str = str7;
                                        str3 = str5;
                                        str2 = str4;
                                        b = b2;
                                    } catch (Exception e6) {
                                        e = e6;
                                        str4 = null;
                                        b2 = 0;
                                        str8 = optString6;
                                        exc = e;
                                        str6 = str4;
                                        exc.printStackTrace();
                                        str = str6;
                                        str3 = str5;
                                        str2 = str4;
                                        b = b2;
                                        z = false;
                                        if (z) {
                                        }
                                    }
                                    if (z) {
                                    }
                                }
                            } else if (optString.equals("text")) {
                                try {
                                    z = WeiXinApiManager.this.reqTextMsg(req, optString2, optString3);
                                    str7 = null;
                                    str5 = null;
                                    str4 = null;
                                    i = 2;
                                    c = 1;
                                    b2 = 0;
                                    str = str7;
                                    str3 = str5;
                                    str2 = str4;
                                    b = b2;
                                } catch (Exception e7) {
                                    exc = e7;
                                    str6 = null;
                                    str5 = null;
                                    str4 = null;
                                    i = 2;
                                    c = 1;
                                    b2 = 0;
                                    exc.printStackTrace();
                                    str = str6;
                                    str3 = str5;
                                    str2 = str4;
                                    b = b2;
                                    z = false;
                                    if (z) {
                                    }
                                }
                                if (z) {
                                    iWebview.obtainWindowView().postDelayed(new Runnable() {
                                        /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass2.AnonymousClass1 */

                                        public void run() {
                                            WeiXinApiManager.this.onSendCallBack(iWebview, str, 0);
                                        }
                                    }, 500);
                                    return;
                                } else if ((iWebview.getActivity() instanceof IActivityHandler) && ((IActivityHandler) iWebview.getActivity()).isMultiProcessMode()) {
                                    WeiXinApiManager.this.startWeiXinMediator(iWebview, str, req, str8, str3, str2, str, b);
                                    return;
                                } else if (!WeiXinApiManager.this.api.sendReq(req) || !WeiXinApiManager.this.hasWXEntryActivity(iWebview.getContext())) {
                                    iWebview.obtainWindowView().postDelayed(new Runnable() {
                                        /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass2.AnonymousClass2 */

                                        public void run() {
                                            WeiXinApiManager.this.onSendCallBack(iWebview, str, -3);
                                        }
                                    }, 500);
                                    return;
                                } else {
                                    FeatureMessageDispatcher.registerListener(WeiXinApiManager.this.sSendCallbackMessageListener);
                                    WeiXinApiManager weiXinApiManager = WeiXinApiManager.this;
                                    Object[] objArr = new Object[i];
                                    objArr[0] = iWebview;
                                    objArr[c] = str;
                                    weiXinApiManager.registerSendCallbackMsg(objArr);
                                    return;
                                }
                            } else if (!optString.equals("image")) {
                                c = 1;
                                try {
                                    if (optString.equals("music")) {
                                        try {
                                            if (PdrUtil.isEmpty(optString5)) {
                                                WeiXinApiManager.this.onSendCallBack(iWebview, str, WeiXinApiManager.ERROR_NOT_COMPLETE);
                                                return;
                                            } else {
                                                i = 2;
                                                z = WeiXinApiManager.this.reqMusicMsg(iWebview, req, optString4, optString5, optJSONArray != null ? optJSONArray.optString(0, null) : null, optString2, optString3);
                                            }
                                        } catch (Exception e8) {
                                            exc = e8;
                                            str6 = null;
                                            str5 = null;
                                            str4 = null;
                                            i = 2;
                                            b2 = 0;
                                            exc.printStackTrace();
                                            str = str6;
                                            str3 = str5;
                                            str2 = str4;
                                            b = b2;
                                            z = false;
                                            if (z) {
                                            }
                                        }
                                    } else if (optString.equals("video")) {
                                        if (PdrUtil.isEmpty(optString5)) {
                                            WeiXinApiManager.this.onSendCallBack(iWebview, str, WeiXinApiManager.ERROR_NOT_COMPLETE);
                                            return;
                                        } else {
                                            i = 2;
                                            z = WeiXinApiManager.this.reqVideoMsg(iWebview, req, optString5, optJSONArray != null ? optJSONArray.optString(0, null) : null, optString2, optString3);
                                        }
                                    } else if (optString.equals("web")) {
                                        if (PdrUtil.isEmpty(optString4)) {
                                            WeiXinApiManager.this.onSendCallBack(iWebview, str, WeiXinApiManager.ERROR_NOT_COMPLETE);
                                            return;
                                        } else {
                                            i = 2;
                                            z = WeiXinApiManager.this.reqWebPageMsg(iWebview, req, optString4, optJSONArray != null ? optJSONArray.optString(0, null) : null, optString2, optString3);
                                        }
                                    } else if (optString.equals("miniProgram")) {
                                        JSONObject optJSONObject = jSONObject.optJSONObject("miniProgram");
                                        if (optJSONObject == null) {
                                            WeiXinApiManager.this.onSendCallBack(iWebview, str, WeiXinApiManager.ERROR_NOT_COMPLETE);
                                            return;
                                        } else {
                                            i = 2;
                                            z = WeiXinApiManager.this.reqMiniMsg(iWebview, req, optJSONArray != null ? optJSONArray.optString(0, null) : null, optString2, optString3, optJSONObject);
                                        }
                                    } else {
                                        i = 2;
                                        if (optString.equals("musicVideo")) {
                                            str7 = null;
                                            str5 = null;
                                            str4 = null;
                                            z = false;
                                            b2 = 0;
                                            str = str7;
                                            str3 = str5;
                                            str2 = str4;
                                            b = b2;
                                            if (z) {
                                            }
                                        } else {
                                            WeiXinApiManager.this.onSendCallBack(iWebview, str, -100);
                                            return;
                                        }
                                    }
                                } catch (Exception e9) {
                                    e = e9;
                                    i = 2;
                                    exc = e;
                                    str6 = null;
                                    str5 = null;
                                    str4 = null;
                                    b2 = 0;
                                    exc.printStackTrace();
                                    str = str6;
                                    str3 = str5;
                                    str2 = str4;
                                    b = b2;
                                    z = false;
                                    if (z) {
                                    }
                                }
                            } else if (optJSONArray2 == null || optJSONArray2.length() == 0) {
                                WeiXinApiManager.this.onSendCallBack(iWebview, str, WeiXinApiManager.ERROR_NOT_COMPLETE);
                                return;
                            } else {
                                i = 2;
                                c = 1;
                                try {
                                    z = WeiXinApiManager.this.reqImageMsg(iWebview, req, optJSONArray2, optJSONArray, optString3, str);
                                } catch (Exception e10) {
                                    e = e10;
                                    exc = e;
                                    str6 = null;
                                    str5 = null;
                                    str4 = null;
                                    b2 = 0;
                                    exc.printStackTrace();
                                    str = str6;
                                    str3 = str5;
                                    str2 = str4;
                                    b = b2;
                                    z = false;
                                    if (z) {
                                    }
                                }
                            }
                            str7 = null;
                            str5 = null;
                            str4 = null;
                            b2 = 0;
                            str = str7;
                            str3 = str5;
                            str2 = str4;
                            b = b2;
                        } catch (Exception e11) {
                            e = e11;
                            i = 2;
                            c = 1;
                            exc = e;
                            str6 = null;
                            str5 = null;
                            str4 = null;
                            b2 = 0;
                            exc.printStackTrace();
                            str = str6;
                            str3 = str5;
                            str2 = str4;
                            b = b2;
                            z = false;
                            if (z) {
                            }
                        }
                        if (z) {
                        }
                    } catch (Exception e12) {
                        e12.printStackTrace();
                    }
                }
            }.start();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startWeiXinMediator(final IWebview iWebview, final String str, SendMessageToWX.Req req, String str2, String str3, String str4, String str5, int i) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WeiXinMediator.class.getName());
        Bundle bundle = new Bundle();
        req.toBundle(bundle);
        bundle.putString("pImg", str2);
        bundle.putString("pThumbImg", str3);
        bundle.putString("absFullPath", str4);
        bundle.putString("AbsFullPathThumb", str5);
        bundle.putInt("mRunningMode", i);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.setClassName(iWebview.getActivity(), WXShareProcessMeadiatorActivity.class.getName());
        intent.putExtra("transaction", req.transaction);
        iWebview.getActivity().startActivityForResult(intent, 1000);
        iWebview.getActivity().overridePendingTransition(0, 0);
        iWebview.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass3 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType sysEventType, Object obj) {
                Object[] objArr = (Object[]) obj;
                int intValue = ((Integer) objArr[0]).intValue();
                ((Integer) objArr[1]).intValue();
                Intent intent = (Intent) objArr[2];
                if (sysEventType == ISysEventListener.SysEventType.onActivityResult && intValue == 1000) {
                    Bundle bundleExtra = intent.getBundleExtra("result");
                    if (bundleExtra == null) {
                        WeiXinApiManager.this.onSendCallBack(iWebview, str, -3);
                    } else {
                        String string = bundleExtra.getString("style");
                        if ("BaseResp".equals(string)) {
                            SendMessageToWX.Resp resp = new SendMessageToWX.Resp();
                            resp.fromBundle(bundleExtra);
                            WeiXinApiManager.this.onSendCallBack(iWebview, str, resp.errCode);
                        } else {
                            "BaseReq".equals(string);
                        }
                    }
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
    }

    private void startWXMiniProgramMediator(final IWebview iWebview, final String str, String str2, String str3, int i) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WeiXinMediator.class.getName());
        Bundle bundle = new Bundle();
        bundle.putString("userName", str2);
        bundle.putString("path", str3);
        bundle.putInt("miniprogramType", i);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.setClassName(iWebview.getActivity(), WXShareProcessMeadiatorActivity.class.getName());
        intent.putExtra(WeiXinMediator.WX_MINI_PROGRAM_KEY, true);
        intent.putExtra(ProcessMediator.PROCESS_ACTIVITY_SOURCE, iWebview.getActivity().getClass().getName());
        iWebview.getActivity().startActivityForResult(intent, 1000);
        iWebview.getActivity().overridePendingTransition(0, 0);
        iWebview.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass4 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType sysEventType, Object obj) {
                Object[] objArr = (Object[]) obj;
                int intValue = ((Integer) objArr[0]).intValue();
                Intent intent = (Intent) objArr[2];
                if (sysEventType == ISysEventListener.SysEventType.onActivityResult && intValue == 1000) {
                    Bundle bundleExtra = intent.getBundleExtra("result");
                    if (bundleExtra == null) {
                        WeiXinApiManager.this.onSendCallBack(iWebview, str, -3);
                    } else {
                        String string = bundleExtra.getString("style");
                        if ("BaseResp".equals(string)) {
                            WXLaunchMiniProgram.Resp resp = new WXLaunchMiniProgram.Resp();
                            resp.fromBundle(bundleExtra);
                            Deprecated_JSUtil.execCallback(iWebview, str, resp.extMsg, JSUtil.OK, false, false);
                        } else {
                            "BaseReq".equals(string);
                        }
                    }
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
    }

    public void send(Activity activity, String str) {
        try {
            JSONObject jSONObject = new JSONObject(str);
            String string = jSONObject.getString(UriUtil.LOCAL_CONTENT_SCHEME);
            String string2 = jSONObject.getString("href");
            String optString = jSONObject.optString("thumbs");
            int i = jSONObject.getInt("flag");
            initData();
            if (this.api == null) {
                this.api = WXAPIFactory.createWXAPI(activity.getApplicationContext(), APPID, true);
            }
            this.api.registerApp(APPID);
            if (!this.api.isWXAppInstalled()) {
                ToastCompat.makeText(activity.getApplicationContext(), (CharSequence) DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_client_not_installed), 0).show();
                return;
            }
            WXWebpageObject wXWebpageObject = new WXWebpageObject();
            wXWebpageObject.webpageUrl = string2;
            WXMediaMessage wXMediaMessage = new WXMediaMessage(wXWebpageObject);
            wXMediaMessage.description = string;
            wXMediaMessage.title = string;
            Bitmap bitmap = null;
            if (!TextUtils.isEmpty(optString) && new File(optString).exists()) {
                bitmap = BitmapFactory.decodeFile(optString);
            }
            if (bitmap == null) {
                bitmap = BitmapFactory.decodeResource(activity.getResources(), RInformation.DRAWABLE_ICON);
            }
            wXMediaMessage.setThumbImage(bitmap);
            SendMessageToWX.Req req = new SendMessageToWX.Req();
            req.transaction = String.valueOf(System.currentTimeMillis());
            req.message = wXMediaMessage;
            req.scene = i;
            this.api.sendReq(req);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void sendImage(Activity activity, String str) {
        try {
            JSONObject jSONObject = new JSONObject(str);
            String optString = jSONObject.optString("image");
            String optString2 = jSONObject.optString("thumbs");
            String optString3 = jSONObject.optString("textToImage");
            int optInt = jSONObject.optInt("flag");
            initData();
            if (this.api == null) {
                this.api = WXAPIFactory.createWXAPI(activity.getApplicationContext(), APPID, true);
            }
            this.api.registerApp(APPID);
            if (!this.api.isWXAppInstalled()) {
                ToastCompat.makeText(activity.getApplicationContext(), (CharSequence) DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_client_not_installed), 0).show();
                return;
            }
            Bitmap bitmap = null;
            Bitmap decodeFile = (TextUtils.isEmpty(optString) || !new File(optString).exists()) ? null : BitmapFactory.decodeFile(optString);
            if (decodeFile == null && !TextUtils.isEmpty(optString3)) {
                decodeFile = StringUtil.textToBitmap(activity, optString3);
            }
            if (decodeFile != null) {
                WXImageObject wXImageObject = new WXImageObject(decodeFile);
                WXMediaMessage wXMediaMessage = new WXMediaMessage(wXImageObject);
                wXMediaMessage.mediaObject = wXImageObject;
                if (!TextUtils.isEmpty(optString2) && new File(optString2).exists()) {
                    bitmap = BitmapFactory.decodeFile(optString2);
                }
                if (bitmap == null) {
                    bitmap = BitmapFactory.decodeResource(activity.getResources(), RInformation.DRAWABLE_ICON);
                }
                wXMediaMessage.setThumbImage(bitmap);
                SendMessageToWX.Req req = new SendMessageToWX.Req();
                req.transaction = String.valueOf(System.currentTimeMillis());
                req.message = wXMediaMessage;
                req.scene = optInt;
                this.api.sendReq(req);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void sendText(Activity activity, String str) {
        try {
            JSONObject jSONObject = new JSONObject(str);
            String optString = jSONObject.optString("text");
            int optInt = jSONObject.optInt("flag");
            initData();
            if (this.api == null) {
                this.api = WXAPIFactory.createWXAPI(activity.getApplicationContext(), APPID, true);
            }
            this.api.registerApp(APPID);
            if (!this.api.isWXAppInstalled()) {
                ToastCompat.makeText(activity.getApplicationContext(), (CharSequence) DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_client_not_installed), 0).show();
                return;
            }
            WXTextObject wXTextObject = new WXTextObject();
            wXTextObject.text = optString;
            WXMediaMessage wXMediaMessage = new WXMediaMessage(wXTextObject);
            wXMediaMessage.mediaObject = wXTextObject;
            wXMediaMessage.description = optString;
            SendMessageToWX.Req req = new SendMessageToWX.Req();
            req.transaction = String.valueOf(System.currentTimeMillis());
            req.message = wXMediaMessage;
            req.scene = optInt;
            this.api.sendReq(req);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0051  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x005d  */
    private void onSendCallBack(IWebview iWebview, String str, int i) {
        boolean z;
        String str2 = "send";
        if (i == -5) {
            str2 = "Unsupport error";
        } else if (i == -4) {
            str2 = "Authentication failed";
        } else if (i == -3) {
            str2 = "Unable to send";
        } else if (i == -2) {
            str2 = "User canceled";
        } else if (i == -1) {
            str2 = "General errors";
        } else if (i != 0) {
            switch (i) {
                case ERROR_IMAGE_ONT_FOUND /*{ENCODED_INT: -103}*/:
                    str2 = "Picture not found";
                    break;
                case ERROR_IMAGE_LIMIT /*{ENCODED_INT: -102}*/:
                    str2 = "Picture maximum 512KB";
                    break;
                case ERROR_NOT_COMPLETE /*{ENCODED_INT: -101}*/:
                    str2 = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_param_not_complete);
                    break;
                case -100:
                    str2 = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_param_type_error);
                    break;
            }
        } else {
            z = true;
            if (!z) {
                Deprecated_JSUtil.execCallback(iWebview, str, "", JSUtil.OK, false, false);
                return;
            }
            Deprecated_JSUtil.execCallback(iWebview, str, StringUtil.format(DOMException.JSON_ERROR_INFO, -100, DOMException.toString(i, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_plugin_name), str2, IFShareApi.mLink)), JSUtil.ERROR, true, false);
            return;
        }
        z = false;
        if (!z) {
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqTextMsg(SendMessageToWX.Req req, String str, String str2) {
        WXTextObject wXTextObject = new WXTextObject();
        wXTextObject.text = str;
        WXMediaMessage wXMediaMessage = new WXMediaMessage();
        wXMediaMessage.mediaObject = wXTextObject;
        if (!PdrUtil.isEmpty(str2)) {
            wXMediaMessage.title = str2;
        } else if (req.scene == 1 && !TextUtils.isEmpty(str)) {
            wXMediaMessage.title = str;
        }
        wXMediaMessage.description = str;
        req.transaction = buildTransaction("text");
        req.message = wXMediaMessage;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqImageMsg(IWebview iWebview, SendMessageToWX.Req req, JSONArray jSONArray, JSONArray jSONArray2, String str, String str2) {
        WXMediaMessage wXMediaMessage = new WXMediaMessage();
        jSONArray.length();
        String optString = jSONArray.optString(0);
        String optString2 = (jSONArray2 == null || jSONArray2.isNull(0)) ? optString : jSONArray2.optString(0);
        if (PdrUtil.isNetPath(optString)) {
            WXImageObject wXImageObject = new WXImageObject();
            try {
                wXImageObject.imageData = bmpToByteArray(BitmapFactory.decodeStream(new URL(optString).openStream()), true);
            } catch (MalformedURLException e) {
                e.printStackTrace();
            } catch (IOException e2) {
                e2.printStackTrace();
            }
            wXMediaMessage.mediaObject = wXImageObject;
            if (!PdrUtil.isEmpty(optString2)) {
                optString = optString2;
            }
            wXMediaMessage.thumbData = buildThumbData(iWebview, optString);
        } else {
            String convert2LocalFullPath = iWebview.obtainFrameView().obtainApp().convert2LocalFullPath(iWebview.obtainFullUrl(), optString);
            WXImageObject wXImageObject2 = new WXImageObject();
            File file = new File(convert2LocalFullPath);
            InputStream inputStream = null;
            Context context = iWebview.getContext();
            try {
                if (file.exists()) {
                    if (Build.VERSION.SDK_INT < 29) {
                        wXImageObject2.imagePath = file.getPath();
                    } else if (FileUtil.checkPrivatePath(context, convert2LocalFullPath)) {
                        String str3 = context.getExternalCacheDir().getPath() + "/share/" + convert2LocalFullPath.substring(convert2LocalFullPath.lastIndexOf("/"));
                        DHFile.copyFile(convert2LocalFullPath, str3);
                        Uri uriForFile = FileProvider.getUriForFile(context, context.getPackageName() + ".dc.fileprovider", new File(str3));
                        context.grantUriPermission("com.tencent.mm", uriForFile, 1);
                        wXImageObject2.imagePath = uriForFile.toString();
                    } else if (FileUtil.isFilePathForPublic(context, convert2LocalFullPath)) {
                        Uri imageFileUri = FileUtil.getImageFileUri(context, convert2LocalFullPath);
                        if (imageFileUri != null) {
                            wXImageObject2.imagePath = imageFileUri.toString();
                        } else {
                            inputStream = FileUtil.getImageFileStream(context, file);
                        }
                    }
                    if (inputStream != null) {
                        if (inputStream.available() < 524288) {
                            wXImageObject2.imageData = IOUtil.getBytes(inputStream);
                            inputStream.close();
                        } else {
                            inputStream.close();
                            onSendCallBack(iWebview, str2, ERROR_IMAGE_LIMIT);
                            return false;
                        }
                    }
                    wXMediaMessage.mediaObject = wXImageObject2;
                    wXMediaMessage.thumbData = buildThumbData(iWebview, optString2);
                } else {
                    onSendCallBack(iWebview, str2, ERROR_IMAGE_ONT_FOUND);
                    return false;
                }
            } catch (Exception unused) {
            }
        }
        if (!PdrUtil.isEmpty(str)) {
            wXMediaMessage.title = str;
        }
        req.transaction = buildTransaction(WXBasicComponentType.IMG);
        req.message = wXMediaMessage;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqWebPageMsg(IWebview iWebview, SendMessageToWX.Req req, String str, String str2, String str3, String str4) {
        WXWebpageObject wXWebpageObject = new WXWebpageObject();
        wXWebpageObject.webpageUrl = str;
        WXMediaMessage wXMediaMessage = new WXMediaMessage(wXWebpageObject);
        if (!PdrUtil.isEmpty(str4)) {
            wXMediaMessage.title = str4;
        } else if (req.scene == 1 && !TextUtils.isEmpty(str3)) {
            wXMediaMessage.title = str3;
        }
        wXMediaMessage.description = str3;
        if (!PdrUtil.isEmpty(str2)) {
            wXMediaMessage.thumbData = buildThumbData(iWebview, str2);
        }
        req.transaction = buildTransaction("webpage");
        req.message = wXMediaMessage;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqMusicMsg(IWebview iWebview, SendMessageToWX.Req req, String str, String str2, String str3, String str4, String str5) {
        WXMusicObject wXMusicObject = new WXMusicObject();
        if (PdrUtil.isEmpty(str)) {
            wXMusicObject.musicUrl = str2;
        } else {
            wXMusicObject.musicUrl = str;
            wXMusicObject.musicDataUrl = str2;
        }
        WXMediaMessage wXMediaMessage = new WXMediaMessage();
        wXMediaMessage.mediaObject = wXMusicObject;
        if (!PdrUtil.isEmpty(str5)) {
            wXMediaMessage.title = str5;
        } else if (req.scene == 1 && !TextUtils.isEmpty(str4)) {
            wXMediaMessage.title = str4;
        }
        if (!PdrUtil.isEmpty(str3)) {
            wXMediaMessage.thumbData = buildThumbData(iWebview, str3);
        }
        wXMediaMessage.description = str4;
        req.transaction = buildTransaction("music");
        req.message = wXMediaMessage;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqVideoMsg(IWebview iWebview, SendMessageToWX.Req req, String str, String str2, String str3, String str4) {
        WXVideoObject wXVideoObject = new WXVideoObject();
        wXVideoObject.videoUrl = str;
        WXMediaMessage wXMediaMessage = new WXMediaMessage();
        wXMediaMessage.mediaObject = wXVideoObject;
        if (!PdrUtil.isEmpty(str4)) {
            wXMediaMessage.title = str4;
        } else if (req.scene == 1 && !TextUtils.isEmpty(str3)) {
            wXMediaMessage.title = str3;
        }
        if (!PdrUtil.isEmpty(str2)) {
            wXMediaMessage.thumbData = buildThumbData(iWebview, str2);
        }
        wXMediaMessage.description = str3;
        req.transaction = buildTransaction("video");
        req.message = wXMediaMessage;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqMiniMsg(IWebview iWebview, SendMessageToWX.Req req, String str, String str2, String str3, JSONObject jSONObject) {
        WXMiniProgramObject wXMiniProgramObject = new WXMiniProgramObject();
        wXMiniProgramObject.webpageUrl = jSONObject.optString("webUrl");
        wXMiniProgramObject.miniprogramType = jSONObject.optInt("type");
        wXMiniProgramObject.userName = jSONObject.optString("id");
        wXMiniProgramObject.path = jSONObject.optString("path");
        WXMediaMessage wXMediaMessage = new WXMediaMessage(wXMiniProgramObject);
        if (!PdrUtil.isEmpty(str3)) {
            wXMediaMessage.title = str3;
        } else if (req.scene == 1 && !TextUtils.isEmpty(str2)) {
            wXMediaMessage.title = str2;
        }
        req.scene = 0;
        if (!PdrUtil.isEmpty(str)) {
            wXMediaMessage.thumbData = getMiniThumbaData(iWebview, str);
        }
        wXMediaMessage.description = str2;
        req.transaction = buildTransaction("webpage");
        req.message = wXMediaMessage;
        return true;
    }

    private boolean reqMusicVideo(IWebview iWebview, SendMessageToWX.Req req, String str, String str2, String str3, String str4, String str5, String str6, String str7) {
        WXMusicVideoObject wXMusicVideoObject = new WXMusicVideoObject();
        wXMusicVideoObject.musicUrl = str;
        wXMusicVideoObject.musicDataUrl = str2;
        if (!TextUtils.isEmpty(str3)) {
            wXMusicVideoObject.songLyric = str3;
        }
        if (!TextUtils.isEmpty(str5)) {
            wXMusicVideoObject.hdAlbumThumbFilePath = str5;
        }
        wXMusicVideoObject.singerName = "xxx";
        wXMusicVideoObject.albumName = "album_xxx";
        wXMusicVideoObject.musicGenre = "流行歌曲";
        wXMusicVideoObject.issueDate = 1610713585;
        wXMusicVideoObject.identification = "sample_identification";
        wXMusicVideoObject.duration = 120000;
        WXMediaMessage wXMediaMessage = new WXMediaMessage();
        wXMediaMessage.mediaObject = wXMusicVideoObject;
        wXMediaMessage.title = str6;
        wXMediaMessage.description = str7;
        wXMediaMessage.messageExt = "额外信息";
        wXMediaMessage.thumbData = buildThumbData(iWebview, str4);
        req.transaction = buildTransaction("musicVideo");
        req.message = wXMediaMessage;
        return true;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:13:0x0031 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:5:0x001b */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r8v0, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r8v6 */
    /* JADX WARN: Type inference failed for: r8v7 */
    /* JADX WARN: Type inference failed for: r8v8 */
    /* JADX WARN: Type inference failed for: r8v9 */
    /* JADX WARN: Type inference failed for: r8v10 */
    /* JADX WARN: Type inference failed for: r8v12, types: [java.io.InputStream] */
    /* JADX WARN: Type inference failed for: r8v13, types: [java.io.InputStream] */
    /* JADX WARN: Type inference failed for: r8v14 */
    /* JADX WARN: Type inference failed for: r8v15 */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0031, code lost:
        if (r8 != 0) goto L_0x0033;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x004b, code lost:
        if (r8 != 0) goto L_0x0033;
     */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0045 A[Catch:{ MalformedURLException -> 0x0046, IOException -> 0x003e, all -> 0x003b, all -> 0x004e }] */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0051  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x0083  */
    private byte[] getMiniThumbaData(IWebview iWebview, String str) {
        InputStream inputStream;
        Throwable th;
        MalformedURLException e;
        IOException e2;
        String convert2LocalFullPath = iWebview.obtainFrameView().obtainApp().convert2LocalFullPath(iWebview.obtainFullUrl(), str);
        Bitmap bitmap = null;
        boolean z = false;
        try {
            if (PdrUtil.isNetPath(str)) {
                try {
                    str = new URL(str).openStream();
                    try {
                        if (str.available() > 131072) {
                            z = true;
                        }
                        if (str != 0) {
                            bitmap = BitmapFactory.decodeStream(str);
                        }
                    } catch (MalformedURLException e3) {
                        e = e3;
                        str = str;
                        e.printStackTrace();
                    } catch (IOException e4) {
                        e2 = e4;
                        str = str;
                        e2.printStackTrace();
                        if (str != 0) {
                        }
                        if (bitmap == null) {
                        }
                        bitmap = cpBitmap(bitmap);
                        return bmpToByteArray(bitmap, true);
                    }
                } catch (MalformedURLException e5) {
                    e = e5;
                    str = 0;
                    e.printStackTrace();
                } catch (IOException e6) {
                    e2 = e6;
                    str = 0;
                    e2.printStackTrace();
                    if (str != 0) {
                        str.close();
                    }
                    if (bitmap == null) {
                    }
                    bitmap = cpBitmap(bitmap);
                    return bmpToByteArray(bitmap, true);
                } catch (Throwable th2) {
                    th = th2;
                    inputStream = str;
                    if (inputStream != null) {
                    }
                    throw th;
                }
            } else {
                FileInputStream fileInputStream = new FileInputStream(convert2LocalFullPath);
                if (fileInputStream.available() > 131072) {
                    z = true;
                }
                bitmap = BitmapFactory.decodeStream(fileInputStream);
                fileInputStream.close();
            }
        } catch (Exception e7) {
            e7.printStackTrace();
            Logger.e("buildThumbData Exception=" + e7);
        }
        if (bitmap == null) {
            bitmap = BitmapFactory.decodeResource(iWebview.getActivity().getResources(), RInformation.DRAWABLE_ICON);
        }
        if (bitmap != null && z) {
            bitmap = cpBitmap(bitmap);
        }
        return bmpToByteArray(bitmap, true);
    }

    public Bitmap scaleLoadPic(IWebview iWebview, String str) throws IOException {
        InputStream inputStream;
        BitmapFactory.Options options = new BitmapFactory.Options();
        int i = 1;
        options.inJustDecodeBounds = true;
        if (FileUtil.checkPrivatePath(iWebview.getContext(), str)) {
            BitmapFactory.decodeFile(str, options);
        } else {
            InputStream imageFileStream = FileUtil.getImageFileStream(iWebview.getContext(), new File(str));
            if (imageFileStream != null) {
                BitmapFactory.decodeStream(imageFileStream, null, options);
                imageFileStream.close();
            }
        }
        int i2 = options.outWidth;
        int i3 = options.outHeight;
        Display defaultDisplay = iWebview.getActivity().getWindowManager().getDefaultDisplay();
        int width = i2 / defaultDisplay.getWidth();
        int height = i3 / defaultDisplay.getHeight();
        if (width >= height && width >= 1) {
            i = width;
        } else if (width < height && height >= 1) {
            i = height;
        }
        options.inSampleSize = i;
        options.inJustDecodeBounds = false;
        if (str.startsWith("content://")) {
            Uri parse = Uri.parse(str);
            Cursor query = iWebview.getContext().getContentResolver().query(parse, null, null, null, null);
            if (query == null) {
                return null;
            }
            try {
                inputStream = iWebview.getContext().getContentResolver().openInputStream(parse);
            } catch (FileNotFoundException e) {
                e.printStackTrace();
                inputStream = null;
            }
            query.moveToFirst();
            Bitmap decodeStream = BitmapFactory.decodeStream(inputStream, null, options);
            query.close();
            return decodeStream;
        } else if (FileUtil.checkPrivatePath(iWebview.getContext(), str)) {
            return BitmapFactory.decodeFile(str, options);
        } else {
            InputStream imageFileStream2 = FileUtil.getImageFileStream(iWebview.getContext(), new File(str));
            Bitmap decodeStream2 = BitmapFactory.decodeStream(imageFileStream2, null, options);
            imageFileStream2.close();
            return decodeStream2;
        }
    }

    private String buildTransaction(String str) {
        if (str == null) {
            return String.valueOf(System.currentTimeMillis());
        }
        return str + System.currentTimeMillis();
    }

    private static Bitmap cpBitmap(Bitmap bitmap) {
        if (PdrUtil.isEmpty(bitmap)) {
            return null;
        }
        while (bitmap.getHeight() * bitmap.getRowBytes() >= 32768) {
            Bitmap createScaledBitmap = Bitmap.createScaledBitmap(bitmap, (bitmap.getWidth() * 2) / 3, (bitmap.getHeight() * 2) / 3, true);
            bitmap.recycle();
            bitmap = createScaledBitmap;
        }
        return bitmap;
    }

    private byte[] buildThumbData(IWebview iWebview, String str) {
        Bitmap bitmap;
        String convert2LocalFullPath = iWebview.obtainFrameView().obtainApp().convert2LocalFullPath(iWebview.obtainFullUrl(), str);
        try {
            if (PdrUtil.isNetPath(str)) {
                bitmap = ImageLoaderL.getInstance().loadImageSync(str, new DisplayImageOptions.Builder().cacheOnDisc(false).cacheInMemory(false).imageScaleType(ImageScaleType.NONE).bitmapConfig(Bitmap.Config.RGB_565).showImageOnLoading(new ColorDrawable(0)).build());
            } else {
                bitmap = scaleLoadPic(iWebview, convert2LocalFullPath);
            }
        } catch (Exception e) {
            Logger.e("buildThumbData Exception=" + e);
            bitmap = null;
        }
        if (bitmap == null) {
            bitmap = BitmapFactory.decodeResource(iWebview.getActivity().getResources(), RInformation.DRAWABLE_ICON);
        }
        if (bitmap != null) {
            bitmap = cpBitmap(bitmap);
        }
        return bmpToByteArray(bitmap, true);
    }

    private void sedMultiplePic(Activity activity, ArrayList<Uri> arrayList, String str) {
        Intent intent = new Intent();
        intent.setComponent(new ComponentName("com.tencent.mm", str));
        intent.setAction("android.intent.action.SEND_MULTIPLE");
        intent.setType("image/*");
        intent.putParcelableArrayListExtra("android.intent.extra.STREAM", arrayList);
        activity.startActivity(intent);
    }

    public static byte[] bmpToByteArray(Bitmap bitmap, boolean z) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        bitmap.compress(Bitmap.CompressFormat.JPEG, 80, byteArrayOutputStream);
        if (z) {
            bitmap.recycle();
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        try {
            byteArrayOutputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return byteArray;
    }

    @Override // io.dcloud.share.IFShareApi
    public void forbid(IWebview iWebview) {
        if (this.api == null) {
            this.api = WXAPIFactory.createWXAPI(iWebview.getActivity().getApplicationContext(), APPID, true);
        }
        this.api.unregisterApp();
    }

    @Override // io.dcloud.share.IFShareApi
    public void authorize(IWebview iWebview, String str, String str2) {
        JSONObject createJSONObject = JSONUtil.createJSONObject(str2);
        if (createJSONObject != null) {
            APPID = createJSONObject.optString("appid", APPID);
            Logger.e(TAG, "authorize: appId" + APPID);
        }
        if (!hasGeneralError(iWebview, str)) {
            boolean register = register(iWebview);
            if (register) {
                Deprecated_JSUtil.execCallback(iWebview, str, StringUtil.format(AUTHORIZE_TEMPLATE, Boolean.valueOf(register), ""), JSUtil.OK, true, false);
                return;
            }
            Deprecated_JSUtil.execCallback(iWebview, str, DOMException.toJSON(-100, DOMException.toString(-4, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_plugin_name), DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_auth_fail), IFShareApi.mLink)), JSUtil.ERROR, true, false);
        }
    }

    private boolean register(IWebview iWebview) {
        if (this.api == null) {
            this.api = WXAPIFactory.createWXAPI(iWebview.getActivity().getApplicationContext(), APPID, true);
        }
        if (!PdrUtil.isEmpty(APPID)) {
            return this.api.registerApp(APPID);
        }
        return false;
    }

    @Override // io.dcloud.share.IFShareApi
    public String getJsonObject(IWebview iWebview) {
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("id", WEIXIN_ID);
            jSONObject.put("description", WEIXIN_DES);
            jSONObject.put(AbsoluteConst.JSON_SHARE_AUTHENTICATED, register(iWebview));
            jSONObject.put(AbsoluteConst.JSON_SHARE_ACCESSTOKEN, "");
            jSONObject.put(AbsoluteConst.JSON_SHARE_NATIVECLIENT, this.api.isWXAppInstalled());
            return jSONObject.toString();
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean hasWXEntryActivity(Context context) {
        try {
            Class.forName(context.getPackageName() + MMessageActV2.DEFAULT_ENTRY_CLASS_NAME);
            return true;
        } catch (ClassNotFoundException unused) {
            return false;
        }
    }

    @Override // io.dcloud.share.IWeiXinFShareApi
    public void launchMiniProgram(IWebview iWebview, String str, String str2) {
        try {
            if (!hasGeneralError(iWebview, str2)) {
                JSONObject jSONObject = new JSONObject(str);
                String optString = jSONObject.optString("id");
                String optString2 = jSONObject.optString("path");
                int optInt = jSONObject.optInt("type", 0);
                if (PdrUtil.isEmpty(optString)) {
                    Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                } else if (!(iWebview.getActivity() instanceof IActivityHandler) || !((IActivityHandler) iWebview.getActivity()).isMultiProcessMode()) {
                    WXLaunchMiniProgram.Req req = new WXLaunchMiniProgram.Req();
                    req.userName = optString;
                    req.path = optString2;
                    req.miniprogramType = optInt;
                    if (!this.api.sendReq(req)) {
                        Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                    } else if (hasWXEntryActivity(iWebview.getContext())) {
                        FeatureMessageDispatcher.registerListener(this.sSendCallbackMessageListener);
                        registerSendCallbackMsg(new Object[]{iWebview, str2});
                    }
                } else {
                    startWXMiniProgramMediator(iWebview, str2, optString, optString2, optInt);
                }
            }
        } catch (Exception e) {
            Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, -99, DOMException.MSG_UNKNOWN_ERROR + e.getMessage()), JSUtil.ERROR, true, false);
        }
    }

    @Override // io.dcloud.share.IWeiXinFShareApi
    public void openCustomerServiceChat(IWebview iWebview, String str, String str2) {
        try {
            if (hasGeneralError(iWebview, str2)) {
                return;
            }
            if (this.api.getWXAppSupportAPI() >= 671090490) {
                JSONObject jSONObject = new JSONObject(str);
                String string = jSONObject.getString("url");
                String string2 = jSONObject.getString("corpid");
                if (PdrUtil.isEmpty(string) || PdrUtil.isEmpty(string2)) {
                    Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                    return;
                }
                WXOpenCustomerServiceChat.Req req = new WXOpenCustomerServiceChat.Req();
                req.corpId = string2;
                req.url = string;
                if (this.api.sendReq(req)) {
                    Deprecated_JSUtil.execCallback(iWebview, str2, "", JSUtil.OK, false, false);
                    return;
                }
                Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                return;
            }
            Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, Integer.valueOf((int) ERROR_NOT_SUPPORT_VERSION_CODE), ERROR_NOT_SUPPORT_VERSION_MSG), JSUtil.ERROR, true, false);
        } catch (Exception e) {
            Deprecated_JSUtil.execCallback(iWebview, str2, StringUtil.format(DOMException.JSON_ERROR_INFO, -99, DOMException.MSG_UNKNOWN_ERROR + e.getMessage()), JSUtil.ERROR, true, false);
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void dispose() {
        IWXAPI iwxapi = this.api;
        if (iwxapi != null) {
            iwxapi.unregisterApp();
            this.api.detach();
        }
        this.api = null;
    }
}
