package com.autonavi.base.ae.gmap.glyph;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.os.Build;
import android.text.TextPaint;
import android.text.TextUtils;
import android.util.Log;
import android.view.accessibility.AccessibilityManager;
import com.amap.api.col.p0003s.p;
import com.autonavi.base.amap.mapcore.tools.GLConvertUtil;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.HashMap;
import java.util.Map;

public class GlyphLoader {
    private static Map<String, Typeface> FontFaceMap = new HashMap();

    private static native long nativeCreateGlyphLoader();

    private static native void nativeDestroyGlyphLoader(long j);

    private static GlyphMetrics loadGlyphMetrics(String str, FontStyle fontStyle, float f, String str2, boolean z, float f2, boolean z2, boolean z3) {
        GlyphMetrics glyphMetrics = new GlyphMetrics();
        if (fontStyle == null || TextUtils.isEmpty(str)) {
            return glyphMetrics;
        }
        if (!z2) {
            try {
                TextPaint newTextPaint = newTextPaint(fontStyle, f, str2, z, f2);
                Rect rect = new Rect();
                newTextPaint.getTextBounds(str, 0, str.length(), rect);
                if (rect.width() == 0 && rect.height() == 0) {
                    float measureText = newTextPaint.measureText(Operators.SPACE_STR, 0, 1);
                    rect.top = 0;
                    rect.left = 0;
                    rect.right = (int) measureText;
                    rect.bottom = (int) (Math.abs(newTextPaint.getFontMetrics().ascent) + Math.abs(newTextPaint.getFontMetrics().descent));
                }
                if (z && f2 > 0.0f) {
                    float f3 = f2 / 2.0f;
                    rect.top = (int) (((float) rect.top) - f3);
                    rect.left = (int) (((float) rect.left) - f3);
                    rect.right = (int) (((float) rect.right) + f3);
                    rect.bottom = (int) (((float) rect.bottom) + f3);
                }
                glyphMetrics.bSuccess = true;
                glyphMetrics.fLeft = (float) rect.left;
                glyphMetrics.fTop = Math.abs(newTextPaint.getFontMetrics().ascent) - ((float) Math.abs(rect.top));
                glyphMetrics.nWidth = rect.width();
                glyphMetrics.nHeight = rect.height();
                glyphMetrics.fAdvance = newTextPaint.measureText(str);
                newTextPaint.setTypeface(null);
            } catch (Exception unused) {
                glyphMetrics.bSuccess = false;
            }
        } else {
            glyphMetrics.bSuccess = true;
            glyphMetrics.fLeft = 0.0f;
            glyphMetrics.fTop = 0.0f;
            int i = (int) f;
            glyphMetrics.nWidth = i;
            glyphMetrics.nHeight = i;
            glyphMetrics.fAdvance = f;
        }
        return glyphMetrics;
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x00b7 A[Catch:{ Exception -> 0x013a }] */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x00c5 A[Catch:{ Exception -> 0x013a }] */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x00c7 A[Catch:{ Exception -> 0x013a }] */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x0105 A[Catch:{ Exception -> 0x013a }] */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x0127 A[Catch:{ Exception -> 0x013a }] */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x012a A[Catch:{ Exception -> 0x013a }] */
    private static GlyphRaster loadGlyphRaster(String str, FontStyle fontStyle, float f, String str2, boolean z, float f2, boolean z2, boolean z3) {
        boolean z4;
        TextPaint newTextPaint;
        Rect rect;
        int i;
        GlyphRaster glyphRaster = new GlyphRaster();
        if (fontStyle == null || TextUtils.isEmpty(str)) {
            return glyphRaster;
        }
        try {
            Context context = p.a;
            if (context != null) {
                z4 = ((Boolean) ReflectUtil.invoke("android.view.accessibility.AccessibilityManager", (AccessibilityManager) context.getApplicationContext().getSystemService("accessibility"), "isHighTextContrastEnabled", null)).booleanValue();
                newTextPaint = newTextPaint(fontStyle, f, str2, z, f2);
                rect = new Rect();
                newTextPaint.getTextBounds(str, 0, str.length(), rect);
                if (rect.width() == 0 && rect.height() == 0) {
                    rect.right = (int) newTextPaint.measureText(Operators.SPACE_STR, 0, 1);
                    rect.bottom = (int) (Math.abs(newTextPaint.getFontMetrics().ascent) + Math.abs(newTextPaint.getFontMetrics().descent));
                    rect.left = 0;
                    rect.top = 0;
                }
                if (z && f2 > 0.0f) {
                    float f3 = f2 / 2.0f;
                    rect.top = (int) (((float) rect.top) - f3);
                    rect.left = (int) (((float) rect.left) - f3);
                    rect.right = (int) (((float) rect.right) + f3);
                    rect.bottom = (int) (((float) rect.bottom) + f3);
                }
                if (!rect.isEmpty()) {
                    Bitmap.Config config = Bitmap.Config.ALPHA_8;
                    if (!z2) {
                        if (!z4) {
                            i = 1;
                            int i2 = !z3 ? 3 : 0;
                            int i3 = i2 * 2;
                            Bitmap createBitmap = Bitmap.createBitmap(rect.width() + i3, rect.height() + i3, config);
                            new Canvas(createBitmap).drawText(str, (float) ((0 - rect.left) + i2), (float) ((0 - rect.top) + i2), newTextPaint);
                            int width = rect.width() + i3;
                            int height = rect.height() + i3;
                            int i4 = width * height;
                            byte[] bArr = new byte[(i4 * i)];
                            createBitmap.copyPixelsToBuffer(ByteBuffer.wrap(bArr));
                            if (z4) {
                                byte[] bArr2 = new byte[i4];
                                for (int i5 = 0; i5 < height; i5++) {
                                    for (int i6 = 0; i6 < width * i; i6 += i) {
                                        int i7 = i5 * width;
                                        bArr2[(i6 / i) + i7] = bArr[(i7 * i) + i6];
                                    }
                                }
                                bArr = bArr2;
                            }
                            glyphRaster.bitmapWidth = width;
                            glyphRaster.bitmapHeight = height;
                            if (!z2) {
                                glyphRaster.bitmapPixelMode = 1;
                            } else {
                                glyphRaster.bitmapPixelMode = 0;
                            }
                            glyphRaster.bitmapSize = bArr.length;
                            glyphRaster.bitmapBuffer = bArr;
                            createBitmap.recycle();
                            glyphRaster.bSuccess = true;
                        }
                    }
                    config = Bitmap.Config.ARGB_8888;
                    i = 4;
                    if (!z3) {
                    }
                    int i32 = i2 * 2;
                    Bitmap createBitmap2 = Bitmap.createBitmap(rect.width() + i32, rect.height() + i32, config);
                    new Canvas(createBitmap2).drawText(str, (float) ((0 - rect.left) + i2), (float) ((0 - rect.top) + i2), newTextPaint);
                    int width2 = rect.width() + i32;
                    int height2 = rect.height() + i32;
                    int i42 = width2 * height2;
                    byte[] bArr3 = new byte[(i42 * i)];
                    createBitmap2.copyPixelsToBuffer(ByteBuffer.wrap(bArr3));
                    if (z4) {
                    }
                    glyphRaster.bitmapWidth = width2;
                    glyphRaster.bitmapHeight = height2;
                    if (!z2) {
                    }
                    glyphRaster.bitmapSize = bArr3.length;
                    glyphRaster.bitmapBuffer = bArr3;
                    createBitmap2.recycle();
                    glyphRaster.bSuccess = true;
                }
                newTextPaint.setTypeface(null);
                return glyphRaster;
            }
        } catch (Throwable th) {
            Log.e("HighText", "highText exception:" + th.toString());
        }
        z4 = false;
        try {
            newTextPaint = newTextPaint(fontStyle, f, str2, z, f2);
            rect = new Rect();
            newTextPaint.getTextBounds(str, 0, str.length(), rect);
            rect.right = (int) newTextPaint.measureText(Operators.SPACE_STR, 0, 1);
            rect.bottom = (int) (Math.abs(newTextPaint.getFontMetrics().ascent) + Math.abs(newTextPaint.getFontMetrics().descent));
            rect.left = 0;
            rect.top = 0;
            float f32 = f2 / 2.0f;
            rect.top = (int) (((float) rect.top) - f32);
            rect.left = (int) (((float) rect.left) - f32);
            rect.right = (int) (((float) rect.right) + f32);
            rect.bottom = (int) (((float) rect.bottom) + f32);
            if (!rect.isEmpty()) {
            }
            newTextPaint.setTypeface(null);
        } catch (Exception unused) {
            glyphRaster.bSuccess = false;
        }
        return glyphRaster;
    }

    private static GlyphRequestParam genGlyphRequestParam(byte[] bArr) {
        GlyphRequestParam glyphRequestParam = new GlyphRequestParam();
        int i = GLConvertUtil.getInt(bArr, 0);
        glyphRequestParam.strBuffer = new String(bArr, 4, i);
        int i2 = i + 4;
        Font font = new Font();
        font.nFontStyleCode = GLConvertUtil.getInt(bArr, i2);
        int i3 = i2 + 4;
        font.nFontSize = GLConvertUtil.getInt(bArr, i3);
        int i4 = i3 + 4;
        int i5 = GLConvertUtil.getInt(bArr, i4);
        int i6 = i4 + 4;
        font.strName = new String(bArr, i6, i5);
        int i7 = i6 + i5;
        FontMetrics fontMetrics = new FontMetrics();
        int i8 = GLConvertUtil.getInt(bArr, i7);
        int i9 = i7 + 4;
        fontMetrics.fAscent = ((float) i8) * 0.001f;
        int i10 = GLConvertUtil.getInt(bArr, i9);
        int i11 = i9 + 4;
        fontMetrics.fDescent = ((float) i10) * 0.001f;
        int i12 = GLConvertUtil.getInt(bArr, i11);
        int i13 = i11 + 4;
        fontMetrics.fLeading = ((float) i12) * 0.001f;
        int i14 = GLConvertUtil.getInt(bArr, i13);
        int i15 = i13 + 4;
        fontMetrics.fHeight = ((float) i14) * 0.001f;
        font.fontMetrics = fontMetrics;
        glyphRequestParam.font = font;
        glyphRequestParam.drawingMode = GLConvertUtil.getInt(bArr, i15);
        int i16 = i15 + 4;
        int i17 = GLConvertUtil.getInt(bArr, i16);
        int i18 = i16 + 4;
        glyphRequestParam.strokeWidth = ((float) i17) * 0.001f;
        int i19 = GLConvertUtil.getInt(bArr, i18);
        int i20 = i18 + 4;
        glyphRequestParam.languageArr = new String(bArr, i20, i19);
        glyphRequestParam.isEmoji = GLConvertUtil.getInt(bArr, i20);
        int i21 = i20 + 4;
        glyphRequestParam.isSDF = GLConvertUtil.getInt(bArr, i21);
        int i22 = i21 + 4;
        int i23 = GLConvertUtil.getInt(bArr, i22);
        int i24 = i22 + 4;
        if (1 == i23) {
            GlyphMetrics glyphMetrics = new GlyphMetrics();
            glyphMetrics.nWidth = GLConvertUtil.getInt(bArr, i24);
            int i25 = i24 + 4;
            glyphMetrics.nHeight = GLConvertUtil.getInt(bArr, i25);
            int i26 = i25 + 4;
            int i27 = GLConvertUtil.getInt(bArr, i26);
            int i28 = i26 + 4;
            glyphMetrics.fLeft = ((float) i27) * 0.001f;
            glyphMetrics.fTop = ((float) GLConvertUtil.getInt(bArr, i28)) * 0.001f;
            glyphMetrics.fAdvance = ((float) GLConvertUtil.getInt(bArr, i28 + 4)) * 0.001f;
            glyphRequestParam.fGlyphMetrics = glyphMetrics;
        }
        return glyphRequestParam;
    }

    private static FontMetricsRequestParam genFontMetricsParam(byte[] bArr) {
        FontMetricsRequestParam fontMetricsRequestParam = new FontMetricsRequestParam();
        fontMetricsRequestParam.fFontSize = ((float) GLConvertUtil.getInt(bArr, 0)) * 0.001f;
        fontMetricsRequestParam.nFontStyleCode = GLConvertUtil.getInt(bArr, 4);
        int i = 12;
        if (1 == GLConvertUtil.getInt(bArr, 8)) {
            int i2 = GLConvertUtil.getInt(bArr, 12);
            fontMetricsRequestParam.strName = new String(bArr, 16, i2);
            i = i2 + 16;
        }
        fontMetricsRequestParam.languageArr = new String(bArr, i + 4, GLConvertUtil.getInt(bArr, i));
        return fontMetricsRequestParam;
    }

    private static GlyphMetrics getGlyphMetrics(byte[] bArr) {
        GlyphRequestParam genGlyphRequestParam = genGlyphRequestParam(bArr);
        return loadGlyphMetrics(genGlyphRequestParam.strBuffer, new FontStyle(genGlyphRequestParam.font.nFontStyleCode), (float) genGlyphRequestParam.font.nFontSize, genGlyphRequestParam.font.strName, genGlyphRequestParam.drawingMode != 0, genGlyphRequestParam.strokeWidth, genGlyphRequestParam.isEmoji > 0, genGlyphRequestParam.isSDF > 0);
    }

    private static GlyphRaster getGlyphRaster(byte[] bArr) {
        GlyphRequestParam genGlyphRequestParam = genGlyphRequestParam(bArr);
        FontStyle fontStyle = new FontStyle(genGlyphRequestParam.font.nFontStyleCode);
        boolean z = genGlyphRequestParam.drawingMode != 0;
        if (genGlyphRequestParam.drawingMode == 3) {
            return loadPathRaster(genGlyphRequestParam.strBuffer, fontStyle, (float) genGlyphRequestParam.font.nFontSize, genGlyphRequestParam.font.strName, z, 2.0f * genGlyphRequestParam.strokeWidth);
        }
        return loadGlyphRaster(genGlyphRequestParam.strBuffer, fontStyle, (float) genGlyphRequestParam.font.nFontSize, genGlyphRequestParam.font.strName, z, genGlyphRequestParam.strokeWidth, genGlyphRequestParam.isEmoji > 0, genGlyphRequestParam.isSDF > 0);
    }

    public static GlyphRaster loadPathRaster(String str, FontStyle fontStyle, float f, String str2, boolean z, float f2) {
        GlyphRaster glyphRaster = new GlyphRaster();
        if (fontStyle == null || TextUtils.isEmpty(str)) {
            return glyphRaster;
        }
        try {
            TextPaint newTextPaint = newTextPaint(fontStyle, f, str2, false, 0.0f);
            Rect rect = new Rect();
            newTextPaint.getTextBounds(str, 0, str.length(), rect);
            new Canvas(Bitmap.createBitmap(rect.width(), rect.height(), Bitmap.Config.ALPHA_8)).drawText(str, (float) (0 - rect.left), (float) (0 - rect.top), newTextPaint);
            TextPaint newTextPaint2 = newTextPaint(fontStyle, f, str2, z, f2);
            Rect rect2 = new Rect();
            newTextPaint2.getTextBounds(str, 0, str.length(), rect2);
            if (z && f2 > 0.0f) {
                float f3 = 0.5f * f2;
                rect2.top = (int) (((float) rect2.top) - f3);
                rect2.left = (int) (((float) rect2.left) - f3);
                rect2.right = (int) (((float) rect2.right) + f3);
                rect2.bottom = (int) (((float) rect2.bottom) + f3);
            }
            if (!rect2.isEmpty()) {
                Bitmap createBitmap = Bitmap.createBitmap(rect2.width(), rect2.height(), Bitmap.Config.ALPHA_8);
                Canvas canvas = new Canvas(createBitmap);
                Path path = new Path();
                newTextPaint.getTextPath(str, 0, str.length(), (float) (0 - rect2.left), (float) (0 - rect2.top), path);
                canvas.drawPath(path, newTextPaint2);
                int width = rect2.width() * rect2.height();
                byte[] bArr = new byte[width];
                ByteBuffer wrap = ByteBuffer.wrap(bArr);
                glyphRaster.bitmapWidth = rect2.width();
                glyphRaster.bitmapHeight = rect2.height();
                glyphRaster.bitmapPixelMode = 0;
                glyphRaster.bitmapSize = width;
                createBitmap.copyPixelsToBuffer(wrap);
                createBitmap.recycle();
                glyphRaster.bitmapBuffer = bArr;
                glyphRaster.bSuccess = true;
            }
            newTextPaint.setTypeface(null);
            newTextPaint2.setTypeface(null);
        } catch (Exception unused) {
            glyphRaster.bSuccess = false;
        }
        return glyphRaster;
    }

    private static FontMetrics getFontMetrics(byte[] bArr) {
        FontMetricsRequestParam genFontMetricsParam = genFontMetricsParam(bArr);
        TextPaint newTextPaint = newTextPaint(new FontStyle(genFontMetricsParam.nFontStyleCode), genFontMetricsParam.fFontSize, genFontMetricsParam.strName, false, 0.0f);
        Paint.FontMetrics fontMetrics = newTextPaint.getFontMetrics();
        FontMetrics fontMetrics2 = new FontMetrics();
        fontMetrics2.bSuccess = true;
        fontMetrics2.fAscent = Math.abs(fontMetrics.ascent);
        fontMetrics2.fDescent = Math.abs(fontMetrics.descent);
        fontMetrics2.fLeading = Math.abs(fontMetrics.leading);
        fontMetrics2.fHeight = Math.abs(fontMetrics.ascent) + Math.abs(fontMetrics.descent);
        newTextPaint.setTypeface(null);
        return fontMetrics2;
    }

    private static String decodeUnicode(short s) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append((char) s);
        return stringBuffer.toString();
    }

    private static String decodeUnicode(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(str);
        return stringBuffer.toString();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0054, code lost:
        if (r3 != false) goto L_0x0058;
     */
    private static TextPaint newTextPaint(FontStyle fontStyle, float f, String str, boolean z, float f2) {
        boolean z2;
        Typeface typeface;
        TextPaint textPaint = new TextPaint();
        if (fontStyle == null) {
            return textPaint;
        }
        textPaint.setColor(-1);
        boolean z3 = true;
        textPaint.setAntiAlias(true);
        textPaint.setFilterBitmap(true);
        textPaint.setTextSize(f);
        textPaint.setTextAlign(Paint.Align.LEFT);
        if (z) {
            textPaint.setStyle(Paint.Style.STROKE);
            textPaint.setStrokeWidth(f2);
        } else {
            textPaint.setStyle(Paint.Style.FILL);
        }
        int slant = fontStyle.getSlant();
        int i = 2;
        boolean z4 = slant != 0 && (slant == 1 || slant == 2);
        switch (fontStyle.getWeight()) {
            case 0:
            case 100:
            case 200:
            case 300:
            case 400:
            default:
                z2 = false;
                break;
            case 500:
            case 600:
            case 700:
            case 800:
            case 900:
            case 1000:
                z2 = true;
                break;
        }
        if (z2 && z4) {
            textPaint.setFakeBoldText(true);
        } else if (z2) {
            textPaint.setFakeBoldText(true);
        }
        i = 0;
        try {
            if (Build.VERSION.SDK_INT >= 23) {
                z3 = false;
            }
        } catch (NumberFormatException unused) {
        }
        if (str.isEmpty() || z3) {
            typeface = Typeface.create(Typeface.DEFAULT, i);
        } else {
            try {
                synchronized (FontFaceMap) {
                    typeface = FontFaceMap.get(str);
                    if (typeface == null) {
                        typeface = Typeface.createFromFile(str);
                        FontFaceMap.put(str, typeface);
                    }
                }
            } catch (Exception unused2) {
                typeface = Typeface.create(Typeface.DEFAULT, i);
            }
        }
        textPaint.setTypeface(typeface);
        return textPaint;
    }

    public static long createGlyphLoader() {
        return nativeCreateGlyphLoader();
    }

    public static void destroyGlyphLoader(long j) {
        nativeDestroyGlyphLoader(j);
    }
}
