package io.dcloud.feature.weex_amap.adapter.ground;

import android.graphics.Bitmap;
import android.net.Uri;
import android.text.TextUtils;
import androidx.core.app.NotificationCompat;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.GroundOverlay;
import com.amap.api.maps.model.GroundOverlayOptions;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.WXImage;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.feature.uniapp.bridge.UniJSCallback;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import io.dcloud.feature.weex.adapter.FrescoLoadUtil;
import io.dcloud.feature.weex_amap.R;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.HashMap;

public class GroundMgr extends MapAbsMgr {
    HashMap<String, GroundOverlay> mGroundCaches = new HashMap<>();

    public GroundMgr(WXSDKInstance wXSDKInstance, WXMapView wXMapView) {
        super(wXSDKInstance, wXMapView);
    }

    public void addGroundOverlay(JSONObject jSONObject, UniJSCallback uniJSCallback) {
        editGroundOverlay(jSONObject, uniJSCallback);
    }

    public void updateGroundOverlay(JSONObject jSONObject, UniJSCallback uniJSCallback) {
        editGroundOverlay(jSONObject, uniJSCallback);
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0080 A[Catch:{ Exception -> 0x00f4 }] */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0098 A[Catch:{ Exception -> 0x00f4 }] */
    private void editGroundOverlay(JSONObject jSONObject, UniJSCallback uniJSCallback) {
        LatLngBounds bounds;
        HashMap hashMap = new HashMap();
        try {
            if (!jSONObject.containsKey("id") || !jSONObject.containsKey("src") || !jSONObject.containsKey("bounds")) {
                hashMap.put("type", Constants.Event.FAIL);
                hashMap.put(NotificationCompat.CATEGORY_MESSAGE, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_weex_amap_msg_bounds_cannot_null));
                uniJSCallback.invoke(hashMap);
                return;
            }
            String string = jSONObject.getString("id");
            boolean z = !this.mGroundCaches.containsKey(string);
            String string2 = jSONObject.getString("src");
            JSONObject jSONObject2 = jSONObject.getJSONObject("bounds");
            boolean booleanValue = jSONObject.containsKey("visible") ? jSONObject.getBooleanValue("visible") : true;
            int intValue = UniUtils.getInteger(jSONObject.get(Constant.JSONKEY.ZINDEX), 1).intValue();
            float f = 1.0f;
            if (jSONObject.containsKey("opacity")) {
                float floatValue = jSONObject.getFloatValue("opacity");
                if (floatValue < 1.0f) {
                    if (floatValue > 0.0f) {
                        f = 1.0f - floatValue;
                    }
                    bounds = getBounds(jSONObject2);
                    if (bounds != null) {
                        hashMap.put("type", Constants.Event.FAIL);
                        hashMap.put(NotificationCompat.CATEGORY_MESSAGE, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_weex_amap_msg_bounds_create_fail));
                        uniJSCallback.invoke(hashMap);
                        return;
                    } else if (z) {
                        GroundOverlayOptions groundOverlayOptions = new GroundOverlayOptions();
                        groundOverlayOptions.visible(booleanValue);
                        groundOverlayOptions.transparency(f);
                        groundOverlayOptions.zIndex((float) intValue);
                        groundOverlayOptions.positionFromBounds(bounds);
                        loadImageToIcon(string, string2, groundOverlayOptions, null, uniJSCallback);
                        return;
                    } else {
                        GroundOverlay groundOverlay = this.mGroundCaches.get(string);
                        groundOverlay.setVisible(booleanValue);
                        groundOverlay.setTransparency(f);
                        groundOverlay.setZIndex((float) intValue);
                        groundOverlay.setPositionFromBounds(bounds);
                        loadImageToIcon(string, string2, null, groundOverlay, uniJSCallback);
                        return;
                    }
                }
            }
            f = 0.0f;
            bounds = getBounds(jSONObject2);
            if (bounds != null) {
            }
        } catch (Exception e) {
            e.printStackTrace();
            hashMap.put("type", Constants.Event.FAIL);
            hashMap.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
            uniJSCallback.invoke(hashMap);
        }
    }

    public void removeGroundOverlay(String str, UniJSCallback uniJSCallback) {
        HashMap hashMap = new HashMap();
        try {
            HashMap<String, GroundOverlay> hashMap2 = this.mGroundCaches;
            if (hashMap2 != null && hashMap2.size() > 0 && !TextUtils.isEmpty(str) && this.mGroundCaches.containsKey(str)) {
                this.mGroundCaches.remove(str).remove();
            }
            hashMap.put("type", WXImage.SUCCEED);
            uniJSCallback.invoke(hashMap);
        } catch (Exception e) {
            e.printStackTrace();
            hashMap.put("type", Constants.Event.FAIL);
            hashMap.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
            uniJSCallback.invoke(hashMap);
        }
    }

    private void loadImageToIcon(final String str, String str2, final GroundOverlayOptions groundOverlayOptions, final GroundOverlay groundOverlay, final UniJSCallback uniJSCallback) {
        FrescoLoadUtil.getInstance().loadImageBitmap(this.mInstance.getContext(), this.mInstance.rewriteUri(Uri.parse(str2), "image").toString(), new BitmapLoadCallback<Bitmap>() {
            /* class io.dcloud.feature.weex_amap.adapter.ground.GroundMgr.AnonymousClass1 */

            public void onSuccess(String str, Bitmap bitmap) {
                BitmapDescriptor fromBitmap = BitmapDescriptorFactory.fromBitmap(bitmap);
                GroundOverlay groundOverlay = groundOverlay;
                if (groundOverlay != null) {
                    groundOverlay.setImage(fromBitmap);
                    return;
                }
                GroundOverlayOptions groundOverlayOptions = groundOverlayOptions;
                if (groundOverlayOptions != null) {
                    groundOverlayOptions.image(fromBitmap);
                    GroundOverlay addGroundOverlay = GroundMgr.this.mMap.getMap().addGroundOverlay(groundOverlayOptions);
                    if (addGroundOverlay != null) {
                        GroundMgr.this.mGroundCaches.put(str, addGroundOverlay);
                        if (uniJSCallback != null) {
                            HashMap hashMap = new HashMap();
                            hashMap.put("type", WXImage.SUCCEED);
                            uniJSCallback.invoke(hashMap);
                            return;
                        }
                        return;
                    }
                    HashMap hashMap2 = new HashMap();
                    hashMap2.put("type", Constants.Event.FAIL);
                    uniJSCallback.invoke(hashMap2);
                }
            }

            @Override // io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback
            public void onFailure(String str, Throwable th) {
                HashMap hashMap = new HashMap();
                hashMap.put("type", Constants.Event.FAIL);
                uniJSCallback.invoke(hashMap);
            }
        });
    }

    private LatLngBounds getBounds(JSONObject jSONObject) {
        if (jSONObject == null || !jSONObject.containsKey("southwest") || !jSONObject.containsKey("northeast")) {
            return null;
        }
        JSONObject jSONObject2 = jSONObject.getJSONObject("southwest");
        JSONObject jSONObject3 = jSONObject.getJSONObject("northeast");
        if (jSONObject2 == null || jSONObject3 == null || !jSONObject2.containsKey(Constant.JSONKEY.LATITUDE) || !jSONObject2.containsKey(Constant.JSONKEY.LONGITUDE) || !jSONObject3.containsKey(Constant.JSONKEY.LATITUDE) || !jSONObject3.containsKey(Constant.JSONKEY.LONGITUDE)) {
            return null;
        }
        return new LatLngBounds(new LatLng(jSONObject2.getDoubleValue(Constant.JSONKEY.LATITUDE), jSONObject2.getDoubleValue(Constant.JSONKEY.LONGITUDE)), new LatLng(jSONObject3.getDoubleValue(Constant.JSONKEY.LATITUDE), jSONObject3.getDoubleValue(Constant.JSONKEY.LONGITUDE)));
    }

    public void destroy() {
        HashMap<String, GroundOverlay> hashMap = this.mGroundCaches;
        if (hashMap != null && hashMap.size() > 0) {
            for (String str : this.mGroundCaches.keySet()) {
                GroundOverlay groundOverlay = this.mGroundCaches.get(str);
                if (groundOverlay != null && groundOverlay.isVisible()) {
                    groundOverlay.remove();
                }
            }
        }
        this.mGroundCaches.clear();
    }
}
